import MFnSet  # type: ignore
import MItDag  # type: ignore
from _typeshed import Incomplete
from typing import Any, ClassVar, overload

class MAngle:
    kAngMinutes: ClassVar[int] = ...
    kAngSeconds: ClassVar[int] = ...
    kDegrees: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kRadians: ClassVar[int] = ...
    unit: Incomplete
    value: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def asAngMinutes(self, *args, **kwargs): ...
    def asAngSeconds(self, *args, **kwargs): ...
    def asDegrees(self, *args, **kwargs): ...
    def asRadians(self, *args, **kwargs): ...
    def asUnits(self, *args, **kwargs): ...
    @staticmethod
    def internalToUI(*args, **kwargs): ...
    @staticmethod
    def internalUnit(*args, **kwargs): ...
    @staticmethod
    def setUIUnit(*args, **kwargs): ...
    @staticmethod
    def uiToInternal(*args, **kwargs): ...
    @staticmethod
    def uiUnit(*args, **kwargs): ...

class MArgDatabase(MArgParser):
    def __init__(self, *args, **kwargs) -> None: ...
    def commandArgumentMSelectionList(self, argIndex) -> MSelectionList: ...
    def flagArgumentMSelectionList(self, flagName, argIndex) -> MSelectionList: ...
    def getObjectList(self) -> MSelectionList: ...

class MArgList:
    kInvalidArgIndex: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def addArg(self, *args, **kwargs): ...
    def asAngle(self, index) -> MAngle: ...
    def asBool(self, index) -> bool: ...
    def asDistance(self, index) -> MDistance: ...
    def asDouble(self, index) -> float: ...
    def asDoubleArray(self, index) -> MDoubleArray: ...
    def asFloat(self, index) -> float: ...
    def asInt(self, index) -> int: ...
    def asIntArray(self, index) -> MIntArray: ...
    def asMatrix(self, index) -> MMatrix: ...
    def asPoint(self, index) -> MPoint: ...
    def asString(self, index) -> string: ...  # type: ignore
    def asStringArray(self, index) -> listofstrings: ...  # type: ignore
    def asTime(self, index) -> MTime: ...
    def asVector(self, index) -> MVector: ...
    def flagIndex(self, shortFlag, longFlag=...) -> int: ...
    def lastArgUsed(self) -> int: ...
    def __len__(self) -> int: ...

class MArgParser:
    isEdit: Incomplete
    isQuery: Incomplete
    numberOfFlagsUsed: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def commandArgumentBool(self, argIndex) -> bool: ...
    def commandArgumentDouble(self, *args, **kwargs): ...
    def commandArgumentFloat(self, argIndex) -> float: ...
    def commandArgumentInt(self, argIndex) -> int: ...
    def commandArgumentMAngle(self, argIndex) -> MAngle: ...
    def commandArgumentMDistance(self, argIndex) -> MDistance: ...
    def commandArgumentMTime(self, argIndex) -> MTime: ...
    def commandArgumentString(self, argIndex) -> unicodestring: ...  # type: ignore
    def flagArgumentBool(self, flagName, argIndex) -> bool: ...
    def flagArgumentDouble(self, flagName, argIndex) -> float: ...
    def flagArgumentFloat(self, flagName, argIndex) -> float: ...
    def flagArgumentInt(self, flagName, argIndex) -> int: ...
    def flagArgumentMAngle(self, flagName, argIndex) -> MAngle: ...
    def flagArgumentMDistance(self, flagName, argIndex) -> MDistance: ...
    def flagArgumentMTime(self, flagName, argIndex) -> MTime: ...
    def flagArgumentString(self, flagName, argIndex) -> string: ...  # type: ignore
    def getFlagArgumentList(self, flagName, occurrence) -> MArgList: ...
    def getFlagArgumentPosition(self, flagName, occurrence) -> int: ...
    def getObjectStrings(self) -> tupleofunicodestrings: ...  # type: ignore
    def isFlagSet(self, flagName) -> bool: ...
    def numberOfFlagUses(self, flagName) -> int: ...

class MArrayDataBuilder:
    def __init__(self, *args, **kwargs) -> None: ...
    def addElement(self, index) -> MDataHandle: ...
    def addElementArray(self, index) -> MArrayDataHandle: ...
    def addLast(self) -> MDataHandle: ...
    def addLastArray(self) -> MArrayDataHandle: ...
    def copy(self, source) -> self: ...  # type: ignore
    def growArray(self, amount) -> self: ...  # type: ignore
    def removeElement(self, index) -> self: ...  # type: ignore
    def setGrowSize(self, size) -> self: ...  # type: ignore
    def __len__(self) -> int: ...

class MArrayDataHandle:
    def __init__(self, *args, **kwargs) -> None: ...
    def builder(self) -> MArrayDataBuilder: ...
    def copy(self, source) -> self: ...  # type: ignore
    def elementLogicalIndex(self) -> int: ...
    def inputArrayValue(self) -> MArrayDataHandle: ...
    def inputValue(self) -> MDataHandle: ...
    def isDone(self) -> bool: ...
    def jumpToLogicalElement(self, index) -> self: ...  # type: ignore
    def jumpToPhysicalElement(self, position) -> self: ...  # type: ignore
    def next(self) -> bool: ...
    def outputArrayValue(self) -> MArrayDataHandle: ...
    def outputValue(self) -> MDataHandle: ...
    def set(self, builder) -> self: ...  # type: ignore
    def setAllClean(self) -> self: ...  # type: ignore
    def setClean(self) -> self: ...  # type: ignore
    def __len__(self) -> int: ...

class MAttributeIndex:
    kFloat: ClassVar[int] = ...
    kInteger: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def copy(self, source) -> self: ...  # type: ignore
    def getLower(self, *args, **kwargs): ...
    def getUpper(self, *args, **kwargs): ...
    def getValue(self, *args, **kwargs): ...
    def hasLowerBound(self) -> bool: ...
    def hasRange(self) -> bool: ...
    def hasUpperBound(self) -> bool: ...
    def hasValidRange(self) -> bool: ...
    def isBounded(self) -> bool: ...
    def setLower(self, value) -> self: ...  # type: ignore
    def setType(self, type) -> self: ...  # type: ignore
    def setUpper(self, value) -> self: ...  # type: ignore
    def setValue(self, value) -> self: ...  # type: ignore
    def type(self) -> int: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MAttributePattern:
    def __init__(self, *args, **kwargs) -> None: ...
    def addRootAttr(self, *args, **kwargs): ...
    @staticmethod
    def attrPattern(*args, **kwargs): ...
    @staticmethod
    def attrPatternCount(*args, **kwargs): ...
    @staticmethod
    def findPattern(*args, **kwargs): ...
    def name(self, *args, **kwargs): ...
    def removeRootAttr(self, *args, **kwargs): ...
    def rootAttr(self, *args, **kwargs): ...
    def rootAttrCount(self, *args, **kwargs): ...

class MAttributeSpec:
    dimensions: Incomplete
    name: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def copy(self, source) -> self: ...  # type: ignore
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MAttributeSpecArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MBoundingBox:
    center: Incomplete
    depth: Incomplete
    height: Incomplete
    max: Incomplete
    min: Incomplete
    width: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def clear(self, *args, **kwargs): ...
    def contains(self, *args, **kwargs): ...
    def expand(self, *args, **kwargs): ...
    def intersects(self, *args, **kwargs): ...
    def transformUsing(self, *args, **kwargs): ...

class MCacheSchema:
    def __init__(self, *args, **kwargs) -> None: ...
    def add(self, attribute) -> self: ...  # type: ignore
    def reset(self) -> Any: ...

class MCallbackIdArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MCameraMessage(MMessage):
    @staticmethod
    def addBeginManipulationCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addEndManipulationCallback(node, function, clientData=...) -> id: ...  # type: ignore

class MColor:
    kByte: ClassVar[int] = ...
    kCMY: ClassVar[int] = ...
    kCMYK: ClassVar[int] = ...
    kFloat: ClassVar[int] = ...
    kHSV: ClassVar[int] = ...
    kOpaqueBlack: ClassVar[MColor] = ...
    kRGB: ClassVar[int] = ...
    kShort: ClassVar[int] = ...
    a: Incomplete
    b: Incomplete
    g: Incomplete
    r: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def getColor(self, *args, **kwargs): ...
    def setColor(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __itruediv__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rtruediv__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __truediv__(self, other): ...

class MColorArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MCommandMessage(MMessage):
    kDisplay: ClassVar[int] = ...
    kError: ClassVar[int] = ...
    kHistory: ClassVar[int] = ...
    kInfo: ClassVar[int] = ...
    kMELCommand: ClassVar[int] = ...
    kMELProc: ClassVar[int] = ...
    kResult: ClassVar[int] = ...
    kStackTrace: ClassVar[int] = ...
    kWarning: ClassVar[int] = ...
    @staticmethod
    def addCommandCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addCommandOutputCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addCommandOutputFilterCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addProcCallback(function, clientData=...) -> id: ...  # type: ignore

class MConditionMessage(MMessage):
    @staticmethod
    def addConditionCallback(conditionName, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def getConditionNames(*args, **kwargs): ...
    @staticmethod
    def getConditionState(name) -> bool: ...

class MContainerMessage(MMessage):
    @staticmethod
    def addBoundAttrCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addPublishAttrCallback(function, clientData=...) -> id: ...  # type: ignore

class MDAGDrawOverrideInfo:
    kDisplayTypeNormal: ClassVar[int] = ...
    kDisplayTypeReference: ClassVar[int] = ...
    kDisplayTypeTemplate: ClassVar[int] = ...
    kLODBoundingBox: ClassVar[int] = ...
    kLODFull: ClassVar[int] = ...
    displayType: Incomplete
    enableShading: Incomplete
    enableTexturing: Incomplete
    enableVisible: Incomplete
    lod: Incomplete
    overrideEnabled: Incomplete
    playbackVisible: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...

class MDGContext:
    kNormal: ClassVar[MDGContext] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def copy(self, source) -> self: ...  # type: ignore
    @staticmethod
    def current(*args, **kwargs): ...
    def getTime(self, *args, **kwargs): ...
    def isCurrent(self, *args, **kwargs): ...
    def isNormal(self, *args, **kwargs): ...
    def makeCurrent(self, *args, **kwargs): ...

class MDGMessage(MMessage):
    @staticmethod
    def addConnectionCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addDelayedTimeChangeCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addDelayedTimeChangeRunupCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addForceUpdateCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeAddedCallback(function, nodeType, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeChangeUuidCheckCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeRemovedCallback(function, nodeType, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addPreConnectionCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addTimeChangeCallback(function, clientData=...) -> id: ...  # type: ignore

class MDGModifier:
    def __init__(self, *args, **kwargs) -> None: ...
    def addAttribute(self, MObjectnode, MObjectattribute) -> self: ...  # type: ignore
    def addExtensionAttribute(self, MNodeClassnodeClass, MObjectattribute) -> self: ...  # type: ignore
    @overload
    def commandToExecute(self, command) -> self: ...  # type: ignore
    @overload
    def commandToExecute(self) -> Any: ...
    @overload
    def commandToExecute(self) -> Any: ...  # type: ignore
    def connect(self, MPlugsource, MPlugdest) -> self: ...  # type: ignore
    @overload
    def createNode(self, typeName) -> MObject: ...
    @overload
    def createNode(self, MTypeIdtypeId) -> MObject: ...
    @overload
    def deleteNode(self) -> Any: ...
    @overload
    def deleteNode(self) -> Any: ...  # type: ignore
    def disconnect(self, MPlugsource, MPlugdest) -> self: ...  # type: ignore
    @overload
    def doIt(self) -> self: ...  # type: ignore
    @overload
    def doIt(self) -> Any: ...  # type: ignore
    @overload
    def doIt(self) -> Any: ...  # type: ignore
    @overload
    def doIt(self) -> Any: ...  # type: ignore
    def linkExtensionAttributeToPlugin(self, MObjectplugin, MObjectattribute) -> self: ...  # type: ignore
    def newPlugValue(self, MPlugplug, MObjectvalue) -> self: ...  # type: ignore
    def newPlugValueBool(self, MPlugplug, boolvalue) -> self: ...  # type: ignore
    def newPlugValueChar(self, MPlugplug, intvalue) -> self: ...  # type: ignore
    def newPlugValueDouble(self, MPlugplug, floatvalue) -> self: ...  # type: ignore
    def newPlugValueFloat(self, MPlugplug, floatvalue) -> self: ...  # type: ignore
    def newPlugValueInt(self, MPlugplug, intvalue) -> self: ...  # type: ignore
    def newPlugValueMAngle(self, MPlugplug, MAnglevalue) -> self: ...  # type: ignore
    def newPlugValueMDistance(self, MPlugplug, MDistancevalue) -> self: ...  # type: ignore
    def newPlugValueMTime(self, MPlugplug, MTimevalue) -> self: ...  # type: ignore
    def newPlugValueShort(self, MPlugplug, intvalue) -> self: ...  # type: ignore
    def newPlugValueString(self, MPlugplug, stringvalue) -> self: ...  # type: ignore
    def pythonCommandToExecute(self) -> Any: ...
    def removeAttribute(self, MObjectnode, MObjectattribute) -> self: ...  # type: ignore
    def removeExtensionAttribute(self, MNodeClassnodeClass, MObjectattribute) -> self: ...  # type: ignore
    def removeExtensionAttributeIfUnset(self, *args, **kwargs): ...
    def removeMultiInstance(self, MPlugplug, boolbreakConnections) -> self: ...  # type: ignore
    def renameAttribute(self, *args, **kwargs): ...
    def renameNode(self, MObjectnode, stringnewName) -> self: ...  # type: ignore
    def setNodeLockState(self, MObjectnode, boolnewState) -> self: ...  # type: ignore
    def undoIt(self) -> self: ...  # type: ignore
    def unlinkExtensionAttributeFromPlugin(self, *args, **kwargs): ...

class MDagMessage(MMessage):
    kAll: ClassVar[int] = ...
    kChildAdded: ClassVar[int] = ...
    kChildRemoved: ClassVar[int] = ...
    kChildReordered: ClassVar[int] = ...
    kInstanceAdded: ClassVar[int] = ...
    kInstanceRemoved: ClassVar[int] = ...
    kInvalidMsg: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kParentAdded: ClassVar[int] = ...
    kParentRemoved: ClassVar[int] = ...
    kRotateOrder: ClassVar[int] = ...
    kRotateOrient: ClassVar[int] = ...
    kRotateOrientX: ClassVar[int] = ...
    kRotateOrientY: ClassVar[int] = ...
    kRotateOrientZ: ClassVar[int] = ...
    kRotatePivot: ClassVar[int] = ...
    kRotatePivotTrans: ClassVar[int] = ...
    kRotatePivotX: ClassVar[int] = ...
    kRotatePivotY: ClassVar[int] = ...
    kRotatePivotZ: ClassVar[int] = ...
    kRotateTransX: ClassVar[int] = ...
    kRotateTransY: ClassVar[int] = ...
    kRotateTransZ: ClassVar[int] = ...
    kRotateX: ClassVar[int] = ...
    kRotateY: ClassVar[int] = ...
    kRotateZ: ClassVar[int] = ...
    kRotation: ClassVar[int] = ...
    kScale: ClassVar[int] = ...
    kScalePivot: ClassVar[int] = ...
    kScalePivotTrans: ClassVar[int] = ...
    kScalePivotX: ClassVar[int] = ...
    kScalePivotY: ClassVar[int] = ...
    kScalePivotZ: ClassVar[int] = ...
    kScaleTransX: ClassVar[int] = ...
    kScaleTransY: ClassVar[int] = ...
    kScaleTransZ: ClassVar[int] = ...
    kScaleX: ClassVar[int] = ...
    kScaleY: ClassVar[int] = ...
    kScaleZ: ClassVar[int] = ...
    kShear: ClassVar[int] = ...
    kShearXY: ClassVar[int] = ...
    kShearXZ: ClassVar[int] = ...
    kShearYZ: ClassVar[int] = ...
    kTranslateX: ClassVar[int] = ...
    kTranslateY: ClassVar[int] = ...
    kTranslateZ: ClassVar[int] = ...
    kTranslation: ClassVar[int] = ...
    @staticmethod
    def addAllDagChangesCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addAllDagChangesDagPathCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addChildAddedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addChildAddedDagPathCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addChildRemovedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addChildRemovedDagPathCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addChildReorderedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addChildReorderedDagPathCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addDagCallback(msgType, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addDagDagPathCallback(node, msgType, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addInstanceAddedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addInstanceAddedDagPathCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addInstanceRemovedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addInstanceRemovedDagPathCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addMatrixModifiedCallback(*args, **kwargs): ...
    @staticmethod
    def addParentAddedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addParentAddedDagPathCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addParentRemovedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addParentRemovedDagPathCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addWorldMatrixModifiedCallback(*args, **kwargs): ...

class MDagModifier(MDGModifier):
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def createNode(self, typeName, parent=...) -> newDAGnodeMObject: ...  # type: ignore
    @overload
    def createNode(self, typeId, parent=...) -> newDAGnodeMObject: ...  # type: ignore
    def reparentNode(self, MObjectnode, newParent=...) -> self: ...  # type: ignore

class MDagPath:
    def __init__(self, *args, **kwargs) -> None: ...
    def apiType(self, *args, **kwargs): ...
    def child(self, *args, **kwargs): ...
    def childCount(self, *args, **kwargs): ...
    def exclusiveMatrix(self, *args, **kwargs): ...
    def exclusiveMatrixInverse(self, *args, **kwargs): ...
    def extendToShape(self, *args, **kwargs): ...
    def fullPathName(self, *args, **kwargs): ...
    @staticmethod
    def getAPathTo(*args, **kwargs): ...
    @staticmethod
    def getAllPathsTo(*args, **kwargs): ...
    def getDisplayStatus(self, *args, **kwargs): ...
    def getDrawOverrideInfo(self, *args, **kwargs): ...
    def getPath(self, *args, **kwargs): ...
    def hasFn(self, *args, **kwargs): ...
    def inclusiveMatrix(self, *args, **kwargs): ...
    def inclusiveMatrixInverse(self, *args, **kwargs): ...
    def instanceNumber(self, *args, **kwargs): ...
    def isInstanced(self, *args, **kwargs): ...
    def isTemplated(self, *args, **kwargs): ...
    def isValid(self, *args, **kwargs): ...
    def isVisible(self, *args, **kwargs): ...
    def length(self, *args, **kwargs): ...
    @staticmethod
    def matchTransform(*args, **kwargs): ...
    def node(self, *args, **kwargs): ...
    def numberOfShapesDirectlyBelow(self, *args, **kwargs): ...
    def partialPathName(self, *args, **kwargs): ...
    def pathCount(self, *args, **kwargs): ...
    def pop(self, *args, **kwargs): ...
    def push(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def transform(self, *args, **kwargs): ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MDagPathArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MDataBlock:
    def __init__(self, *args, **kwargs) -> None: ...
    def context(self) -> MDGContext: ...
    @overload
    def inputArrayValue(self, plug) -> MArrayDataHandle: ...
    @overload
    def inputArrayValue(self, attribute) -> MArrayDataHandle: ...
    @overload
    def inputValue(self, plug) -> MDataHandle: ...
    @overload
    def inputValue(self, attribute) -> MDataHandle: ...
    @overload
    def isClean(self, plug) -> bool: ...
    @overload
    def isClean(self, attribute) -> bool: ...
    @overload
    def outputArrayValue(self, plug) -> MArrayDataHandle: ...
    @overload
    def outputArrayValue(self, attribute) -> MArrayDataHandle: ...
    @overload
    def outputValue(self, plug) -> MDataHandle: ...
    @overload
    def outputValue(self, attribute) -> MDataHandle: ...
    @overload
    def setClean(self, plug) -> self: ...  # type: ignore
    @overload
    def setClean(self, attribute) -> self: ...  # type: ignore
    def setContext(self, ctx) -> self: ...  # type: ignore

class MDataHandle:
    def __init__(self, *args, **kwargs) -> None: ...
    def acceptedTypeIds(self) -> arrayofMTypeIds: ...  # type: ignore
    def asAddr(self) -> long: ...  # type: ignore
    def asAngle(self) -> MAngle: ...
    def asBool(self) -> bool: ...
    def asChar(self) -> int: ...
    def asDistance(self) -> MDistance: ...
    def asDouble(self) -> float: ...
    def asDouble2(self, *args, **kwargs): ...
    def asDouble3(self, *args, **kwargs): ...
    def asDouble4(self, *args, **kwargs): ...
    def asFloat(self) -> float: ...
    def asFloat2(self, *args, **kwargs): ...
    def asFloat3(self, *args, **kwargs): ...
    def asFloatMatrix(self) -> MFloatMatrix: ...
    def asFloatVector(self) -> MFloatVector: ...
    def asGenericBool(self) -> bool: ...
    def asGenericChar(self) -> int: ...
    def asGenericDouble(self) -> float: ...
    def asGenericFloat(self) -> float: ...
    def asGenericInt(self) -> int: ...
    def asGenericShort(self) -> int: ...
    def asInt(self) -> int: ...
    def asInt2(self, *args, **kwargs): ...
    def asInt3(self, *args, **kwargs): ...
    def asMatrix(self) -> MMatrix: ...
    def asMesh(self) -> MObject: ...
    def asMeshTransformed(self) -> MObject: ...
    def asNurbsCurve(self) -> MObject: ...
    def asNurbsCurveTransformed(self) -> MObject: ...
    def asNurbsSurface(self) -> MObject: ...
    def asNurbsSurfaceTransformed(self) -> MObject: ...
    def asPluginData(self) -> MPxData: ...
    def asShort(self) -> int: ...
    def asShort2(self, *args, **kwargs): ...
    def asShort3(self, *args, **kwargs): ...
    def asString(self) -> MString: ...  # type: ignore
    def asSubdSurface(self) -> MObject: ...
    def asSubdSurfaceTransformed(self) -> MObject: ...
    def asTime(self) -> MTime: ...
    def asUChar(self) -> int: ...
    def asVector(self) -> MVector: ...
    @overload
    def child(self, MPlug) -> MDataHandle: ...
    @overload
    def child(self, MObject) -> MDataHandle: ...
    def copy(self, src) -> self: ...  # type: ignore
    def copyWritable(self, src) -> self: ...  # type: ignore
    def data(self) -> MObject: ...
    def datablock(self) -> MDataBlock: ...
    def geometryTransformMatrix(self) -> MMatrix: ...
    def isGeneric(self, *args, **kwargs): ...
    def isNumeric(self) -> bool: ...
    def numericType(self) -> int: ...
    def set2Double(self, *args, **kwargs): ...
    def set2Float(self, *args, **kwargs): ...
    def set2Int(self, *args, **kwargs): ...
    def set2Short(self, *args, **kwargs): ...
    def set3Double(self, *args, **kwargs): ...
    def set3Float(self, *args, **kwargs): ...
    def set3Int(self, *args, **kwargs): ...
    def set3Short(self, *args, **kwargs): ...
    def set4Double(self, *args, **kwargs): ...
    def setBool(self, bool) -> self: ...  # type: ignore
    def setChar(self, int) -> self: ...  # type: ignore
    def setClean(self) -> self: ...  # type: ignore
    def setDouble(self, float) -> self: ...  # type: ignore
    def setFloat(self, float) -> self: ...  # type: ignore
    def setGenericBool(self, bool, force) -> self: ...  # type: ignore
    def setGenericChar(self, int, force) -> self: ...  # type: ignore
    def setGenericDouble(self, float, force) -> self: ...  # type: ignore
    def setGenericFloat(self, float, force) -> self: ...  # type: ignore
    def setGenericInt(self, int, force) -> self: ...  # type: ignore
    def setGenericShort(self, int, force) -> self: ...  # type: ignore
    def setInt(self, int) -> self: ...  # type: ignore
    def setMAngle(self, MAngle) -> self: ...  # type: ignore
    def setMDistance(self, MDistance) -> self: ...  # type: ignore
    def setMFloatMatrix(self, MFloatMatrix) -> self: ...  # type: ignore
    def setMFloatVector(self, MFloatVector) -> self: ...  # type: ignore
    def setMMatrix(self, MMatrix) -> self: ...  # type: ignore
    def setMObject(self, MObject) -> self: ...  # type: ignore
    def setMPxData(self, MPxData) -> self: ...  # type: ignore
    def setMTime(self, MTime) -> self: ...  # type: ignore
    def setMVector(self, MVector) -> self: ...  # type: ignore
    def setShort(self, int) -> self: ...  # type: ignore
    def setString(self, string) -> self: ...  # type: ignore
    def type(self) -> int: ...
    def typeId(self) -> MTypeId: ...

class MDistance:
    kCentimeters: ClassVar[int] = ...
    kFeet: ClassVar[int] = ...
    kInches: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kKilometers: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kMeters: ClassVar[int] = ...
    kMiles: ClassVar[int] = ...
    kMillimeters: ClassVar[int] = ...
    kYards: ClassVar[int] = ...
    unit: Incomplete
    value: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def asCentimeters(self, *args, **kwargs): ...
    def asFeet(self, *args, **kwargs): ...
    def asInches(self, *args, **kwargs): ...
    def asKilometers(self, *args, **kwargs): ...
    def asMeters(self, *args, **kwargs): ...
    def asMiles(self, *args, **kwargs): ...
    def asMillimeters(self, *args, **kwargs): ...
    def asUnits(self, *args, **kwargs): ...
    def asYards(self, *args, **kwargs): ...
    @staticmethod
    def internalToUI(*args, **kwargs): ...
    @staticmethod
    def internalUnit(*args, **kwargs): ...
    @staticmethod
    def setUIUnit(*args, **kwargs): ...
    @staticmethod
    def uiToInternal(*args, **kwargs): ...
    @staticmethod
    def uiUnit(*args, **kwargs): ...

class MDoubleArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MEulerRotation:
    kIdentity: ClassVar[MEulerRotation] = ...
    kTolerance: ClassVar[float] = ...
    kXYZ: ClassVar[int] = ...
    kXZY: ClassVar[int] = ...
    kYXZ: ClassVar[int] = ...
    kYZX: ClassVar[int] = ...
    kZXY: ClassVar[int] = ...
    kZYX: ClassVar[int] = ...
    order: Incomplete
    x: Incomplete
    y: Incomplete
    z: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def alternateSolution(self, *args, **kwargs): ...
    def asMatrix(self, *args, **kwargs): ...
    def asQuaternion(self, *args, **kwargs): ...
    def asVector(self, *args, **kwargs): ...
    def bound(self, *args, **kwargs): ...
    def boundIt(self, *args, **kwargs): ...
    def closestCut(self, *args, **kwargs): ...
    def closestSolution(self, *args, **kwargs): ...
    @staticmethod
    def computeAlternateSolution(*args, **kwargs): ...
    @staticmethod
    def computeBound(*args, **kwargs): ...
    @staticmethod
    def computeClosestCut(*args, **kwargs): ...
    @staticmethod
    def computeClosestSolution(*args, **kwargs): ...
    @staticmethod
    def decompose(*args, **kwargs): ...
    def incrementalRotateBy(self, *args, **kwargs): ...
    def inverse(self, *args, **kwargs): ...
    def invertIt(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def isZero(self, *args, **kwargs): ...
    def reorder(self, *args, **kwargs): ...
    def reorderIt(self, *args, **kwargs): ...
    def setToAlternateSolution(self, *args, **kwargs): ...
    def setToClosestCut(self, *args, **kwargs): ...
    def setToClosestSolution(self, *args, **kwargs): ...
    def setValue(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __isub__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __neg__(self): ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __sub__(self, other): ...

class MEvaluationNode:
    def __init__(self, *args, **kwargs) -> None: ...
    def datablock(self, *args, **kwargs): ...
    def dependencyNode(self, *args, **kwargs): ...
    def dirtyPlug(self, *args, **kwargs): ...
    def dirtyPlugExists(self, *args, **kwargs): ...
    def iterator(self, *args, **kwargs): ...

class MEvaluationNodeIterator:
    def __init__(self, *args, **kwargs) -> None: ...
    def isDone(self, *args, **kwargs): ...
    def next(self, *args, **kwargs): ...
    def plug(self, *args, **kwargs): ...
    def reset(self, *args, **kwargs): ...

class MEventMessage(MMessage):
    @staticmethod
    def addEventCallback(eventName, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def getEventNames(*args, **kwargs): ...

class MExternalContentInfoTable:
    def __init__(self, *args, **kwargs) -> None: ...
    def addResolvedEntry(self, key, unresolvedLocation, resolvedLocation, contextNodeFullName, roles) -> self: ...  # type: ignore
    def addUnresolvedEntry(self, key, unresolvedLocation, contextNodeFullName, roles=...) -> self: ...  # type: ignore
    def getEntry(self, *args, **kwargs): ...
    def getInfo(self, *args, **kwargs): ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...

class MExternalContentLocationTable:
    def __init__(self, *args, **kwargs) -> None: ...
    def addEntry(self, key, location) -> self: ...  # type: ignore
    def getEntry(self, *args, **kwargs): ...
    def getLocation(self, key) -> string: ...  # type: ignore
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...

class MFileObject:
    kBaseName: ClassVar[int] = ...
    kDirMap: ClassVar[int] = ...
    kExact: ClassVar[int] = ...
    kInputFile: ClassVar[int] = ...
    kInputReference: ClassVar[int] = ...
    kNone: ClassVar[int] = ...
    kReferenceMappings: ClassVar[int] = ...
    kRelative: ClassVar[int] = ...
    kStrict: ClassVar[int] = ...
    resolveMethod: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def copy(self, source) -> self: ...  # type: ignore
    def exists(self, index=...) -> bool: ...
    def expandedFullName(self) -> string: ...  # type: ignore
    def expandedPath(self) -> string: ...  # type: ignore
    def fullName(self, index) -> string: ...  # type: ignore
    @staticmethod
    def getResolvedFullName(rawFullName) -> string: ...  # type: ignore
    @staticmethod
    def getResolvedFullNameAndExistsStatus(*args, **kwargs): ...
    @staticmethod
    def isAbsolutePath(fileName) -> bool: ...
    def isSet(self) -> bool: ...
    def overrideResolvedFullName(self, fullFileName, reresolveType=...) -> self: ...  # type: ignore
    def path(self, index) -> string: ...  # type: ignore
    def pathCount(self) -> int: ...
    def rawFullName(self) -> string: ...  # type: ignore
    def rawName(self) -> string: ...  # type: ignore
    def rawPath(self) -> string: ...  # type: ignore
    def rawURI(self) -> MURI: ...
    def resolvedFullName(self) -> string: ...  # type: ignore
    def resolvedName(self) -> string: ...  # type: ignore
    def resolvedPath(self) -> string: ...  # type: ignore
    def setRawFullName(self, fullFileName) -> self: ...  # type: ignore
    def setRawName(self, fileName) -> self: ...  # type: ignore
    def setRawPath(self, pathName) -> self: ...  # type: ignore
    def setRawURI(self, uri) -> self: ...  # type: ignore

class MFloatArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MFloatMatrix:
    kTolerance: ClassVar[float] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def adjoint(self, *args, **kwargs): ...
    def det3x3(self, *args, **kwargs): ...
    def det4x4(self, *args, **kwargs): ...
    def getElement(self, *args, **kwargs): ...
    def homogenize(self, *args, **kwargs): ...
    def inverse(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def setElement(self, *args, **kwargs): ...
    def setToIdentity(self, *args, **kwargs): ...
    def setToProduct(self, *args, **kwargs): ...
    def transpose(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __isub__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __sub__(self, other): ...

class MFloatPoint:
    kOrigin: ClassVar[MFloatPoint] = ...
    kTolerance: ClassVar[float] = ...
    w: Incomplete
    x: Incomplete
    y: Incomplete
    z: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def cartesianize(self, *args, **kwargs): ...
    def distanceTo(self, *args, **kwargs): ...
    def homogenize(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def rationalize(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __isub__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __rtruediv__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __sub__(self, other): ...
    def __truediv__(self, other): ...

class MFloatPointArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MFloatVector:
    kOneVector: ClassVar[MFloatVector] = ...
    kTolerance: ClassVar[float] = ...
    kXaxisVector: ClassVar[MFloatVector] = ...
    kXnegAxisVector: ClassVar[MFloatVector] = ...
    kYaxisVector: ClassVar[MFloatVector] = ...
    kYnegAxisVector: ClassVar[MFloatVector] = ...
    kZaxisVector: ClassVar[MFloatVector] = ...
    kZeroVector: ClassVar[MFloatVector] = ...
    kZnegAxisVector: ClassVar[MFloatVector] = ...
    x: Incomplete
    y: Incomplete
    z: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def angle(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def isParallel(self, *args, **kwargs): ...
    def length(self, *args, **kwargs): ...
    def normal(self, *args, **kwargs): ...
    def normalize(self, *args, **kwargs): ...
    def transformAsNormal(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __isub__(self, other): ...
    def __itruediv__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __neg__(self): ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __rtruediv__(self, other): ...
    def __rxor__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __sub__(self, other): ...
    def __truediv__(self, other): ...
    def __xor__(self, other): ...

class MFloatVectorArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MFn:
    kACos: ClassVar[int] = ...
    kAISEnvFacade: ClassVar[int] = ...
    kASin: ClassVar[int] = ...
    kATan: ClassVar[int] = ...
    kATan2: ClassVar[int] = ...
    kAbsolute: ClassVar[int] = ...
    kAddDoubleLinear: ClassVar[int] = ...
    kAdskMaterial: ClassVar[int] = ...
    kAffect: ClassVar[int] = ...
    kAimConstraint: ClassVar[int] = ...
    kAimMatrix: ClassVar[int] = ...
    kAir: ClassVar[int] = ...
    kAlignCurve: ClassVar[int] = ...
    kAlignManip: ClassVar[int] = ...
    kAlignSurface: ClassVar[int] = ...
    kAmbientLight: ClassVar[int] = ...
    kAnd: ClassVar[int] = ...
    kAngle: ClassVar[int] = ...
    kAngleBetween: ClassVar[int] = ...
    kAngleToDoubleNode: ClassVar[int] = ...
    kAnimBlend: ClassVar[int] = ...
    kAnimBlendInOut: ClassVar[int] = ...
    kAnimCurve: ClassVar[int] = ...
    kAnimCurveTimeToAngular: ClassVar[int] = ...
    kAnimCurveTimeToDistance: ClassVar[int] = ...
    kAnimCurveTimeToTime: ClassVar[int] = ...
    kAnimCurveTimeToUnitless: ClassVar[int] = ...
    kAnimCurveUnitlessToAngular: ClassVar[int] = ...
    kAnimCurveUnitlessToDistance: ClassVar[int] = ...
    kAnimCurveUnitlessToTime: ClassVar[int] = ...
    kAnimCurveUnitlessToUnitless: ClassVar[int] = ...
    kAnimLayer: ClassVar[int] = ...
    kAnisotropy: ClassVar[int] = ...
    kAnnotation: ClassVar[int] = ...
    kAnyGeometryVarGroup: ClassVar[int] = ...
    kArcLength: ClassVar[int] = ...
    kAreaLight: ClassVar[int] = ...
    kArrayMapper: ClassVar[int] = ...
    kArrowManip: ClassVar[int] = ...
    kArubaTesselate: ClassVar[int] = ...
    kAssembly: ClassVar[int] = ...
    kAsset: ClassVar[int] = ...
    kAttachCurve: ClassVar[int] = ...
    kAttachSurface: ClassVar[int] = ...
    kAttribute: ClassVar[int] = ...
    kAttribute2Double: ClassVar[int] = ...
    kAttribute2Float: ClassVar[int] = ...
    kAttribute2Int: ClassVar[int] = ...
    kAttribute2Short: ClassVar[int] = ...
    kAttribute3Double: ClassVar[int] = ...
    kAttribute3Float: ClassVar[int] = ...
    kAttribute3Int: ClassVar[int] = ...
    kAttribute3Short: ClassVar[int] = ...
    kAttribute4Double: ClassVar[int] = ...
    kAudio: ClassVar[int] = ...
    kAverage: ClassVar[int] = ...
    kAverageCurveManip: ClassVar[int] = ...
    kAvgCurves: ClassVar[int] = ...
    kAvgNurbsSurfacePoints: ClassVar[int] = ...
    kAvgSurfacePoints: ClassVar[int] = ...
    kAxesActionManip: ClassVar[int] = ...
    kAxisFromMatrix: ClassVar[int] = ...
    kBackground: ClassVar[int] = ...
    kBallProjectionManip: ClassVar[int] = ...
    kBarnDoorManip: ClassVar[int] = ...
    kBase: ClassVar[int] = ...
    kBaseLattice: ClassVar[int] = ...
    kBendLattice: ClassVar[int] = ...
    kBevel: ClassVar[int] = ...
    kBevelManip: ClassVar[int] = ...
    kBevelPlus: ClassVar[int] = ...
    kBezierCurve: ClassVar[int] = ...
    kBezierCurveData: ClassVar[int] = ...
    kBezierCurveToNurbs: ClassVar[int] = ...
    kBinaryData: ClassVar[int] = ...
    kBirailSrf: ClassVar[int] = ...
    kBlend: ClassVar[int] = ...
    kBlendColorSet: ClassVar[int] = ...
    kBlendColors: ClassVar[int] = ...
    kBlendDevice: ClassVar[int] = ...
    kBlendFalloff: ClassVar[int] = ...
    kBlendManip: ClassVar[int] = ...
    kBlendMatrix: ClassVar[int] = ...
    kBlendNodeAdditiveRotation: ClassVar[int] = ...
    kBlendNodeAdditiveScale: ClassVar[int] = ...
    kBlendNodeBase: ClassVar[int] = ...
    kBlendNodeBoolean: ClassVar[int] = ...
    kBlendNodeDouble: ClassVar[int] = ...
    kBlendNodeDoubleAngle: ClassVar[int] = ...
    kBlendNodeDoubleLinear: ClassVar[int] = ...
    kBlendNodeEnum: ClassVar[int] = ...
    kBlendNodeFloat: ClassVar[int] = ...
    kBlendNodeFloatAngle: ClassVar[int] = ...
    kBlendNodeFloatLinear: ClassVar[int] = ...
    kBlendNodeInt16: ClassVar[int] = ...
    kBlendNodeInt32: ClassVar[int] = ...
    kBlendNodeTime: ClassVar[int] = ...
    kBlendShape: ClassVar[int] = ...
    kBlendTwoAttr: ClassVar[int] = ...
    kBlendWeighted: ClassVar[int] = ...
    kBlindData: ClassVar[int] = ...
    kBlindDataTemplate: ClassVar[int] = ...
    kBlinn: ClassVar[int] = ...
    kBlinnMaterial: ClassVar[int] = ...
    kBoundary: ClassVar[int] = ...
    kBox: ClassVar[int] = ...
    kBoxData: ClassVar[int] = ...
    kBrownian: ClassVar[int] = ...
    kBrush: ClassVar[int] = ...
    kBulge: ClassVar[int] = ...
    kBulgeLattice: ClassVar[int] = ...
    kBump: ClassVar[int] = ...
    kBump3d: ClassVar[int] = ...
    kButtonManip: ClassVar[int] = ...
    kCacheBase: ClassVar[int] = ...
    kCacheBlend: ClassVar[int] = ...
    kCacheFile: ClassVar[int] = ...
    kCacheTrack: ClassVar[int] = ...
    kCacheableNode: ClassVar[int] = ...
    kCaddyManipBase: ClassVar[int] = ...
    kCamera: ClassVar[int] = ...
    kCameraManip: ClassVar[int] = ...
    kCameraPlaneManip: ClassVar[int] = ...
    kCameraSet: ClassVar[int] = ...
    kCameraView: ClassVar[int] = ...
    kCeil: ClassVar[int] = ...
    kCenterManip: ClassVar[int] = ...
    kChainToSpline: ClassVar[int] = ...
    kCharacter: ClassVar[int] = ...
    kCharacterMap: ClassVar[int] = ...
    kCharacterMappingData: ClassVar[int] = ...
    kCharacterOffset: ClassVar[int] = ...
    kChecker: ClassVar[int] = ...
    kChoice: ClassVar[int] = ...
    kChooser: ClassVar[int] = ...
    kCircle: ClassVar[int] = ...
    kCircleManip: ClassVar[int] = ...
    kCirclePointManip: ClassVar[int] = ...
    kCircleSweepManip: ClassVar[int] = ...
    kClampColor: ClassVar[int] = ...
    kClampRange: ClassVar[int] = ...
    kClientDevice: ClassVar[int] = ...
    kClip: ClassVar[int] = ...
    kClipGhostShape: ClassVar[int] = ...
    kClipLibrary: ClassVar[int] = ...
    kClipScheduler: ClassVar[int] = ...
    kClipToGhostData: ClassVar[int] = ...
    kCloseCurve: ClassVar[int] = ...
    kCloseSurface: ClassVar[int] = ...
    kClosestPointOnMesh: ClassVar[int] = ...
    kClosestPointOnSurface: ClassVar[int] = ...
    kCloth: ClassVar[int] = ...
    kCloud: ClassVar[int] = ...
    kCluster: ClassVar[int] = ...
    kClusterFilter: ClassVar[int] = ...
    kClusterFlexor: ClassVar[int] = ...
    kCoiManip: ClassVar[int] = ...
    kCollision: ClassVar[int] = ...
    kColorBackground: ClassVar[int] = ...
    kColorMgtGlobals: ClassVar[int] = ...
    kColorProfile: ClassVar[int] = ...
    kColumnFromMatrix: ClassVar[int] = ...
    kCombinationShape: ClassVar[int] = ...
    kCommCornerManip: ClassVar[int] = ...
    kCommCornerOperManip: ClassVar[int] = ...
    kCommEdgeOperManip: ClassVar[int] = ...
    kCommEdgePtManip: ClassVar[int] = ...
    kCommEdgeSegmentManip: ClassVar[int] = ...
    kComponent: ClassVar[int] = ...
    kComponentFalloff: ClassVar[int] = ...
    kComponentListData: ClassVar[int] = ...
    kComponentManip: ClassVar[int] = ...
    kComponentMatch: ClassVar[int] = ...
    kComposeMatrix: ClassVar[int] = ...
    kCompoundAttribute: ClassVar[int] = ...
    kConcentricProjectionManip: ClassVar[int] = ...
    kCondition: ClassVar[int] = ...
    kCone: ClassVar[int] = ...
    kConstraint: ClassVar[int] = ...
    kContainer: ClassVar[int] = ...
    kContainerBase: ClassVar[int] = ...
    kContourProjectionManip: ClassVar[int] = ...
    kContrast: ClassVar[int] = ...
    kControl: ClassVar[int] = ...
    kControllerTag: ClassVar[int] = ...
    kCopyColorSet: ClassVar[int] = ...
    kCopyUVSet: ClassVar[int] = ...
    kCos: ClassVar[int] = ...
    kCpManip: ClassVar[int] = ...
    kCrater: ClassVar[int] = ...
    kCreaseSet: ClassVar[int] = ...
    kCreate: ClassVar[int] = ...
    kCreateBPManip: ClassVar[int] = ...
    kCreateBezierManip: ClassVar[int] = ...
    kCreateCVManip: ClassVar[int] = ...
    kCreateColorSet: ClassVar[int] = ...
    kCreateEPManip: ClassVar[int] = ...
    kCreateSectionManip: ClassVar[int] = ...
    kCreateUVSet: ClassVar[int] = ...
    kCrossProduct: ClassVar[int] = ...
    kCrossSectionEditManip: ClassVar[int] = ...
    kCrossSectionManager: ClassVar[int] = ...
    kCubicProjectionManip: ClassVar[int] = ...
    kCurve: ClassVar[int] = ...
    kCurveCVComponent: ClassVar[int] = ...
    kCurveCurveIntersect: ClassVar[int] = ...
    kCurveEPComponent: ClassVar[int] = ...
    kCurveEdManip: ClassVar[int] = ...
    kCurveFromMeshCoM: ClassVar[int] = ...
    kCurveFromMeshEdge: ClassVar[int] = ...
    kCurveFromSubdivEdge: ClassVar[int] = ...
    kCurveFromSubdivFace: ClassVar[int] = ...
    kCurveFromSurface: ClassVar[int] = ...
    kCurveFromSurfaceBnd: ClassVar[int] = ...
    kCurveFromSurfaceCoS: ClassVar[int] = ...
    kCurveFromSurfaceIso: ClassVar[int] = ...
    kCurveInfo: ClassVar[int] = ...
    kCurveKnotComponent: ClassVar[int] = ...
    kCurveNormalizerAngle: ClassVar[int] = ...
    kCurveNormalizerLinear: ClassVar[int] = ...
    kCurveParamComponent: ClassVar[int] = ...
    kCurveSegmentManip: ClassVar[int] = ...
    kCurveVarGroup: ClassVar[int] = ...
    kCustomEvaluatorClusterNode: ClassVar[int] = ...
    kCylinder: ClassVar[int] = ...
    kCylindricalProjectionManip: ClassVar[int] = ...
    kDOF: ClassVar[int] = ...
    kDPbirailSrf: ClassVar[int] = ...
    kDagContainer: ClassVar[int] = ...
    kDagNode: ClassVar[int] = ...
    kDagPose: ClassVar[int] = ...
    kDagSelectionItem: ClassVar[int] = ...
    kData: ClassVar[int] = ...
    kData2Double: ClassVar[int] = ...
    kData2Float: ClassVar[int] = ...
    kData2Int: ClassVar[int] = ...
    kData2Short: ClassVar[int] = ...
    kData3Double: ClassVar[int] = ...
    kData3Float: ClassVar[int] = ...
    kData3Int: ClassVar[int] = ...
    kData3Short: ClassVar[int] = ...
    kData4Double: ClassVar[int] = ...
    kDblTrsManip: ClassVar[int] = ...
    kDecayRegionCapComponent: ClassVar[int] = ...
    kDecayRegionComponent: ClassVar[int] = ...
    kDecomposeMatrix: ClassVar[int] = ...
    kDefaultLightList: ClassVar[int] = ...
    kDeformBend: ClassVar[int] = ...
    kDeformBendManip: ClassVar[int] = ...
    kDeformFlare: ClassVar[int] = ...
    kDeformFlareManip: ClassVar[int] = ...
    kDeformFunc: ClassVar[int] = ...
    kDeformSine: ClassVar[int] = ...
    kDeformSineManip: ClassVar[int] = ...
    kDeformSquash: ClassVar[int] = ...
    kDeformSquashManip: ClassVar[int] = ...
    kDeformTwist: ClassVar[int] = ...
    kDeformTwistManip: ClassVar[int] = ...
    kDeformWave: ClassVar[int] = ...
    kDeformWaveManip: ClassVar[int] = ...
    kDeleteColorSet: ClassVar[int] = ...
    kDeleteComponent: ClassVar[int] = ...
    kDeleteUVSet: ClassVar[int] = ...
    kDeltaMush: ClassVar[int] = ...
    kDependencyNode: ClassVar[int] = ...
    kDetachCurve: ClassVar[int] = ...
    kDetachSurface: ClassVar[int] = ...
    kDeterminant: ClassVar[int] = ...
    kDiffuseMaterial: ClassVar[int] = ...
    kDimension: ClassVar[int] = ...
    kDimensionManip: ClassVar[int] = ...
    kDirectedDisc: ClassVar[int] = ...
    kDirectionManip: ClassVar[int] = ...
    kDirectionalLight: ClassVar[int] = ...
    kDiscManip: ClassVar[int] = ...
    kDiskCache: ClassVar[int] = ...
    kDispatchCompute: ClassVar[int] = ...
    kDisplacementShader: ClassVar[int] = ...
    kDisplayLayer: ClassVar[int] = ...
    kDisplayLayerManager: ClassVar[int] = ...
    kDistance: ClassVar[int] = ...
    kDistanceBetween: ClassVar[int] = ...
    kDistanceManip: ClassVar[int] = ...
    kDivide: ClassVar[int] = ...
    kDofManip: ClassVar[int] = ...
    kDotProduct: ClassVar[int] = ...
    kDoubleAngleAttribute: ClassVar[int] = ...
    kDoubleArrayData: ClassVar[int] = ...
    kDoubleIndexedComponent: ClassVar[int] = ...
    kDoubleLinearAttribute: ClassVar[int] = ...
    kDoubleShadingSwitch: ClassVar[int] = ...
    kDoubleToAngleNode: ClassVar[int] = ...
    kDrag: ClassVar[int] = ...
    kDropOffFunction: ClassVar[int] = ...
    kDropoffLocator: ClassVar[int] = ...
    kDropoffManip: ClassVar[int] = ...
    kDummy: ClassVar[int] = ...
    kDummyConnectable: ClassVar[int] = ...
    kDynAirManip: ClassVar[int] = ...
    kDynArrayAttrsData: ClassVar[int] = ...
    kDynAttenuationManip: ClassVar[int] = ...
    kDynBase: ClassVar[int] = ...
    kDynBaseFieldManip: ClassVar[int] = ...
    kDynEmitterManip: ClassVar[int] = ...
    kDynFieldsManip: ClassVar[int] = ...
    kDynGlobals: ClassVar[int] = ...
    kDynNewtonManip: ClassVar[int] = ...
    kDynParticleSetComponent: ClassVar[int] = ...
    kDynSpreadManip: ClassVar[int] = ...
    kDynSweptGeometryData: ClassVar[int] = ...
    kDynTurbulenceManip: ClassVar[int] = ...
    kDynamicConstraint: ClassVar[int] = ...
    kDynamicsController: ClassVar[int] = ...
    kEdgeComponent: ClassVar[int] = ...
    kEditCurve: ClassVar[int] = ...
    kEditCurveManip: ClassVar[int] = ...
    kEditMetadata: ClassVar[int] = ...
    kEditsManager: ClassVar[int] = ...
    kEmitter: ClassVar[int] = ...
    kEnableManip: ClassVar[int] = ...
    kEnumAttribute: ClassVar[int] = ...
    kEnvBall: ClassVar[int] = ...
    kEnvChrome: ClassVar[int] = ...
    kEnvCube: ClassVar[int] = ...
    kEnvFacade: ClassVar[int] = ...
    kEnvFogMaterial: ClassVar[int] = ...
    kEnvFogShape: ClassVar[int] = ...
    kEnvSky: ClassVar[int] = ...
    kEnvSphere: ClassVar[int] = ...
    kEqual: ClassVar[int] = ...
    kExplodeNurbsShell: ClassVar[int] = ...
    kExpression: ClassVar[int] = ...
    kExtendCurve: ClassVar[int] = ...
    kExtendCurveDistanceManip: ClassVar[int] = ...
    kExtendSurface: ClassVar[int] = ...
    kExtendSurfaceDistanceManip: ClassVar[int] = ...
    kExtract: ClassVar[int] = ...
    kExtrude: ClassVar[int] = ...
    kExtrudeManip: ClassVar[int] = ...
    kFFD: ClassVar[int] = ...
    kFFblendSrf: ClassVar[int] = ...
    kFFfilletSrf: ClassVar[int] = ...
    kFacade: ClassVar[int] = ...
    kFalloffEval: ClassVar[int] = ...
    kFfdDualBase: ClassVar[int] = ...
    kField: ClassVar[int] = ...
    kFileBackground: ClassVar[int] = ...
    kFileTexture: ClassVar[int] = ...
    kFilletCurve: ClassVar[int] = ...
    kFilter: ClassVar[int] = ...
    kFilterClosestSample: ClassVar[int] = ...
    kFilterEuler: ClassVar[int] = ...
    kFilterSimplify: ClassVar[int] = ...
    kFitBspline: ClassVar[int] = ...
    kFixedLineManip: ClassVar[int] = ...
    kFlexor: ClassVar[int] = ...
    kFloatAngleAttribute: ClassVar[int] = ...
    kFloatArrayData: ClassVar[int] = ...
    kFloatLinearAttribute: ClassVar[int] = ...
    kFloatMatrixAttribute: ClassVar[int] = ...
    kFloatVectorArrayData: ClassVar[int] = ...
    kFloor: ClassVar[int] = ...
    kFlow: ClassVar[int] = ...
    kFluid: ClassVar[int] = ...
    kFluidData: ClassVar[int] = ...
    kFluidEmitter: ClassVar[int] = ...
    kFluidGeom: ClassVar[int] = ...
    kFluidTexture2D: ClassVar[int] = ...
    kFluidTexture3D: ClassVar[int] = ...
    kFollicle: ClassVar[int] = ...
    kForceUpdateManip: ClassVar[int] = ...
    kFosterParent: ClassVar[int] = ...
    kFourByFourMatrix: ClassVar[int] = ...
    kFractal: ClassVar[int] = ...
    kFreePointManip: ClassVar[int] = ...
    kFreePointTriadManip: ClassVar[int] = ...
    kGammaCorrect: ClassVar[int] = ...
    kGenericAttribute: ClassVar[int] = ...
    kGeoConnectable: ClassVar[int] = ...
    kGeoConnector: ClassVar[int] = ...
    kGeomBind: ClassVar[int] = ...
    kGeometric: ClassVar[int] = ...
    kGeometryConstraint: ClassVar[int] = ...
    kGeometryData: ClassVar[int] = ...
    kGeometryFilt: ClassVar[int] = ...
    kGeometryOnLineManip: ClassVar[int] = ...
    kGeometryVarGroup: ClassVar[int] = ...
    kGlobalCacheControls: ClassVar[int] = ...
    kGlobalStitch: ClassVar[int] = ...
    kGranite: ClassVar[int] = ...
    kGravity: ClassVar[int] = ...
    kGreasePencilSequence: ClassVar[int] = ...
    kGreasePlane: ClassVar[int] = ...
    kGreasePlaneRenderShape: ClassVar[int] = ...
    kGreaterThan: ClassVar[int] = ...
    kGrid: ClassVar[int] = ...
    kGroundPlane: ClassVar[int] = ...
    kGroupId: ClassVar[int] = ...
    kGroupParts: ClassVar[int] = ...
    kGuide: ClassVar[int] = ...
    kGuideLine: ClassVar[int] = ...
    kHairConstraint: ClassVar[int] = ...
    kHairSystem: ClassVar[int] = ...
    kHairTubeShader: ClassVar[int] = ...
    kHandleRotateManip: ClassVar[int] = ...
    kHardenPointCurve: ClassVar[int] = ...
    kHardwareReflectionMap: ClassVar[int] = ...
    kHardwareRenderGlobals: ClassVar[int] = ...
    kHardwareRenderingGlobals: ClassVar[int] = ...
    kHeightField: ClassVar[int] = ...
    kHikEffector: ClassVar[int] = ...
    kHikFKJoint: ClassVar[int] = ...
    kHikFloorContactMarker: ClassVar[int] = ...
    kHikGroundPlane: ClassVar[int] = ...
    kHikHandle: ClassVar[int] = ...
    kHikIKEffector: ClassVar[int] = ...
    kHikSolver: ClassVar[int] = ...
    kHistorySwitch: ClassVar[int] = ...
    kHsvToRgb: ClassVar[int] = ...
    kHwShaderNode: ClassVar[int] = ...
    kHyperGraphInfo: ClassVar[int] = ...
    kHyperLayout: ClassVar[int] = ...
    kHyperLayoutDG: ClassVar[int] = ...
    kHyperView: ClassVar[int] = ...
    kIkEffector: ClassVar[int] = ...
    kIkHandle: ClassVar[int] = ...
    kIkRPManip: ClassVar[int] = ...
    kIkSolver: ClassVar[int] = ...
    kIkSplineManip: ClassVar[int] = ...
    kIkSystem: ClassVar[int] = ...
    kIllustratorCurve: ClassVar[int] = ...
    kImageAdd: ClassVar[int] = ...
    kImageBlur: ClassVar[int] = ...
    kImageColorCorrect: ClassVar[int] = ...
    kImageData: ClassVar[int] = ...
    kImageDepth: ClassVar[int] = ...
    kImageDiff: ClassVar[int] = ...
    kImageDisplay: ClassVar[int] = ...
    kImageFilter: ClassVar[int] = ...
    kImageLoad: ClassVar[int] = ...
    kImageMotionBlur: ClassVar[int] = ...
    kImageMultiply: ClassVar[int] = ...
    kImageNetDest: ClassVar[int] = ...
    kImageNetSrc: ClassVar[int] = ...
    kImageOver: ClassVar[int] = ...
    kImagePlane: ClassVar[int] = ...
    kImageRender: ClassVar[int] = ...
    kImageSave: ClassVar[int] = ...
    kImageSource: ClassVar[int] = ...
    kImageUnder: ClassVar[int] = ...
    kImageView: ClassVar[int] = ...
    kImplicitCone: ClassVar[int] = ...
    kImplicitSphere: ClassVar[int] = ...
    kInsertKnotCrv: ClassVar[int] = ...
    kInsertKnotSrf: ClassVar[int] = ...
    kInstancer: ClassVar[int] = ...
    kInt64ArrayData: ClassVar[int] = ...
    kIntArrayData: ClassVar[int] = ...
    kIntersectSurface: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kInverseLinearInterpolation: ClassVar[int] = ...
    kIsoparmComponent: ClassVar[int] = ...
    kIsoparmManip: ClassVar[int] = ...
    kItemList: ClassVar[int] = ...
    kJiggleDeformer: ClassVar[int] = ...
    kJoint: ClassVar[int] = ...
    kJointCluster: ClassVar[int] = ...
    kJointClusterManip: ClassVar[int] = ...
    kJointTranslateManip: ClassVar[int] = ...
    kKeyframeDelta: ClassVar[int] = ...
    kKeyframeDeltaAddRemove: ClassVar[int] = ...
    kKeyframeDeltaBlockAddRemove: ClassVar[int] = ...
    kKeyframeDeltaBreakdown: ClassVar[int] = ...
    kKeyframeDeltaInfType: ClassVar[int] = ...
    kKeyframeDeltaMove: ClassVar[int] = ...
    kKeyframeDeltaScale: ClassVar[int] = ...
    kKeyframeDeltaTangent: ClassVar[int] = ...
    kKeyframeDeltaWeighted: ClassVar[int] = ...
    kKeyframeRegionManip: ClassVar[int] = ...
    kKeyingGroup: ClassVar[int] = ...
    kLambert: ClassVar[int] = ...
    kLambertMaterial: ClassVar[int] = ...
    kLattice: ClassVar[int] = ...
    kLatticeComponent: ClassVar[int] = ...
    kLatticeData: ClassVar[int] = ...
    kLatticeGeom: ClassVar[int] = ...
    kLayeredShader: ClassVar[int] = ...
    kLayeredTexture: ClassVar[int] = ...
    kLeastSquares: ClassVar[int] = ...
    kLeather: ClassVar[int] = ...
    kLength: ClassVar[int] = ...
    kLessThan: ClassVar[int] = ...
    kLight: ClassVar[int] = ...
    kLightDataAttribute: ClassVar[int] = ...
    kLightFogMaterial: ClassVar[int] = ...
    kLightInfo: ClassVar[int] = ...
    kLightLink: ClassVar[int] = ...
    kLightList: ClassVar[int] = ...
    kLightManip: ClassVar[int] = ...
    kLightProjectionGeometry: ClassVar[int] = ...
    kLightSource: ClassVar[int] = ...
    kLightSourceMaterial: ClassVar[int] = ...
    kLimitManip: ClassVar[int] = ...
    kLineArrowManip: ClassVar[int] = ...
    kLineManip: ClassVar[int] = ...
    kLineModifier: ClassVar[int] = ...
    kLinearInterpolation: ClassVar[int] = ...
    kLinearLight: ClassVar[int] = ...
    kLocator: ClassVar[int] = ...
    kLodGroup: ClassVar[int] = ...
    kLodThresholds: ClassVar[int] = ...
    kLog: ClassVar[int] = ...
    kLookAt: ClassVar[int] = ...
    kLuminance: ClassVar[int] = ...
    kMCsolver: ClassVar[int] = ...
    kMPbirailSrf: ClassVar[int] = ...
    kMakeGroup: ClassVar[int] = ...
    kMandelbrot: ClassVar[int] = ...
    kMandelbrot3D: ClassVar[int] = ...
    kManip2DContainer: ClassVar[int] = ...
    kManipContainer: ClassVar[int] = ...
    kManipulator: ClassVar[int] = ...
    kManipulator2D: ClassVar[int] = ...
    kManipulator3D: ClassVar[int] = ...
    kMarble: ClassVar[int] = ...
    kMarker: ClassVar[int] = ...
    kMarkerManip: ClassVar[int] = ...
    kMaterial: ClassVar[int] = ...
    kMaterialFacade: ClassVar[int] = ...
    kMaterialInfo: ClassVar[int] = ...
    kMaterialTemplate: ClassVar[int] = ...
    kMatrixAdd: ClassVar[int] = ...
    kMatrixArrayData: ClassVar[int] = ...
    kMatrixAttribute: ClassVar[int] = ...
    kMatrixData: ClassVar[int] = ...
    kMatrixFloatData: ClassVar[int] = ...
    kMatrixHold: ClassVar[int] = ...
    kMatrixMult: ClassVar[int] = ...
    kMatrixPass: ClassVar[int] = ...
    kMatrixWtAdd: ClassVar[int] = ...
    kMax: ClassVar[int] = ...
    kMembrane: ClassVar[int] = ...
    kMentalRayTexture: ClassVar[int] = ...
    kMergeVertsToolManip: ClassVar[int] = ...
    kMesh: ClassVar[int] = ...
    kMeshComponent: ClassVar[int] = ...
    kMeshData: ClassVar[int] = ...
    kMeshEdgeComponent: ClassVar[int] = ...
    kMeshFaceVertComponent: ClassVar[int] = ...
    kMeshFrEdgeComponent: ClassVar[int] = ...
    kMeshGeom: ClassVar[int] = ...
    kMeshMapComponent: ClassVar[int] = ...
    kMeshPolygonComponent: ClassVar[int] = ...
    kMeshVarGroup: ClassVar[int] = ...
    kMeshVertComponent: ClassVar[int] = ...
    kMeshVtxFaceComponent: ClassVar[int] = ...
    kMessageAttribute: ClassVar[int] = ...
    kMidModifier: ClassVar[int] = ...
    kMidModifierWithMatrix: ClassVar[int] = ...
    kMin: ClassVar[int] = ...
    kModel: ClassVar[int] = ...
    kModifyEdgeBaseManip: ClassVar[int] = ...
    kModifyEdgeCrvManip: ClassVar[int] = ...
    kModifyEdgeManip: ClassVar[int] = ...
    kModulo: ClassVar[int] = ...
    kMorph: ClassVar[int] = ...
    kMotionPath: ClassVar[int] = ...
    kMotionPathManip: ClassVar[int] = ...
    kMountain: ClassVar[int] = ...
    kMoveUVShellManip2D: ClassVar[int] = ...
    kMoveVertexManip: ClassVar[int] = ...
    kMultDoubleLinear: ClassVar[int] = ...
    kMultiSubVertexComponent: ClassVar[int] = ...
    kMultilisterLight: ClassVar[int] = ...
    kMultiply: ClassVar[int] = ...
    kMultiplyDivide: ClassVar[int] = ...
    kMultiplyPointByMatrix: ClassVar[int] = ...
    kMultiplyVectorByMatrix: ClassVar[int] = ...
    kMute: ClassVar[int] = ...
    kNBase: ClassVar[int] = ...
    kNCloth: ClassVar[int] = ...
    kNComponent: ClassVar[int] = ...
    kNId: ClassVar[int] = ...
    kNIdData: ClassVar[int] = ...
    kNLE: ClassVar[int] = ...
    kNObject: ClassVar[int] = ...
    kNObjectData: ClassVar[int] = ...
    kNParticle: ClassVar[int] = ...
    kNRigid: ClassVar[int] = ...
    kNamedObject: ClassVar[int] = ...
    kNearestPointOnCurve: ClassVar[int] = ...
    kNegate: ClassVar[int] = ...
    kNewton: ClassVar[int] = ...
    kNodeGraphEditorBookmarkInfo: ClassVar[int] = ...
    kNodeGraphEditorBookmarks: ClassVar[int] = ...
    kNodeGraphEditorInfo: ClassVar[int] = ...
    kNoise: ClassVar[int] = ...
    kNonAmbientLight: ClassVar[int] = ...
    kNonDagSelectionItem: ClassVar[int] = ...
    kNonExtendedLight: ClassVar[int] = ...
    kNonLinear: ClassVar[int] = ...
    kNormalConstraint: ClassVar[int] = ...
    kNormalize: ClassVar[int] = ...
    kNot: ClassVar[int] = ...
    kNucleus: ClassVar[int] = ...
    kNumericAttribute: ClassVar[int] = ...
    kNumericData: ClassVar[int] = ...
    kNurbsBoolean: ClassVar[int] = ...
    kNurbsCircular2PtArc: ClassVar[int] = ...
    kNurbsCircular3PtArc: ClassVar[int] = ...
    kNurbsCube: ClassVar[int] = ...
    kNurbsCurve: ClassVar[int] = ...
    kNurbsCurveData: ClassVar[int] = ...
    kNurbsCurveGeom: ClassVar[int] = ...
    kNurbsCurveToBezier: ClassVar[int] = ...
    kNurbsPlane: ClassVar[int] = ...
    kNurbsSquare: ClassVar[int] = ...
    kNurbsSurface: ClassVar[int] = ...
    kNurbsSurfaceData: ClassVar[int] = ...
    kNurbsSurfaceGeom: ClassVar[int] = ...
    kNurbsTesselate: ClassVar[int] = ...
    kNurbsToSubdiv: ClassVar[int] = ...
    kObjectAttrFilter: ClassVar[int] = ...
    kObjectBinFilter: ClassVar[int] = ...
    kObjectFilter: ClassVar[int] = ...
    kObjectMultiFilter: ClassVar[int] = ...
    kObjectNameFilter: ClassVar[int] = ...
    kObjectRenderFilter: ClassVar[int] = ...
    kObjectScriptFilter: ClassVar[int] = ...
    kObjectTypeFilter: ClassVar[int] = ...
    kOcean: ClassVar[int] = ...
    kOceanDeformer: ClassVar[int] = ...
    kOceanShader: ClassVar[int] = ...
    kOffsetCos: ClassVar[int] = ...
    kOffsetCosManip: ClassVar[int] = ...
    kOffsetCurve: ClassVar[int] = ...
    kOffsetCurveManip: ClassVar[int] = ...
    kOffsetSurface: ClassVar[int] = ...
    kOffsetSurfaceManip: ClassVar[int] = ...
    kOldGeometryConstraint: ClassVar[int] = ...
    kOpaqueAttribute: ClassVar[int] = ...
    kOpticalFX: ClassVar[int] = ...
    kOr: ClassVar[int] = ...
    kOrientConstraint: ClassVar[int] = ...
    kOrientationComponent: ClassVar[int] = ...
    kOrientationLocator: ClassVar[int] = ...
    kOrientationMarker: ClassVar[int] = ...
    kOrthoGrid: ClassVar[int] = ...
    kPASolver: ClassVar[int] = ...
    kPIConstant: ClassVar[int] = ...
    kPairBlend: ClassVar[int] = ...
    kParamDimension: ClassVar[int] = ...
    kParentConstraint: ClassVar[int] = ...
    kParentMatrix: ClassVar[int] = ...
    kParticle: ClassVar[int] = ...
    kParticleAgeMapper: ClassVar[int] = ...
    kParticleCloud: ClassVar[int] = ...
    kParticleColorMapper: ClassVar[int] = ...
    kParticleIncandecenceMapper: ClassVar[int] = ...
    kParticleSamplerInfo: ClassVar[int] = ...
    kParticleTransparencyMapper: ClassVar[int] = ...
    kPartition: ClassVar[int] = ...
    kPassContributionMap: ClassVar[int] = ...
    kPfxGeometry: ClassVar[int] = ...
    kPfxHair: ClassVar[int] = ...
    kPfxToon: ClassVar[int] = ...
    kPhong: ClassVar[int] = ...
    kPhongExplorer: ClassVar[int] = ...
    kPhongMaterial: ClassVar[int] = ...
    kPickMatrix: ClassVar[int] = ...
    kPivotComponent: ClassVar[int] = ...
    kPivotManip2D: ClassVar[int] = ...
    kPlace2dTexture: ClassVar[int] = ...
    kPlace3dTexture: ClassVar[int] = ...
    kPlanarProjectionManip: ClassVar[int] = ...
    kPlanarTrimSrf: ClassVar[int] = ...
    kPlane: ClassVar[int] = ...
    kPlugin: ClassVar[int] = ...
    kPluginBlendShape: ClassVar[int] = ...
    kPluginCameraSet: ClassVar[int] = ...
    kPluginClientDevice: ClassVar[int] = ...
    kPluginConstraintNode: ClassVar[int] = ...
    kPluginData: ClassVar[int] = ...
    kPluginDeformerNode: ClassVar[int] = ...
    kPluginDependNode: ClassVar[int] = ...
    kPluginEmitterNode: ClassVar[int] = ...
    kPluginFieldNode: ClassVar[int] = ...
    kPluginGeometryData: ClassVar[int] = ...
    kPluginGeometryFilter: ClassVar[int] = ...
    kPluginHardwareShader: ClassVar[int] = ...
    kPluginHwShaderNode: ClassVar[int] = ...
    kPluginIkSolver: ClassVar[int] = ...
    kPluginImagePlaneNode: ClassVar[int] = ...
    kPluginLocatorNode: ClassVar[int] = ...
    kPluginManipContainer: ClassVar[int] = ...
    kPluginManipulatorNode: ClassVar[int] = ...
    kPluginMotionPathNode: ClassVar[int] = ...
    kPluginObjectSet: ClassVar[int] = ...
    kPluginParticleAttributeMapperNode: ClassVar[int] = ...
    kPluginShape: ClassVar[int] = ...
    kPluginSkinCluster: ClassVar[int] = ...
    kPluginSpringNode: ClassVar[int] = ...
    kPluginThreadedDevice: ClassVar[int] = ...
    kPluginTransformNode: ClassVar[int] = ...
    kPlusMinusAverage: ClassVar[int] = ...
    kPointArrayData: ClassVar[int] = ...
    kPointConstraint: ClassVar[int] = ...
    kPointLight: ClassVar[int] = ...
    kPointManip: ClassVar[int] = ...
    kPointMatrixMult: ClassVar[int] = ...
    kPointOnCurveInfo: ClassVar[int] = ...
    kPointOnCurveManip: ClassVar[int] = ...
    kPointOnLineManip: ClassVar[int] = ...
    kPointOnPolyConstraint: ClassVar[int] = ...
    kPointOnSurfaceInfo: ClassVar[int] = ...
    kPointOnSurfaceManip: ClassVar[int] = ...
    kPoleVectorConstraint: ClassVar[int] = ...
    kPolyAppend: ClassVar[int] = ...
    kPolyAppendVertex: ClassVar[int] = ...
    kPolyArrow: ClassVar[int] = ...
    kPolyAutoProj: ClassVar[int] = ...
    kPolyAutoProjManip: ClassVar[int] = ...
    kPolyAverageVertex: ClassVar[int] = ...
    kPolyAxis: ClassVar[int] = ...
    kPolyBevel: ClassVar[int] = ...
    kPolyBevel2: ClassVar[int] = ...
    kPolyBevel3: ClassVar[int] = ...
    kPolyBevelCutback: ClassVar[int] = ...
    kPolyBlindData: ClassVar[int] = ...
    kPolyBoolOp: ClassVar[int] = ...
    kPolyBridgeEdge: ClassVar[int] = ...
    kPolyCBoolOp: ClassVar[int] = ...
    kPolyCaddyManip: ClassVar[int] = ...
    kPolyChipOff: ClassVar[int] = ...
    kPolyCircularize: ClassVar[int] = ...
    kPolyClean: ClassVar[int] = ...
    kPolyCloseBorder: ClassVar[int] = ...
    kPolyCollapseEdge: ClassVar[int] = ...
    kPolyCollapseF: ClassVar[int] = ...
    kPolyColorDel: ClassVar[int] = ...
    kPolyColorMod: ClassVar[int] = ...
    kPolyColorPerVertex: ClassVar[int] = ...
    kPolyComponentData: ClassVar[int] = ...
    kPolyCone: ClassVar[int] = ...
    kPolyConnectComponents: ClassVar[int] = ...
    kPolyContourProj: ClassVar[int] = ...
    kPolyCreaseEdge: ClassVar[int] = ...
    kPolyCreateFacet: ClassVar[int] = ...
    kPolyCreateToolManip: ClassVar[int] = ...
    kPolyCreator: ClassVar[int] = ...
    kPolyCube: ClassVar[int] = ...
    kPolyCut: ClassVar[int] = ...
    kPolyCutManip: ClassVar[int] = ...
    kPolyCutManipContainer: ClassVar[int] = ...
    kPolyCylProj: ClassVar[int] = ...
    kPolyCylinder: ClassVar[int] = ...
    kPolyDelEdge: ClassVar[int] = ...
    kPolyDelFacet: ClassVar[int] = ...
    kPolyDelVertex: ClassVar[int] = ...
    kPolyDuplicateEdge: ClassVar[int] = ...
    kPolyEdgeToCurve: ClassVar[int] = ...
    kPolyEditEdgeFlow: ClassVar[int] = ...
    kPolyExtrudeEdge: ClassVar[int] = ...
    kPolyExtrudeFacet: ClassVar[int] = ...
    kPolyExtrudeManip: ClassVar[int] = ...
    kPolyExtrudeManipContainer: ClassVar[int] = ...
    kPolyExtrudeVertex: ClassVar[int] = ...
    kPolyFlipEdge: ClassVar[int] = ...
    kPolyFlipUV: ClassVar[int] = ...
    kPolyHelix: ClassVar[int] = ...
    kPolyHoleFace: ClassVar[int] = ...
    kPolyLayoutUV: ClassVar[int] = ...
    kPolyMapCut: ClassVar[int] = ...
    kPolyMapDel: ClassVar[int] = ...
    kPolyMapSew: ClassVar[int] = ...
    kPolyMapSewMove: ClassVar[int] = ...
    kPolyMappingManip: ClassVar[int] = ...
    kPolyMergeEdge: ClassVar[int] = ...
    kPolyMergeFacet: ClassVar[int] = ...
    kPolyMergeUV: ClassVar[int] = ...
    kPolyMergeVert: ClassVar[int] = ...
    kPolyMesh: ClassVar[int] = ...
    kPolyMirror: ClassVar[int] = ...
    kPolyMirrorManipContainer: ClassVar[int] = ...
    kPolyModifierManip: ClassVar[int] = ...
    kPolyModifierManipContainer: ClassVar[int] = ...
    kPolyMoveEdge: ClassVar[int] = ...
    kPolyMoveFacet: ClassVar[int] = ...
    kPolyMoveFacetUV: ClassVar[int] = ...
    kPolyMoveUV: ClassVar[int] = ...
    kPolyMoveUVManip: ClassVar[int] = ...
    kPolyMoveVertex: ClassVar[int] = ...
    kPolyMoveVertexManip: ClassVar[int] = ...
    kPolyMoveVertexUV: ClassVar[int] = ...
    kPolyNormal: ClassVar[int] = ...
    kPolyNormalPerVertex: ClassVar[int] = ...
    kPolyNormalizeUV: ClassVar[int] = ...
    kPolyPassThru: ClassVar[int] = ...
    kPolyPinUV: ClassVar[int] = ...
    kPolyPipe: ClassVar[int] = ...
    kPolyPlanProj: ClassVar[int] = ...
    kPolyPlatonicSolid: ClassVar[int] = ...
    kPolyPoke: ClassVar[int] = ...
    kPolyPokeManip: ClassVar[int] = ...
    kPolyPrimitive: ClassVar[int] = ...
    kPolyPrimitiveMisc: ClassVar[int] = ...
    kPolyPrism: ClassVar[int] = ...
    kPolyProj: ClassVar[int] = ...
    kPolyProjectCurve: ClassVar[int] = ...
    kPolyProjectionManip: ClassVar[int] = ...
    kPolyPyramid: ClassVar[int] = ...
    kPolyQuad: ClassVar[int] = ...
    kPolyReFormManip: ClassVar[int] = ...
    kPolyReFormManipContainer: ClassVar[int] = ...
    kPolyReduce: ClassVar[int] = ...
    kPolyRemesh: ClassVar[int] = ...
    kPolySelectEditFeedbackManip: ClassVar[int] = ...
    kPolySeparate: ClassVar[int] = ...
    kPolySewEdge: ClassVar[int] = ...
    kPolySmartExtrude: ClassVar[int] = ...
    kPolySmartExtrudeManip: ClassVar[int] = ...
    kPolySmooth: ClassVar[int] = ...
    kPolySmoothFacet: ClassVar[int] = ...
    kPolySmoothProxy: ClassVar[int] = ...
    kPolySoftEdge: ClassVar[int] = ...
    kPolySphProj: ClassVar[int] = ...
    kPolySphere: ClassVar[int] = ...
    kPolySpinEdge: ClassVar[int] = ...
    kPolySplit: ClassVar[int] = ...
    kPolySplitEdge: ClassVar[int] = ...
    kPolySplitRing: ClassVar[int] = ...
    kPolySplitToolManip: ClassVar[int] = ...
    kPolySplitVert: ClassVar[int] = ...
    kPolyStraightenUVBorder: ClassVar[int] = ...
    kPolySubdEdge: ClassVar[int] = ...
    kPolySubdFacet: ClassVar[int] = ...
    kPolyToSubdiv: ClassVar[int] = ...
    kPolyToolFeedbackManip: ClassVar[int] = ...
    kPolyToolFeedbackShape: ClassVar[int] = ...
    kPolyTorus: ClassVar[int] = ...
    kPolyTransfer: ClassVar[int] = ...
    kPolyTriangulate: ClassVar[int] = ...
    kPolyTweak: ClassVar[int] = ...
    kPolyTweakUV: ClassVar[int] = ...
    kPolyUVRectangle: ClassVar[int] = ...
    kPolyUnite: ClassVar[int] = ...
    kPolyUnsmooth: ClassVar[int] = ...
    kPolyVertexNormalManip: ClassVar[int] = ...
    kPolyWedgeFace: ClassVar[int] = ...
    kPoseInterpolatorManager: ClassVar[int] = ...
    kPositionMarker: ClassVar[int] = ...
    kPostProcessList: ClassVar[int] = ...
    kPower: ClassVar[int] = ...
    kPrecompExport: ClassVar[int] = ...
    kPrimitive: ClassVar[int] = ...
    kPrimitiveFalloff: ClassVar[int] = ...
    kProjectCurve: ClassVar[int] = ...
    kProjectTangent: ClassVar[int] = ...
    kProjectTangentManip: ClassVar[int] = ...
    kProjection: ClassVar[int] = ...
    kProjectionManip: ClassVar[int] = ...
    kProjectionMultiManip: ClassVar[int] = ...
    kProjectionUVManip: ClassVar[int] = ...
    kPropModManip: ClassVar[int] = ...
    kPropMoveTriadManip: ClassVar[int] = ...
    kProximityFalloff: ClassVar[int] = ...
    kProximityPin: ClassVar[int] = ...
    kProximityWrap: ClassVar[int] = ...
    kProxy: ClassVar[int] = ...
    kProxyManager: ClassVar[int] = ...
    kPsdFileTexture: ClassVar[int] = ...
    kQuadPtOnLineManip: ClassVar[int] = ...
    kQuadShadingSwitch: ClassVar[int] = ...
    kRBFsurface: ClassVar[int] = ...
    kRPsolver: ClassVar[int] = ...
    kRadial: ClassVar[int] = ...
    kRadius: ClassVar[int] = ...
    kRamp: ClassVar[int] = ...
    kRampBackground: ClassVar[int] = ...
    kRampShader: ClassVar[int] = ...
    kRbfSrfManip: ClassVar[int] = ...
    kReForm: ClassVar[int] = ...
    kRebuildCurve: ClassVar[int] = ...
    kRebuildSurface: ClassVar[int] = ...
    kRecord: ClassVar[int] = ...
    kReference: ClassVar[int] = ...
    kReflect: ClassVar[int] = ...
    kRemapColor: ClassVar[int] = ...
    kRemapHsv: ClassVar[int] = ...
    kRemapValue: ClassVar[int] = ...
    kRenderBox: ClassVar[int] = ...
    kRenderCone: ClassVar[int] = ...
    kRenderGlobals: ClassVar[int] = ...
    kRenderGlobalsList: ClassVar[int] = ...
    kRenderLayer: ClassVar[int] = ...
    kRenderLayerManager: ClassVar[int] = ...
    kRenderPass: ClassVar[int] = ...
    kRenderPassSet: ClassVar[int] = ...
    kRenderQuality: ClassVar[int] = ...
    kRenderRect: ClassVar[int] = ...
    kRenderSetup: ClassVar[int] = ...
    kRenderSphere: ClassVar[int] = ...
    kRenderTarget: ClassVar[int] = ...
    kRenderUtilityList: ClassVar[int] = ...
    kRenderedImageSource: ClassVar[int] = ...
    kRenderingList: ClassVar[int] = ...
    kReorderUVSet: ClassVar[int] = ...
    kResolution: ClassVar[int] = ...
    kResultCurve: ClassVar[int] = ...
    kResultCurveTimeToAngular: ClassVar[int] = ...
    kResultCurveTimeToDistance: ClassVar[int] = ...
    kResultCurveTimeToTime: ClassVar[int] = ...
    kResultCurveTimeToUnitless: ClassVar[int] = ...
    kReverse: ClassVar[int] = ...
    kReverseCrvManip: ClassVar[int] = ...
    kReverseCurve: ClassVar[int] = ...
    kReverseCurveManip: ClassVar[int] = ...
    kReverseSurface: ClassVar[int] = ...
    kReverseSurfaceManip: ClassVar[int] = ...
    kRevolve: ClassVar[int] = ...
    kRevolveManip: ClassVar[int] = ...
    kRevolvedPrimitive: ClassVar[int] = ...
    kRevolvedPrimitiveManip: ClassVar[int] = ...
    kRgbToHsv: ClassVar[int] = ...
    kRigid: ClassVar[int] = ...
    kRigidConstraint: ClassVar[int] = ...
    kRigidDeform: ClassVar[int] = ...
    kRigidSolver: ClassVar[int] = ...
    kRock: ClassVar[int] = ...
    kRotateBoxManip: ClassVar[int] = ...
    kRotateLimitsManip: ClassVar[int] = ...
    kRotateManip: ClassVar[int] = ...
    kRotateUVManip2D: ClassVar[int] = ...
    kRotateVector: ClassVar[int] = ...
    kRotationFromMatrix: ClassVar[int] = ...
    kRound: ClassVar[int] = ...
    kRoundConstantRadius: ClassVar[int] = ...
    kRoundConstantRadiusManip: ClassVar[int] = ...
    kRoundRadiusCrvManip: ClassVar[int] = ...
    kRoundRadiusManip: ClassVar[int] = ...
    kRowFromMatrix: ClassVar[int] = ...
    kSCsolver: ClassVar[int] = ...
    kSPbirailSrf: ClassVar[int] = ...
    kSamplerInfo: ClassVar[int] = ...
    kScaleConstraint: ClassVar[int] = ...
    kScaleFromMatrix: ClassVar[int] = ...
    kScaleLimitsManip: ClassVar[int] = ...
    kScaleManip: ClassVar[int] = ...
    kScalePointManip: ClassVar[int] = ...
    kScaleUVManip2D: ClassVar[int] = ...
    kScalingBoxManip: ClassVar[int] = ...
    kScreenAlignedCircleManip: ClassVar[int] = ...
    kScript: ClassVar[int] = ...
    kScriptManip: ClassVar[int] = ...
    kSculpt: ClassVar[int] = ...
    kSectionManip: ClassVar[int] = ...
    kSelectionItem: ClassVar[int] = ...
    kSelectionList: ClassVar[int] = ...
    kSelectionListData: ClassVar[int] = ...
    kSelectionListOperator: ClassVar[int] = ...
    kSequenceManager: ClassVar[int] = ...
    kSequencer: ClassVar[int] = ...
    kSet: ClassVar[int] = ...
    kSetGroupComponent: ClassVar[int] = ...
    kSetRange: ClassVar[int] = ...
    kSfRevolveManip: ClassVar[int] = ...
    kShaderGlow: ClassVar[int] = ...
    kShaderList: ClassVar[int] = ...
    kShadingEngine: ClassVar[int] = ...
    kShadingMap: ClassVar[int] = ...
    kShape: ClassVar[int] = ...
    kShapeEditorManager: ClassVar[int] = ...
    kShapeFragment: ClassVar[int] = ...
    kShot: ClassVar[int] = ...
    kShrinkWrapFilter: ClassVar[int] = ...
    kSimpleVolumeShader: ClassVar[int] = ...
    kSin: ClassVar[int] = ...
    kSingleIndexedComponent: ClassVar[int] = ...
    kSingleShadingSwitch: ClassVar[int] = ...
    kSketchPlane: ClassVar[int] = ...
    kSkin: ClassVar[int] = ...
    kSkinBinding: ClassVar[int] = ...
    kSkinClusterFilter: ClassVar[int] = ...
    kSkinShader: ClassVar[int] = ...
    kSl60: ClassVar[int] = ...
    kSmear: ClassVar[int] = ...
    kSmoothCurve: ClassVar[int] = ...
    kSmoothStep: ClassVar[int] = ...
    kSmoothTangentSrf: ClassVar[int] = ...
    kSnapUVManip2D: ClassVar[int] = ...
    kSnapshot: ClassVar[int] = ...
    kSnapshotPath: ClassVar[int] = ...
    kSnapshotShape: ClassVar[int] = ...
    kSnow: ClassVar[int] = ...
    kSoftMod: ClassVar[int] = ...
    kSoftModFilter: ClassVar[int] = ...
    kSoftModManip: ClassVar[int] = ...
    kSolidFractal: ClassVar[int] = ...
    kSolidify: ClassVar[int] = ...
    kSphere: ClassVar[int] = ...
    kSphereData: ClassVar[int] = ...
    kSphericalProjectionManip: ClassVar[int] = ...
    kSplineSolver: ClassVar[int] = ...
    kSpotCylinderManip: ClassVar[int] = ...
    kSpotLight: ClassVar[int] = ...
    kSpotManip: ClassVar[int] = ...
    kSpring: ClassVar[int] = ...
    kSprite: ClassVar[int] = ...
    kSquareSrf: ClassVar[int] = ...
    kSquareSrfManip: ClassVar[int] = ...
    kStandardSurface: ClassVar[int] = ...
    kStateManip: ClassVar[int] = ...
    kStencil: ClassVar[int] = ...
    kStereoCameraMaster: ClassVar[int] = ...
    kStitchAsNurbsShell: ClassVar[int] = ...
    kStitchSrf: ClassVar[int] = ...
    kStitchSrfManip: ClassVar[int] = ...
    kStoryBoard: ClassVar[int] = ...
    kStringArrayData: ClassVar[int] = ...
    kStringData: ClassVar[int] = ...
    kStringShadingSwitch: ClassVar[int] = ...
    kStroke: ClassVar[int] = ...
    kStrokeGlobals: ClassVar[int] = ...
    kStucco: ClassVar[int] = ...
    kStudioClearCoat: ClassVar[int] = ...
    kStyleCurve: ClassVar[int] = ...
    kSubCurve: ClassVar[int] = ...
    kSubSurface: ClassVar[int] = ...
    kSubVertexComponent: ClassVar[int] = ...
    kSubdAddTopology: ClassVar[int] = ...
    kSubdAutoProj: ClassVar[int] = ...
    kSubdBlindData: ClassVar[int] = ...
    kSubdBoolean: ClassVar[int] = ...
    kSubdCleanTopology: ClassVar[int] = ...
    kSubdCloseBorder: ClassVar[int] = ...
    kSubdDelFace: ClassVar[int] = ...
    kSubdExtrudeFace: ClassVar[int] = ...
    kSubdHierBlind: ClassVar[int] = ...
    kSubdLayoutUV: ClassVar[int] = ...
    kSubdMapCut: ClassVar[int] = ...
    kSubdMapSewMove: ClassVar[int] = ...
    kSubdMappingManip: ClassVar[int] = ...
    kSubdMergeVert: ClassVar[int] = ...
    kSubdModifier: ClassVar[int] = ...
    kSubdModifyEdge: ClassVar[int] = ...
    kSubdMoveEdge: ClassVar[int] = ...
    kSubdMoveFace: ClassVar[int] = ...
    kSubdMoveVertex: ClassVar[int] = ...
    kSubdPlanProj: ClassVar[int] = ...
    kSubdProjectionManip: ClassVar[int] = ...
    kSubdSplitFace: ClassVar[int] = ...
    kSubdSubdivideFace: ClassVar[int] = ...
    kSubdTweak: ClassVar[int] = ...
    kSubdTweakUV: ClassVar[int] = ...
    kSubdiv: ClassVar[int] = ...
    kSubdivCVComponent: ClassVar[int] = ...
    kSubdivCollapse: ClassVar[int] = ...
    kSubdivCompId: ClassVar[int] = ...
    kSubdivData: ClassVar[int] = ...
    kSubdivEdgeComponent: ClassVar[int] = ...
    kSubdivFaceComponent: ClassVar[int] = ...
    kSubdivGeom: ClassVar[int] = ...
    kSubdivMapComponent: ClassVar[int] = ...
    kSubdivReverseFaces: ClassVar[int] = ...
    kSubdivSurfaceVarGroup: ClassVar[int] = ...
    kSubdivToNurbs: ClassVar[int] = ...
    kSubdivToPoly: ClassVar[int] = ...
    kSubsetFalloff: ClassVar[int] = ...
    kSubtract: ClassVar[int] = ...
    kSum: ClassVar[int] = ...
    kSummaryObject: ClassVar[int] = ...
    kSuper: ClassVar[int] = ...
    kSurface: ClassVar[int] = ...
    kSurfaceCVComponent: ClassVar[int] = ...
    kSurfaceEPComponent: ClassVar[int] = ...
    kSurfaceEdManip: ClassVar[int] = ...
    kSurfaceFaceComponent: ClassVar[int] = ...
    kSurfaceInfo: ClassVar[int] = ...
    kSurfaceKnotComponent: ClassVar[int] = ...
    kSurfaceLuminance: ClassVar[int] = ...
    kSurfaceRangeComponent: ClassVar[int] = ...
    kSurfaceShader: ClassVar[int] = ...
    kSurfaceVarGroup: ClassVar[int] = ...
    kSymmetryConstraint: ClassVar[int] = ...
    kSymmetryLocator: ClassVar[int] = ...
    kSymmetryMapCurve: ClassVar[int] = ...
    kSymmetryMapVector: ClassVar[int] = ...
    kTan: ClassVar[int] = ...
    kTangentConstraint: ClassVar[int] = ...
    kTension: ClassVar[int] = ...
    kTexLattice: ClassVar[int] = ...
    kTexLatticeDeformManip: ClassVar[int] = ...
    kTexSmoothManip: ClassVar[int] = ...
    kTexSmudgeUVManip: ClassVar[int] = ...
    kTextButtonManip: ClassVar[int] = ...
    kTextCurves: ClassVar[int] = ...
    kTextManip: ClassVar[int] = ...
    kTexture2d: ClassVar[int] = ...
    kTexture3d: ClassVar[int] = ...
    kTextureBakeSet: ClassVar[int] = ...
    kTextureDeformer: ClassVar[int] = ...
    kTextureDeformerHandle: ClassVar[int] = ...
    kTextureEnv: ClassVar[int] = ...
    kTextureList: ClassVar[int] = ...
    kTextureManip3D: ClassVar[int] = ...
    kThreadedDevice: ClassVar[int] = ...
    kThreePointArcManip: ClassVar[int] = ...
    kTime: ClassVar[int] = ...
    kTimeAttribute: ClassVar[int] = ...
    kTimeEditor: ClassVar[int] = ...
    kTimeEditorAnimSource: ClassVar[int] = ...
    kTimeEditorClip: ClassVar[int] = ...
    kTimeEditorClipBase: ClassVar[int] = ...
    kTimeEditorClipEvaluator: ClassVar[int] = ...
    kTimeEditorInterpolator: ClassVar[int] = ...
    kTimeEditorTracks: ClassVar[int] = ...
    kTimeFunction: ClassVar[int] = ...
    kTimeToUnitConversion: ClassVar[int] = ...
    kTimeWarp: ClassVar[int] = ...
    kToggleManip: ClassVar[int] = ...
    kToggleOnLineManip: ClassVar[int] = ...
    kToolContext: ClassVar[int] = ...
    kToonLineAttributes: ClassVar[int] = ...
    kTorus: ClassVar[int] = ...
    kTowPointManip: ClassVar[int] = ...
    kTowPointOnCurveManip: ClassVar[int] = ...
    kTowPointOnSurfaceManip: ClassVar[int] = ...
    kTrackInfoManager: ClassVar[int] = ...
    kTransferAttributes: ClassVar[int] = ...
    kTransferFalloff: ClassVar[int] = ...
    kTransform: ClassVar[int] = ...
    kTransformBoxManip: ClassVar[int] = ...
    kTransformGeometry: ClassVar[int] = ...
    kTranslateBoxManip: ClassVar[int] = ...
    kTranslateLimitsManip: ClassVar[int] = ...
    kTranslateManip: ClassVar[int] = ...
    kTranslateManip2D: ClassVar[int] = ...
    kTranslateUVManip: ClassVar[int] = ...
    kTranslateUVManip2D: ClassVar[int] = ...
    kTranslationFromMatrix: ClassVar[int] = ...
    kTriadManip: ClassVar[int] = ...
    kTrim: ClassVar[int] = ...
    kTrimLocator: ClassVar[int] = ...
    kTrimManip: ClassVar[int] = ...
    kTrimWithBoundaries: ClassVar[int] = ...
    kTriplanarProjectionManip: ClassVar[int] = ...
    kTripleIndexedComponent: ClassVar[int] = ...
    kTripleShadingSwitch: ClassVar[int] = ...
    kTrsInsertManip: ClassVar[int] = ...
    kTrsManip: ClassVar[int] = ...
    kTrsTransManip: ClassVar[int] = ...
    kTrsXformManip: ClassVar[int] = ...
    kTruncate: ClassVar[int] = ...
    kTurbulence: ClassVar[int] = ...
    kTweak: ClassVar[int] = ...
    kTwoPointArcManip: ClassVar[int] = ...
    kTxSl: ClassVar[int] = ...
    kTypedAttribute: ClassVar[int] = ...
    kUInt64ArrayData: ClassVar[int] = ...
    kUVManip2D: ClassVar[int] = ...
    kUVPin: ClassVar[int] = ...
    kUfeProxyTransform: ClassVar[int] = ...
    kUint64SingleIndexedComponent: ClassVar[int] = ...
    kUintArrayData: ClassVar[int] = ...
    kUnderWorld: ClassVar[int] = ...
    kUniform: ClassVar[int] = ...
    kUniformFalloff: ClassVar[int] = ...
    kUnitAttribute: ClassVar[int] = ...
    kUnitConversion: ClassVar[int] = ...
    kUnitToTimeConversion: ClassVar[int] = ...
    kUnknown: ClassVar[int] = ...
    kUnknownDag: ClassVar[int] = ...
    kUnknownTransform: ClassVar[int] = ...
    kUntrim: ClassVar[int] = ...
    kUnused1: ClassVar[int] = ...
    kUnused2: ClassVar[int] = ...
    kUnused3: ClassVar[int] = ...
    kUnused4: ClassVar[int] = ...
    kUnused5: ClassVar[int] = ...
    kUnused6: ClassVar[int] = ...
    kUseBackground: ClassVar[int] = ...
    kUvChooser: ClassVar[int] = ...
    kVectorArrayData: ClassVar[int] = ...
    kVectorProduct: ClassVar[int] = ...
    kVertexBakeSet: ClassVar[int] = ...
    kVertexWeightSet: ClassVar[int] = ...
    kViewColorManager: ClassVar[int] = ...
    kViewManip: ClassVar[int] = ...
    kVolumeAxis: ClassVar[int] = ...
    kVolumeBindManip: ClassVar[int] = ...
    kVolumeFog: ClassVar[int] = ...
    kVolumeLight: ClassVar[int] = ...
    kVolumeNoise: ClassVar[int] = ...
    kVolumeShader: ClassVar[int] = ...
    kVortex: ClassVar[int] = ...
    kWater: ClassVar[int] = ...
    kWeightFunctionData: ClassVar[int] = ...
    kWeightGeometryFilt: ClassVar[int] = ...
    kWire: ClassVar[int] = ...
    kWood: ClassVar[int] = ...
    kWorld: ClassVar[int] = ...
    kWrapFilter: ClassVar[int] = ...
    kWriteToColorBuffer: ClassVar[int] = ...
    kWriteToDepthBuffer: ClassVar[int] = ...
    kWriteToFrameBuffer: ClassVar[int] = ...
    kWriteToLabelBuffer: ClassVar[int] = ...
    kWriteToVectorBuffer: ClassVar[int] = ...
    kXformManip: ClassVar[int] = ...
    kXsectionSubdivEdit: ClassVar[int] = ...

class MFnAssembly(MFnDagNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def activate(self, *args, **kwargs): ...
    @overload
    def activateNonRecursive(self) -> Any: ...
    @overload
    def activateNonRecursive(self) -> Any: ...  # type: ignore
    @overload
    def canActivate(self) -> bool: ...
    @overload
    def canActivate(self) -> Any: ...  # type: ignore
    def canRepApplyEdits(self, representation) -> bool: ...
    def createRepresentation(self, *args, **kwargs): ...
    def deleteAllRepresentations(self) -> self: ...  # type: ignore
    def deleteRepresentation(self, representation) -> self: ...  # type: ignore
    def getAbsoluteRepNamespace(self) -> MString: ...  # type: ignore
    def getActive(self) -> MString: ...  # type: ignore
    def getInitialRep(self, *args, **kwargs): ...
    def getParentAssembly(self) -> MObject: ...
    def getRepLabel(self, representation) -> MString: ...  # type: ignore
    def getRepNamespace(self) -> MString: ...  # type: ignore
    def getRepType(self, representation) -> MString: ...  # type: ignore
    def getRepresentations(self, *args, **kwargs): ...
    def getSubAssemblies(self) -> MObjectArray: ...
    @staticmethod
    def getTopLevelAssemblies() -> MObjectArray: ...
    def handlesAddEdits(self) -> bool: ...
    def importFile(self) -> Any: ...
    def isActive(self, representation) -> bool: ...
    def isTopLevel(self) -> bool: ...
    @overload
    def postLoad(self) -> self: ...  # type: ignore
    @overload
    def postLoad(self) -> Any: ...  # type: ignore
    @overload
    def postLoad(self) -> Any: ...  # type: ignore
    def repTypes(self, *args, **kwargs): ...
    def setRepLabel(self, representation, label) -> self: ...  # type: ignore
    def setRepName(self, representation, newName) -> MString: ...  # type: ignore
    def supportsEdits(self) -> bool: ...
    @overload
    def supportsMemberChanges(self) -> bool: ...
    @overload
    def supportsMemberChanges(self) -> Any: ...  # type: ignore

class MFnAttribute(MFnBase):
    kDelete: ClassVar[int] = ...
    kNothing: ClassVar[int] = ...
    kReset: ClassVar[int] = ...
    affectsAppearance: Incomplete
    affectsWorldSpace: Incomplete
    array: Incomplete
    cached: Incomplete
    channelBox: Incomplete
    connectable: Incomplete
    disconnectBehavior: Incomplete
    dynamic: Incomplete
    enforcingUniqueName: Incomplete
    extension: Incomplete
    hidden: Incomplete
    indeterminant: Incomplete
    indexMatters: Incomplete
    internal: Incomplete
    isProxyAttribute: Incomplete
    keyable: Incomplete
    name: Incomplete
    parent: Incomplete
    readable: Incomplete
    renderSource: Incomplete
    shortName: Incomplete
    storable: Incomplete
    usedAsColor: Incomplete
    usedAsFilename: Incomplete
    usesArrayDataBuilder: Incomplete
    worldSpace: Incomplete
    writable: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def accepts(self, *args, **kwargs): ...
    def acceptsAttribute(self, *args, **kwargs): ...
    def addToCategory(self, *args, **kwargs): ...
    def getAddAttrCmd(self, *args, **kwargs): ...
    def hasCategory(self, *args, **kwargs): ...
    def pathName(self, *args, **kwargs): ...
    def setNiceNameOverride(self, *args, **kwargs): ...

class MFnBase:
    def __init__(self, *args, **kwargs) -> None: ...
    def hasObj(self, *args, **kwargs): ...
    def object(self, *args, **kwargs): ...
    def setObject(self, *args, **kwargs): ...
    def type(self, *args, **kwargs): ...

class MFnCamera(MFnDagNode):
    kFillFilmFit: ClassVar[int] = ...
    kHorizontalFilmFit: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kOverscanFilmFit: ClassVar[int] = ...
    kRotateTranslate: ClassVar[int] = ...
    kTranslateRotate: ClassVar[int] = ...
    kVerticalFilmFit: ClassVar[int] = ...
    cameraScale: Incomplete
    centerOfInterest: Incomplete
    fStop: Incomplete
    farClippingPlane: Incomplete
    farFocusDistance: Incomplete
    filmFit: Incomplete
    filmFitOffset: Incomplete
    filmRollOrder: Incomplete
    filmRollValue: Incomplete
    filmTranslateH: Incomplete
    filmTranslateV: Incomplete
    focalLength: Incomplete
    focusDistance: Incomplete
    horizontalFilmAperture: Incomplete
    horizontalFilmOffset: Incomplete
    horizontalPan: Incomplete
    horizontalRollPivot: Incomplete
    horizontalShake: Incomplete
    isClippingPlanes: Incomplete
    isDepthOfField: Incomplete
    isDisplayFilmGate: Incomplete
    isDisplayGateMask: Incomplete
    isMotionBlur: Incomplete
    isVerticalLock: Incomplete
    lensSqueezeRatio: Incomplete
    nearClippingPlane: Incomplete
    nearFocusDistance: Incomplete
    orthoWidth: Incomplete
    overscan: Incomplete
    panZoomEnabled: Incomplete
    postScale: Incomplete
    preScale: Incomplete
    renderPanZoom: Incomplete
    shakeEnabled: Incomplete
    shakeOverscan: Incomplete
    shakeOverscanEnabled: Incomplete
    shutterAngle: Incomplete
    stereoHIT: Incomplete
    stereoHITEnabled: Incomplete
    tumblePivot: Incomplete
    usePivotAsLocalSpace: Incomplete
    verticalFilmAperture: Incomplete
    verticalFilmOffset: Incomplete
    verticalPan: Incomplete
    verticalRollPivot: Incomplete
    verticalShake: Incomplete
    zoom: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def aspectRatio(self) -> float: ...
    def centerOfInterestPoint(self, space=...) -> MPoint: ...
    def computeDepthOfField(self, nearLimit=...) -> self: ...  # type: ignore
    def copyViewFrom(self, otherCamera) -> self: ...  # type: ignore
    def create(self, parent=...) -> MObject: ...  # type: ignore
    def eyePoint(self, space=...) -> MPoint: ...
    def getAspectRatioLimits(self, *args, **kwargs): ...
    def getFilmApertureLimits(self, *args, **kwargs): ...
    def getFilmFrustum(self, *args, **kwargs): ...
    def getFilmFrustumCorners(self, distance, applyPanZoom=...) -> MPointArray: ...
    def getFocalLengthLimits(self, *args, **kwargs): ...
    def getPortFieldOfView(self, *args, **kwargs): ...
    def getRenderingFrustum(self, *args, **kwargs): ...
    def getViewParameters(self, *args, **kwargs): ...
    def getViewingFrustum(self, *args, **kwargs): ...
    def hasSamePerspective(self, otherCamera) -> bool: ...
    def horizontalFieldOfView(self) -> float: ...
    def isOrtho(self) -> bool: ...
    def postProjectionMatrix(self, context=...) -> MFloatMatrix: ...
    def projectionMatrix(self, context=...) -> MFloatMatrix: ...
    def rightDirection(self, space=...) -> MVector: ...
    def set(self, wsEyeLocation, wsViewDirection, wsUpDirection, horizFieldOfView, aspectRatio) -> self: ...  # type: ignore
    def setAspectRatio(self, aspectRatio) -> self: ...  # type: ignore
    def setCenterOfInterestPoint(self, centerOfInterest, space=...) -> self: ...  # type: ignore
    def setEyePoint(self, eyeLocation, space=...) -> self: ...  # type: ignore
    def setHorizontalFieldOfView(self, fov) -> self: ...  # type: ignore
    def setIsOrtho(self, orthoState, useDist=...) -> self: ...  # type: ignore
    def setNearFarClippingPlanes(self, near, far) -> self: ...  # type: ignore
    def setVerticalFieldOfView(self, fov) -> self: ...  # type: ignore
    def upDirection(self, space=...) -> MVector: ...
    def verticalFieldOfView(self) -> float: ...
    def viewDirection(self, space=...) -> MVector: ...

class MFnComponent(MFnBase):
    componentType: Incomplete
    elementCount: Incomplete
    hasWeights: Incomplete
    isComplete: Incomplete
    isEmpty: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def isEqual(self, MObjectother) -> bool: ...
    def weight(self, index) -> MWeight: ...

class MFnComponentListData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def add(self, MObject) -> self: ...  # type: ignore
    def clear(self) -> self: ...  # type: ignore
    def create(self) -> MObject: ...
    def get(self, index) -> MObject: ...
    def has(self, MObject) -> bool: ...
    def length(self) -> int: ...
    @overload
    def remove(self, MObject) -> self: ...  # type: ignore
    @overload
    def remove(self, index) -> self: ...  # type: ignore

class MFnCompoundAttribute(MFnAttribute):
    def __init__(self, *args, **kwargs) -> None: ...
    def addChild(self, *args, **kwargs): ...
    def child(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def getAddAttrCmds(self, *args, **kwargs): ...
    def numChildren(self, *args, **kwargs): ...
    def removeChild(self, *args, **kwargs): ...

class MFnContainerNode(MFnDependencyNode):
    kChildAnchor: ClassVar[int] = ...
    kGeneric: ClassVar[int] = ...
    kParentAnchor: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def clear(self) -> Any: ...
    @staticmethod
    def getCurrentAsMObject() -> MObject: ...
    def getMembers(self) -> MObjectArray: ...
    def getParentContainer(self) -> MObject: ...
    def getPublishedNames(self, *args, **kwargs): ...
    def getPublishedNodes(self, *args, **kwargs): ...
    def getPublishedPlugs(self, *args, **kwargs): ...
    def getRootTransform(self) -> MObject: ...
    def getSubcontainers(self) -> MObjectArray: ...
    def isCurrent(self) -> bool: ...
    def makeCurrent(self, isCurrent) -> self: ...  # type: ignore

class MFnDagNode(MFnDependencyNode):
    kNextPos: ClassVar[int] = ...
    boundingBox: Incomplete
    inModel: Incomplete
    inUnderWorld: Incomplete
    isInstanceable: Incomplete
    isIntermediateObject: Incomplete
    objectColor: Incomplete
    objectColorRGB: Incomplete
    objectColorType: Incomplete
    useObjectColor: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def addChild(self, node, index=..., keepExistingParents=...) -> self: ...  # type: ignore
    def child(self, index) -> MObject: ...
    def childCount(self) -> int: ...
    def create(self, type, name=..., parent=...) -> MObject: ...
    def dagPath(self) -> MDagPath: ...
    def dagRoot(self) -> MObject: ...
    def duplicate(self, instance=..., instanceLeaf=...) -> MObject: ...
    def fullPathName(self) -> string: ...  # type: ignore
    def getAllPaths(self) -> MDagPathArray: ...
    def getConnectedSetsAndMembers(self, *args, **kwargs): ...
    def getPath(self) -> MDagPath: ...
    def hasChild(self, node) -> bool: ...
    def hasParent(self, node) -> bool: ...
    def instanceCount(self, indirect) -> int: ...
    def isChildOf(self, node) -> bool: ...
    def isInstanced(self, indirect=...) -> bool: ...
    def isInstancedAttribute(self, attr) -> bool: ...
    def isParentOf(self, node) -> bool: ...
    def parent(self, index) -> MObject: ...
    def parentCount(self) -> int: ...
    def partialPathName(self) -> string: ...  # type: ignore
    def removeChild(self, node) -> self: ...  # type: ignore
    def removeChildAt(self, index) -> self: ...  # type: ignore
    def setObject(self, MObjectorMDagPath) -> self: ...  # type: ignore
    def transformationMatrix(self) -> MMatrix: ...

class MFnData(MFnBase):
    kAny: ClassVar[int] = ...
    kComponentList: ClassVar[int] = ...
    kDoubleArray: ClassVar[int] = ...
    kDynArrayAttrs: ClassVar[int] = ...
    kDynSweptGeometry: ClassVar[int] = ...
    kFalloffFunction: ClassVar[int] = ...
    kFloatArray: ClassVar[int] = ...
    kIntArray: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kLattice: ClassVar[int] = ...
    kMatrix: ClassVar[int] = ...
    kMatrixArray: ClassVar[int] = ...
    kMesh: ClassVar[int] = ...
    kNId: ClassVar[int] = ...
    kNObject: ClassVar[int] = ...
    kNumeric: ClassVar[int] = ...
    kNurbsCurve: ClassVar[int] = ...
    kNurbsSurface: ClassVar[int] = ...
    kPlugin: ClassVar[int] = ...
    kPluginGeometry: ClassVar[int] = ...
    kPointArray: ClassVar[int] = ...
    kSphere: ClassVar[int] = ...
    kString: ClassVar[int] = ...
    kStringArray: ClassVar[int] = ...
    kSubdSurface: ClassVar[int] = ...
    kVectorArray: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...

class MFnDependencyNode(MFnBase):
    kExtensionAttr: ClassVar[int] = ...
    kInvalidAttr: ClassVar[int] = ...
    kLocalDynamicAttr: ClassVar[int] = ...
    kNormalAttr: ClassVar[int] = ...
    kTimerInvalidState: ClassVar[int] = ...
    kTimerMetric_callback: ClassVar[int] = ...
    kTimerMetric_callbackNotViaAPI: ClassVar[int] = ...
    kTimerMetric_callbackViaAPI: ClassVar[int] = ...
    kTimerMetric_compute: ClassVar[int] = ...
    kTimerMetric_computeDuringCallback: ClassVar[int] = ...
    kTimerMetric_computeNotDuringCallback: ClassVar[int] = ...
    kTimerMetric_dirty: ClassVar[int] = ...
    kTimerMetric_draw: ClassVar[int] = ...
    kTimerMetric_fetch: ClassVar[int] = ...
    kTimerMetrics: ClassVar[int] = ...
    kTimerOff: ClassVar[int] = ...
    kTimerOn: ClassVar[int] = ...
    kTimerType_count: ClassVar[int] = ...
    kTimerType_inclusive: ClassVar[int] = ...
    kTimerType_self: ClassVar[int] = ...
    kTimerTypes: ClassVar[int] = ...
    kTimerUninitialized: ClassVar[int] = ...
    isDefaultNode: Incomplete
    isFromReferencedFile: Incomplete
    isLocked: Incomplete
    isShared: Incomplete
    namespace: Incomplete
    pluginName: Incomplete
    typeId: Incomplete
    typeName: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def absoluteName(self) -> Any: ...
    def addAttribute(self, *args, **kwargs): ...
    def addExternalContentForFileAttr(self, *args, **kwargs): ...
    def affectsAnimation(self, *args, **kwargs): ...
    @staticmethod
    def allocateFlag(*args, **kwargs): ...
    def attribute(self, *args, **kwargs): ...
    def attributeClass(self, *args, **kwargs): ...
    def attributeCount(self, *args, **kwargs): ...
    def canBeWritten(self, *args, **kwargs): ...
    @staticmethod
    def classification(*args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    @staticmethod
    def deallocateAllFlags(*args, **kwargs): ...
    @staticmethod
    def deallocateFlag(*args, **kwargs): ...
    def dgCallbackIds(self, *args, **kwargs): ...
    def dgCallbacks(self, *args, **kwargs): ...
    def dgTimer(self, *args, **kwargs): ...
    def dgTimerOff(self, *args, **kwargs): ...
    def dgTimerOn(self, *args, **kwargs): ...
    def dgTimerQueryState(self, *args, **kwargs): ...
    def dgTimerReset(self, *args, **kwargs): ...
    def findAlias(self, *args, **kwargs): ...
    def findPlug(self, *args, **kwargs): ...
    def getAffectedAttributes(self, *args, **kwargs): ...
    def getAffectingAttributes(self, *args, **kwargs): ...
    def getAliasAttr(self, *args, **kwargs): ...
    def getAliasList(self, *args, **kwargs): ...
    def getConnections(self, *args, **kwargs): ...
    def getExternalContent(self, *args, **kwargs): ...
    def hasAttribute(self, *args, **kwargs): ...
    def hasUniqueName(self, *args, **kwargs): ...
    def isFlagSet(self, *args, **kwargs): ...
    def isNewAttribute(self, *args, **kwargs): ...
    def isTrackingEdits(self, *args, **kwargs): ...
    def name(self, *args, **kwargs): ...
    def plugsAlias(self, *args, **kwargs): ...
    def removeAttribute(self, *args, **kwargs): ...
    def reorderedAttribute(self, *args, **kwargs): ...
    def setAffectsAnimation(self, *args, **kwargs): ...
    def setAlias(self, *args, **kwargs): ...
    def setDoNotWrite(self, *args, **kwargs): ...
    def setExternalContent(self, *args, **kwargs): ...
    def setExternalContentForFileAttr(self, *args, **kwargs): ...
    def setFlag(self, *args, **kwargs): ...
    def setName(self, *args, **kwargs): ...
    def setUuid(self, *args, **kwargs): ...
    def uniqueName(self, *args, **kwargs): ...
    def userNode(self, *args, **kwargs): ...
    def uuid(self, *args, **kwargs): ...

class MFnDisplayLayer(MFnDependencyNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def add(self, item) -> status: ...  # type: ignore
    def contains(self, item) -> bool: ...
    def containsAncestorInclusive(self, item) -> status: ...  # type: ignore
    def getMembers(self, members) -> status: ...  # type: ignore
    def remove(self, item) -> status: ...  # type: ignore

class MFnDisplayLayerManager(MFnDependencyNode):
    def __init__(self, *args, **kwargs) -> None: ...
    @staticmethod
    def currentDisplayLayerManager() -> MObject: ...
    def getAllDisplayLayers(self) -> objectarray: ...  # type: ignore
    def getAncestorLayersInclusive(self, item) -> status: ...  # type: ignore
    def getLayer(self, item) -> status: ...  # type: ignore

class MFnDoubleArrayData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def array(self, *args, **kwargs): ...
    def copyTo(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...
    def __setitem__(self, index, object) -> None: ...

class MFnDoubleIndexedComponent(MFnComponent):
    def __init__(self, *args, **kwargs) -> None: ...
    def addElement(self, uIndex, vIndex) -> self: ...  # type: ignore
    def addElements(self, *args, **kwargs): ...
    def create(self, MFnTypeconstant) -> MObject: ...
    def getCompleteData(self, *args, **kwargs): ...
    def getElement(self, *args, **kwargs): ...
    def getElements(self, *args, **kwargs): ...
    def setCompleteData(self, numU, numV) -> self: ...  # type: ignore

class MFnEnumAttribute(MFnAttribute):
    default: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def addField(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def fieldName(self, *args, **kwargs): ...
    def fieldValue(self, *args, **kwargs): ...
    def getMax(self, *args, **kwargs): ...
    def getMin(self, *args, **kwargs): ...
    def setDefaultByName(self, *args, **kwargs): ...

class MFnGenericAttribute(MFnAttribute):
    def __init__(self, *args, **kwargs) -> None: ...
    def addDataType(self, *args, **kwargs): ...
    def addNumericType(self, *args, **kwargs): ...
    def addTypeId(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def removeDataType(self, *args, **kwargs): ...
    def removeNumericType(self, *args, **kwargs): ...
    def removeTypeId(self, *args, **kwargs): ...

class MFnGeometryData(MFnData):
    kAuto: ClassVar[int] = ...
    kCompleteGroup: ClassVar[int] = ...
    kEdges: ClassVar[int] = ...
    kEmptyGroup: ClassVar[int] = ...
    kFaces: ClassVar[int] = ...
    kInvalidGroup: ClassVar[int] = ...
    kNull: ClassVar[int] = ...
    kPartialGroup: ClassVar[int] = ...
    kUnsupported: ClassVar[int] = ...
    kVerts: ClassVar[int] = ...
    isIdentity: Incomplete
    isNotIdentity: Incomplete
    matrix: Incomplete
    objectGroupCount: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def addComponentTag(self, key) -> self: ...  # type: ignore
    def addObjectGroup(self, id) -> self: ...  # type: ignore
    def addObjectGroupComponent(self, id, MObjectcomponent) -> self: ...  # type: ignore
    def changeObjectGroupId(self, sourceId, destId) -> self: ...  # type: ignore
    def componentTagContents(self, key) -> MObject: ...
    def componentTagExpressionSubsetState(self, *args, **kwargs): ...
    def componentTagType(self, key) -> MFnTypeconstant: ...  # type: ignore
    def componentTags(self) -> MObject: ...
    def copyObjectGroups(self, MObjectinGeom) -> self: ...  # type: ignore
    def hasComponentTag(self, key) -> bool: ...
    def hasObjectGroup(self, id) -> self: ...  # type: ignore
    def objectGroup(self, index) -> int: ...
    def objectGroupComponent(self, id) -> MObject: ...
    def objectGroupSubsetState(self, *args, **kwargs): ...
    def objectGroupType(self, id) -> MFnTypeconstant: ...  # type: ignore
    def removeComponentTag(self, key) -> self: ...  # type: ignore
    def removeObjectGroup(self, id) -> self: ...  # type: ignore
    def removeObjectGroupComponent(self, id, MObjectcomponent) -> self: ...  # type: ignore
    def renameComponentTag(self, key, newKey) -> self: ...  # type: ignore
    def resolveComponentTagExpression(self, key, ctg) -> MObject: ...
    def setComponentTagContents(self, key, MObjectcomponent) -> self: ...  # type: ignore
    def setObjectGroupComponent(self, id, MObjectcomponent) -> self: ...  # type: ignore

class MFnIntArrayData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def array(self, *args, **kwargs): ...
    def copyTo(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...
    def __setitem__(self, index, object) -> None: ...

class MFnLightDataAttribute(MFnAttribute):
    default: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def child(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...

class MFnMatrixArrayData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def array(self, *args, **kwargs): ...
    def copyTo(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...
    def __setitem__(self, index, object) -> None: ...

class MFnMatrixAttribute(MFnAttribute):
    kDouble: ClassVar[int] = ...
    kFloat: ClassVar[int] = ...
    default: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, *args, **kwargs): ...

class MFnMatrixData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, *args, **kwargs): ...
    def isTransformation(self, *args, **kwargs): ...
    def matrix(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def transformation(self, *args, **kwargs): ...

class MFnMesh(MFnDagNode):
    kAlpha: ClassVar[int] = ...
    kDifference: ClassVar[int] = ...
    kEdgeClassification: ClassVar[int] = ...
    kGeomBorder: ClassVar[int] = ...
    kInstanceUnspecified: ClassVar[int] = ...
    kInternalPoint: ClassVar[int] = ...
    kIntersectTolerance: ClassVar[float] = ...
    kIntersection: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kNormalClassification: ClassVar[int] = ...
    kOnEdge: ClassVar[int] = ...
    kPointTolerance: ClassVar[float] = ...
    kRGB: ClassVar[int] = ...
    kRGBA: ClassVar[int] = ...
    kSharedUV: ClassVar[int] = ...
    kUVBorder: ClassVar[int] = ...
    kUnion: ClassVar[int] = ...
    kUnsharedUV: ClassVar[int] = ...
    checkSamePointTwice: Incomplete
    displayColors: Incomplete
    numColorSets: Incomplete
    numEdges: Incomplete
    numFaceVertices: Incomplete
    numNormals: Incomplete
    numPolygons: Incomplete
    numUVSets: Incomplete
    numVertices: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def addHoles(self, faceIndex, vertices, loopCounts, mergeVertices=..., pointTolerance=...) -> self: ...  # type: ignore
    def addPolygon(self, vertices, mergeVertices=..., pointTolerance=..., loopCounts=...) -> faceId: ...  # type: ignore
    def allIntersections(self) -> Any: ...
    def anyIntersection(self) -> Any: ...
    def assignColor(self, faceId, vertexIndex, colorId, colorSet=...) -> self: ...  # type: ignore
    def assignColors(self, colorIds, colorSet=...) -> self: ...  # type: ignore
    def assignUV(self, faceId, vertexIndex, uvId, uvSet=...) -> self: ...  # type: ignore
    def assignUVs(self, uvCounts, uvIds, uvSet=...) -> self: ...  # type: ignore
    @staticmethod
    def autoUniformGridParams() -> MMeshIsectAccelParams: ...
    def booleanOp(self, *args, **kwargs): ...
    def booleanOps(self, BooleanOperationconstant, MObjectArray, bool) -> self: ...  # type: ignore
    def cachedIntersectionAcceleratorInfo(self) -> string: ...  # type: ignore
    def cleanupEdgeSmoothing(self) -> self: ...  # type: ignore
    @overload
    def clearBlindData(self, compType) -> self: ...  # type: ignore
    @overload
    def clearBlindData(self, compType, blindDataId, compId=..., attr=...) -> self: ...  # type: ignore
    @overload
    def clearColors(self, colorSet=...) -> self: ...  # type: ignore
    @overload
    def clearColors(self) -> Any: ...  # type: ignore
    @staticmethod
    def clearGlobalIntersectionAcceleratorInfo() -> Any: ...
    @overload
    def clearUVs(self, uvSet=...) -> self: ...  # type: ignore
    @overload
    def clearUVs(self) -> Any: ...  # type: ignore
    def closestIntersection(self, *args, **kwargs): ...
    def collapseEdges(self, seqofint) -> self: ...  # type: ignore
    def collapseFaces(self, seqofint) -> self: ...  # type: ignore
    def copy(self, MObject, parent=...) -> MObject: ...
    def copyInPlace(self, MObject) -> self: ...  # type: ignore
    def copyUVSet(self, fromName, toName, modifier=...) -> string: ...  # type: ignore
    def create(self) -> Any: ...  # type: ignore
    def createBlindDataType(self, *args, **kwargs): ...
    def createColorSet(self, name, clamped, rep=..., modifier=..., instances=...) -> string: ...  # type: ignore
    def createInPlace(self, *args, **kwargs): ...
    def createUVSet(self, name, modifier=..., instances=...) -> string: ...  # type: ignore
    def currentColorSetName(self, instance=...) -> string: ...  # type: ignore
    def currentUVSetName(self, instance=...) -> string: ...  # type: ignore
    def deleteColorSet(self, colorSet, modifier=..., currentSelection=...) -> self: ...  # type: ignore
    def deleteEdge(self, edgeId, modifier=...) -> self: ...  # type: ignore
    def deleteFace(self, faceId, modifier=...) -> self: ...  # type: ignore
    def deleteUVSet(self, uvSet, modifier=..., currentSelection=...) -> self: ...  # type: ignore
    def deleteVertex(self, vertexId, modifier=...) -> self: ...  # type: ignore
    def duplicateFaces(self, faces, translation=...) -> self: ...  # type: ignore
    def edgeBorderInfo(self, *args, **kwargs): ...
    def extractFaces(self, faces, translation=...) -> self: ...  # type: ignore
    def extrudeEdges(self, edges, extrusionCount=..., translation=..., extrudeTogether=..., thickness=..., offset=...) -> self: ...  # type: ignore
    def extrudeFaces(self, faces, extrusionCount=..., translation=..., extrudeTogether=..., thickness=..., offset=...) -> self: ...  # type: ignore
    def freeCachedIntersectionAccelerator(self) -> self: ...  # type: ignore
    def generateSmoothMesh(self, parent=..., options=...) -> MObject: ...
    def getAssignedUVs(self, *args, **kwargs): ...
    def getAssociatedColorSetInstances(self, colorSet) -> MIntArray: ...
    def getAssociatedUVSetInstances(self, uvSet) -> MIntArray: ...
    def getAssociatedUVSetTextures(self, uvSet) -> MObjectArray: ...
    @overload
    def getBinaryBlindData(self, compId, compType, blindDataId, attr) -> string: ...  # type: ignore
    @overload
    def getBinaryBlindData(self, compType, blindDataId, attr) -> Any: ...
    def getBinormals(self, space=..., uvSet=...) -> MFloatVectorArray: ...
    def getBlindDataAttrNames(self, *args, **kwargs): ...
    def getBlindDataTypes(self, MFnTypeconstant) -> MIntArray: ...
    def getBoolBlindData(self, compId, compType, blindDataId, attr) -> bool: ...
    def getClosestNormal(self, *args, **kwargs): ...
    def getClosestPoint(self, *args, **kwargs): ...
    def getClosestPointAndNormal(self, MPoint, space=...) -> Any: ...
    def getClosestUVs(self, u, v, uvSet=...) -> MIntArray: ...
    def getColor(self, colorId, colorSet=...) -> MColor: ...
    def getColorIndex(self, faceId, localVertexId, colorSet=...) -> int: ...
    def getColorRepresentation(self, colorSet) -> ColorRepresentationconstant: ...  # type: ignore
    def getColorSetFamilyNames(self, *args, **kwargs): ...
    def getColorSetNames(self, *args, **kwargs): ...
    def getColorSetsInFamily(self, *args, **kwargs): ...
    def getColors(self, colorSet=...) -> MColorArray: ...
    def getConnectedShaders(self, *args, **kwargs): ...
    def getCreaseEdges(self, *args, **kwargs): ...
    def getCreaseVertices(self, *args, **kwargs): ...
    def getDoubleBlindData(self, compId, compType, blindDataId, attr) -> float: ...
    def getEdgeVertices(self, *args, **kwargs): ...
    def getFaceAndVertexIndices(self, *args, **kwargs): ...
    def getFaceNormalIds(self, faceId) -> MIntArray: ...
    def getFaceUVSetNames(self, *args, **kwargs): ...
    def getFaceVertexBinormal(self, faceId, vertexId, space=..., uvSet=...) -> MVector: ...
    def getFaceVertexBinormals(self, faceId, space=..., uvSet=...) -> MFloatVectorArray: ...
    def getFaceVertexColors(self, colorSet=..., defaultUnsetColor=...) -> MColorArray: ...
    def getFaceVertexIndex(self, faceId, vertexIndex, localVertex=...) -> int: ...
    def getFaceVertexNormal(self, faceId, vertexId, space=...) -> MVector: ...
    def getFaceVertexNormals(self, faceId, space=...) -> MFloatVectorArray: ...
    def getFaceVertexTangent(self, faceId, vertexId, space=..., uvSet=...) -> MVector: ...
    def getFaceVertexTangents(self, faceId, space=..., uvSet=...) -> MFloatVectorArray: ...
    def getFloatBlindData(self, compId, compType, blindDataId, attr) -> float: ...
    def getFloatPoints(self, space=...) -> MFloatPointArray: ...
    def getHoles(self, *args, **kwargs): ...
    def getIntBlindData(self, compId, compType, blindDataId, attr) -> int: ...
    def getInvisibleFaces(self) -> MUintArray: ...
    def getMeshShellsIds(self, *args, **kwargs): ...
    def getNormalIds(self, *args, **kwargs): ...
    def getNormals(self, space=...) -> MFloatVectorArray: ...
    def getPoint(self, vertexId, space=...) -> MPoint: ...
    def getPointAtUV(self, faceId, u, v, space=..., uvSet=..., tolerance=...) -> MPoint: ...
    def getPoints(self, space=...) -> MPointArray: ...
    def getPointsAtUV(self, *args, **kwargs): ...
    def getPolygonNormal(self, polygonId, space=...) -> MVector: ...
    def getPolygonTriangleVertices(self, *args, **kwargs): ...
    def getPolygonUV(self, *args, **kwargs): ...
    def getPolygonUVid(self, polygonId, vertexId, uvSet=...) -> int: ...
    def getPolygonVertices(self, polygonId) -> MIntArray: ...
    def getSmoothMeshDisplayOptions(self) -> MMeshSmoothOptions: ...
    @overload
    def getStringBlindData(self, compId, compType, blindDataId, attr) -> string: ...  # type: ignore
    @overload
    def getStringBlindData(self, compType, blindDataId, attr) -> Any: ...
    def getTangentId(self, faceId, vertexId) -> int: ...
    def getTangents(self, space=..., uvSet=...) -> MFloatVectorArray: ...
    def getTriangleOffsets(self, *args, **kwargs): ...
    def getTriangles(self, *args, **kwargs): ...
    def getUV(self, *args, **kwargs): ...
    def getUVAtPoint(self, *args, **kwargs): ...
    def getUVBorderEdges(self, setId) -> MIntArray: ...
    def getUVSetFamilyNames(self, *args, **kwargs): ...
    def getUVSetNames(self, *args, **kwargs): ...
    def getUVSetsInFamily(self, *args, **kwargs): ...
    def getUVs(self, *args, **kwargs): ...
    def getUvShellsIds(self, *args, **kwargs): ...
    def getVertexColors(self, colorSet=..., defaultUnsetColor=...) -> MColorArray: ...
    def getVertexNormal(self, vertexId, angleWeighted, space=...) -> MVector: ...
    def getVertexNormals(self, angleWeighted, space=...) -> MFloatVectorArray: ...
    def getVertices(self, *args, **kwargs): ...
    @staticmethod
    def globalIntersectionAcceleratorsInfo() -> string: ...  # type: ignore
    def hasAlphaChannels(self, colorSet) -> bool: ...
    def hasBlindData(self, compType, compId=..., blindDataId=...) -> bool: ...
    def hasColorChannels(self, colorSet) -> bool: ...
    def intersectFaceAtUV(self, u, v, uvSet=...) -> int: ...
    def isBlindDataTypeUsed(self, blindDataId) -> bool: ...
    def isColorClamped(self, colorSet) -> bool: ...
    def isColorSetPerInstance(self, colorSet) -> bool: ...
    def isEdgeSmooth(self, edgeId) -> bool: ...
    def isNormalLocked(self, normalId) -> bool: ...
    def isPolygonConvex(self, faceId) -> bool: ...
    def isPolygonUVReversed(self, faceId) -> bool: ...
    def isRightHandedTangent(self, tangentId, uvSet=...) -> bool: ...
    def isUVSetPerInstance(self, uvSet) -> bool: ...
    def lockFaceVertexNormals(self, seqoffaceIds, seqofvertIds) -> self: ...  # type: ignore
    def lockVertexNormals(self, sequenceofvertIds) -> self: ...  # type: ignore
    def numColors(self, colorSet=...) -> int: ...
    def numUVs(self, uvSet=...) -> int: ...
    def onBoundary(self, faceId) -> bool: ...
    def polygonVertexCount(self, faceId) -> int: ...
    def removeFaceColors(self, seqoffaceIds) -> self: ...  # type: ignore
    def removeFaceVertexColors(self, seqoffaceIds, seqofvertexIds) -> self: ...  # type: ignore
    def removeVertexColors(self, seqofvertexIds) -> self: ...  # type: ignore
    def renameUVSet(self, origName, newName, modifier=...) -> self: ...  # type: ignore
    @overload
    def setBinaryBlindData(self, compId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setBinaryBlindData(self, seqofcompId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setBoolBlindData(self, compId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setBoolBlindData(self, seqofcompId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    def setColor(self, colorId, MColor, colorSet=..., rep=...) -> self: ...  # type: ignore
    def setColors(self, seqofMColor, colorSet=..., rep=...) -> self: ...  # type: ignore
    def setCreaseEdges(self, edgeIds, seqoffloat) -> self: ...  # type: ignore
    def setCreaseVertices(self, edgeIds, seqoffloat) -> self: ...  # type: ignore
    def setCurrentColorSetName(self, colorSet, modifier=..., currentSelection=...) -> self: ...  # type: ignore
    def setCurrentUVSetName(self, uvSet, modifier=..., currentSelection=...) -> self: ...  # type: ignore
    @overload
    def setDoubleBlindData(self, compId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setDoubleBlindData(self, seqofcompId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setEdgeSmoothing(self, edgeId, smooth=...) -> self: ...  # type: ignore
    @overload
    def setEdgeSmoothing(self) -> Any: ...
    @overload
    def setEdgeSmoothings(self, edgeIds, smooths) -> self: ...  # type: ignore
    @overload
    def setEdgeSmoothings(self) -> Any: ...
    def setFaceColor(self, color, faceId, rep=...) -> self: ...  # type: ignore
    def setFaceColors(self, colors, faceIds, rep=...) -> self: ...  # type: ignore
    def setFaceVertexColor(self, color, faceId, vertexId, modifier=..., rep=...) -> self: ...  # type: ignore
    def setFaceVertexColors(self, colors, faceIds, vertexIds, modifier=..., rep=...) -> self: ...  # type: ignore
    def setFaceVertexNormal(self, normal, faceId, vertexId, space=..., modifier=...) -> self: ...  # type: ignore
    def setFaceVertexNormals(self, *args, **kwargs): ...
    @overload
    def setFloatBlindData(self, compId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setFloatBlindData(self, seqofcompId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setIntBlindData(self, compId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setIntBlindData(self, seqofcompId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    def setInvisibleFaces(self, faceIds, makeVisible=...) -> self: ...  # type: ignore
    def setIsColorClamped(self, colorSet, clamped) -> self: ...  # type: ignore
    def setNormals(self, normals, space=...) -> self: ...  # type: ignore
    @overload
    def setPoint(self, vertexId, MPoint, space=...) -> self: ...  # type: ignore
    @overload
    def setPoint(self) -> Any: ...
    def setPoints(self, points, space=...) -> self: ...  # type: ignore
    def setSmoothMeshDisplayOptions(self, MMeshSmoothOptions) -> self: ...  # type: ignore
    def setSomeColors(self, colorIds, colors, colorSet=..., rep=...) -> self: ...  # type: ignore
    def setSomeUVs(self, uvIds, uValues, vValues, uvSet=...) -> self: ...  # type: ignore
    @overload
    def setStringBlindData(self, compId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    @overload
    def setStringBlindData(self, seqofcompId, compType, blindDataId, attr, data) -> self: ...  # type: ignore
    def setUV(self, uvId, u, v, uvSet=...) -> self: ...  # type: ignore
    def setUVs(self, uValues, vValues, uvSet=...) -> self: ...  # type: ignore
    def setVertexColor(self, color, vertexId, modifier=..., rep=...) -> self: ...  # type: ignore
    def setVertexColors(self, colors, vertexIds, modifier=..., rep=...) -> self: ...  # type: ignore
    def setVertexNormal(self, normal, vertexId, space=..., modifier=...) -> self: ...  # type: ignore
    def setVertexNormals(self, *args, **kwargs): ...
    def sortIntersectionFaceTriIds(self, faceIds, triIds=...) -> self: ...  # type: ignore
    def split(self, *args, **kwargs): ...
    def subdivideEdges(self, edges, numDivisions) -> self: ...  # type: ignore
    def subdivideFaces(self, faces, numDivisions) -> self: ...  # type: ignore
    def syncObject(self) -> self: ...  # type: ignore
    @staticmethod
    def uniformGridParams(xDiv, yDiv, zDiv) -> MMeshIsectAccelParams: ...
    def unlockFaceVertexNormals(self, seqoffaceIds, seqofvertIds) -> self: ...  # type: ignore
    def unlockVertexNormals(self, sequenceofvertIds) -> self: ...  # type: ignore
    def updateSurface(self) -> self: ...  # type: ignore

class MFnMeshData(MFnGeometryData):
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self) -> MObject: ...

class MFnMessageAttribute(MFnAttribute):
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, *args, **kwargs): ...

class MFnNumericAttribute(MFnAttribute):
    default: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def child(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def createAddr(self, *args, **kwargs): ...
    def createColor(self, *args, **kwargs): ...
    def createPoint(self, *args, **kwargs): ...
    def getMax(self, *args, **kwargs): ...
    def getMin(self, *args, **kwargs): ...
    def getSoftMax(self, *args, **kwargs): ...
    def getSoftMin(self, *args, **kwargs): ...
    def hasMax(self, *args, **kwargs): ...
    def hasMin(self, *args, **kwargs): ...
    def hasSoftMax(self, *args, **kwargs): ...
    def hasSoftMin(self, *args, **kwargs): ...
    def numericType(self, *args, **kwargs): ...
    def setMax(self, *args, **kwargs): ...
    def setMin(self, *args, **kwargs): ...
    def setSoftMax(self, *args, **kwargs): ...
    def setSoftMin(self, *args, **kwargs): ...

class MFnNumericData(MFnData):
    k2Double: ClassVar[int] = ...
    k2Float: ClassVar[int] = ...
    k2Int: ClassVar[int] = ...
    k2Long: ClassVar[int] = ...
    k2Short: ClassVar[int] = ...
    k3Double: ClassVar[int] = ...
    k3Float: ClassVar[int] = ...
    k3Int: ClassVar[int] = ...
    k3Long: ClassVar[int] = ...
    k3Short: ClassVar[int] = ...
    k4Double: ClassVar[int] = ...
    kAddr: ClassVar[int] = ...
    kBoolean: ClassVar[int] = ...
    kByte: ClassVar[int] = ...
    kChar: ClassVar[int] = ...
    kDouble: ClassVar[int] = ...
    kFloat: ClassVar[int] = ...
    kInt: ClassVar[int] = ...
    kInt64: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kLong: ClassVar[int] = ...
    kShort: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, *args, **kwargs): ...
    def getData(self, *args, **kwargs): ...
    def numericType(self, *args, **kwargs): ...
    def setData(self, *args, **kwargs): ...

class MFnNurbsCurve(MFnDagNode):
    kClosed: ClassVar[int] = ...
    kFindParamTolerance: ClassVar[float] = ...
    kInvalid: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kOpen: ClassVar[int] = ...
    kPeriodic: ClassVar[int] = ...
    kPointTolerance: ClassVar[float] = ...
    degree: Incomplete
    form: Incomplete
    hasHistoryOnCreate: Incomplete
    isPlanar: Incomplete
    knotDomain: Incomplete
    numCVs: Incomplete
    numKnots: Incomplete
    numSpans: Incomplete
    planeNormal: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def area(self, tolerance=...) -> float: ...
    def closestPoint(self, *args, **kwargs): ...
    def copy(self, source, parent=...) -> MObject: ...
    @overload  # type: ignore
    def create(self, cvs, knots, degree, form, is2D, rational, parent=...) -> Any: ...
    @overload
    def create(self, subCurves, parent=...) -> self: ...  # type: ignore
    def createWithEditPoints(self, eps, degree, form, is2D, rational, uniform, 
parent=...) -> MObject: ...
    def cvPosition(self, index, space=...) -> MPoint: ...
    def cvPositions(self, space=...) -> MPointArray: ...
    def cvs(self, *args, **kwargs): ...
    def distanceToPoint(self, point, space=...) -> float: ...
    def findLengthFromParam(self, param) -> float: ...
    def findParamFromLength(self, length, tolerance=...) -> float: ...
    def getDerivativesAtParam(self, *args, **kwargs): ...
    def getParamAtPoint(self, point, tolerance=..., space=...) -> float: ...
    def getPointAtParam(self, param, space=...) -> MPoint: ...
    def isParamOnCurve(self, param) -> bool: ...
    def isPointOnCurve(self, point, tolerance=..., space=...) -> bool: ...
    def knot(self, index) -> float: ...
    def knots(self) -> MDoubleArray: ...
    def length(self, tolerance=...) -> float: ...
    def makeMultipleEndKnots(self) -> self: ...  # type: ignore
    def normal(self, param, space=...) -> MVector: ...
    def removeKnot(self, param, removeAll=...) -> self: ...  # type: ignore
    def reverse(self) -> self: ...  # type: ignore
    def setCVPosition(self, index, point, space=...) -> self: ...  # type: ignore
    def setCVPositions(self, points, space=...) -> self: ...  # type: ignore
    def setKnot(self, index, param) -> self: ...  # type: ignore
    def setKnots(self, params, startIndex, endIndex) -> self: ...  # type: ignore
    def tangent(self, param, space=...) -> MVector: ...
    def updateCurve(self) -> self: ...  # type: ignore

class MFnNurbsCurveData(MFnGeometryData):
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self) -> MObject: ...

class MFnNurbsSurface(MFnDagNode):
    kClosed: ClassVar[int] = ...
    kClosedSegment: ClassVar[int] = ...
    kInner: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kInvalidBoundary: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kOpen: ClassVar[int] = ...
    kOuter: ClassVar[int] = ...
    kPeriodic: ClassVar[int] = ...
    kPointTolerance: ClassVar[float] = ...
    kSegment: ClassVar[int] = ...
    dataObject: Incomplete
    degreeInU: Incomplete
    degreeInV: Incomplete
    formInU: Incomplete
    formInV: Incomplete
    hasHistoryOnCreate: Incomplete
    isBezier: Incomplete
    isFoldedOnBispan: Incomplete
    isTrimmedSurface: Incomplete
    isUniform: Incomplete
    knotDomainInU: Incomplete
    knotDomainInV: Incomplete
    numCVsInU: Incomplete
    numCVsInV: Incomplete
    numKnotsInU: Incomplete
    numKnotsInV: Incomplete
    numNonZeroSpansInU: Incomplete
    numNonZeroSpansInV: Incomplete
    numPatches: Incomplete
    numPatchesInU: Incomplete
    numPatchesInV: Incomplete
    numRegions: Incomplete
    numSpansInU: Incomplete
    numSpansInV: Incomplete
    numUVs: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def area(self, space=..., tolerance=...) -> float: ...
    def assignUV(self, patchId, cornerIndex, uvId) -> self: ...  # type: ignore
    def assignUVs(self, uvCounts, uvIds) -> self: ...  # type: ignore
    def boundaryType(self, region, boundary) -> int: ...
    def clearUVs(self) -> self: ...  # type: ignore
    def closestPoint(self, *args, **kwargs): ...
    def copy(self, source, parent=...) -> MObject: ...
    def create(self, *args, **kwargs): ...
    def cv(self, uIndex, vIndex) -> MObject: ...
    def cvPosition(self, uIndex, vIndex, space=...) -> MPoint: ...
    def cvPositions(self, space=...) -> MPointArray: ...
    def cvsInU(self, startUIndex, endUIndex, vIndex) -> MObject: ...
    def cvsInV(self, startVIndex, endVIndex, uIndex) -> MObject: ...
    def distanceToPoint(self, point, space=...) -> float: ...
    @overload
    def edge(self, region, boundary, edge, paramEdge=...) -> MObjectArray: ...
    @overload
    def edge(self, int) -> Any: ...
    def getAssignedUVs(self, *args, **kwargs): ...
    def getConnectedShaders(self, *args, **kwargs): ...
    def getDerivativesAtParam(self, uParam, vParam, space=..., secondOrder=...) -> Any: ...
    def getParamAtPoint(self, *args, **kwargs): ...
    def getPatchUV(self, *args, **kwargs): ...
    def getPatchUVid(self, patchId, cornerIndex) -> int: ...
    def getPatchUVs(self, *args, **kwargs): ...
    def getPointAtParam(self, uParam, vParam, space=...) -> MPoint: ...
    def getUV(self, *args, **kwargs): ...
    def getUVs(self, *args, **kwargs): ...
    def intersect(self, rayStart, rayDir, tolerance=..., space=..., 
distance=..., exactHit=..., all=...) -> Any: ...
    def isFlipNorm(self, region) -> bool: ...
    def isKnotU(self, param) -> bool: ...
    def isKnotV(self, param) -> bool: ...
    def isParamOnSurface(self, uParam, vParam) -> bool: ...
    def isPointInTrimmedRegion(self, uParam, vParam) -> bool: ...
    def isPointOnSurface(self, point, tolerance=..., space=...) -> bool: ...
    def knotInU(self, index) -> float: ...
    def knotInV(self, index) -> float: ...
    def knotsInU(self) -> MDoubleArray: ...
    def knotsInV(self) -> MDoubleArray: ...
    def normal(self, uParam, vParam, space=...) -> MVector: ...
    def numBoundaries(self, region) -> unsignedint: ...  # type: ignore
    def numEdges(self, region, boundary) -> unsignedint: ...  # type: ignore
    def projectCurve(self, *args, **kwargs): ...
    def removeKnotInU(self, param, removeAll=...) -> self: ...  # type: ignore
    def removeKnotInV(self, param, removeAll=...) -> self: ...  # type: ignore
    def removeOneKnotInU(self, param) -> self: ...  # type: ignore
    def removeOneKnotInV(self, param) -> self: ...  # type: ignore
    def setCVPosition(self, uIndex, vIndex, point, space=...) -> self: ...  # type: ignore
    def setCVPositions(self, points, space=...) -> self: ...  # type: ignore
    def setKnotInU(self, index, param) -> self: ...  # type: ignore
    def setKnotInV(self, index, param) -> self: ...  # type: ignore
    def setKnotsInU(self, params, startIndex, endIndex) -> self: ...  # type: ignore
    def setKnotsInV(self, params, startIndex, endIndex) -> self: ...  # type: ignore
    def setUV(self, uvId, u, v) -> self: ...  # type: ignore
    def setUVs(self, uList, vList) -> self: ...  # type: ignore
    def tangents(self, *args, **kwargs): ...
    def trim(self, regionsToKeepU, regionsToKeepV, keepHistory=...) -> self: ...  # type: ignore
    def updateSurface(self) -> self: ...  # type: ignore

class MFnNurbsSurfaceData(MFnGeometryData):
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self) -> MObject: ...

class MFnPlugin(MFnBase):
    version: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def apiVersion(self, *args, **kwargs): ...
    def deregisterAttributePatternFactory(self, *args, **kwargs): ...
    def deregisterCommand(self, *args, **kwargs): ...
    def deregisterContextCommand(self, *args, **kwargs): ...
    def deregisterData(self, *args, **kwargs): ...
    def deregisterDragAndDropBehavior(self, *args, **kwargs): ...
    def deregisterNode(self, *args, **kwargs): ...
    @staticmethod
    def findPlugin(*args, **kwargs): ...
    def loadPath(self, *args, **kwargs): ...
    def name(self, *args, **kwargs): ...
    def registerAttributePatternFactory(self, *args, **kwargs): ...
    def registerCommand(self, *args, **kwargs): ...
    def registerContextCommand(self, *args, **kwargs): ...
    def registerData(self, *args, **kwargs): ...
    def registerDragAndDropBehavior(self, *args, **kwargs): ...
    def registerNode(self, *args, **kwargs): ...
    def registerShape(self, *args, **kwargs): ...
    def setName(self, *args, **kwargs): ...
    def vendor(self, *args, **kwargs): ...

class MFnPluginData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, id) -> MObject: ...
    def data(self) -> MPxData: ...
    def typeId(self) -> MTypeId: ...

class MFnPointArrayData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def array(self, *args, **kwargs): ...
    def copyTo(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...
    def __setitem__(self, index, object) -> None: ...

class MFnReference(MFnDependencyNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def associatedNamespace(self, boolshortName) -> MString: ...  # type: ignore
    def containsNode(self, MObject) -> bool: ...
    def containsNodeExactly(self, MObject) -> bool: ...
    def fileName(self, boolresolvedName, boolincludePath, boolincludeCopyNumber) -> MString: ...  # type: ignore
    @staticmethod
    def ignoreReferenceEdits() -> bool: ...
    def isExportEditsFile(self) -> bool: ...
    def isLoaded(self) -> bool: ...
    def isLocked(self) -> bool: ...
    def isValidReference(self) -> bool: ...
    def nodes(self) -> MObjectArray: ...
    def parentAssembly(self) -> MObject: ...
    def parentFileName(self, boolresolvedName, boolincludePath, boolincludeCopyNumber) -> MString: ...  # type: ignore
    def parentReference(self) -> MObject: ...
    @staticmethod
    def setIgnoreReferenceEdits(bool) -> None: ...

class MFnSet(MFnDependencyNode):  # type: ignore
    kEdgesOnly: ClassVar[int] = ...
    kEditPointsOnly: ClassVar[int] = ...
    kFacetsOnly: ClassVar[int] = ...
    kNone: ClassVar[int] = ...
    kRenderableOnly: ClassVar[int] = ...
    kVerticesOnly: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def addMember(self, object) -> self: ...  # type: ignore
    def addMembers(self, MSelectionList) -> self: ...  # type: ignore
    def annotation(self) -> string: ...  # type: ignore
    def clear(self) -> self: ...  # type: ignore
    def create(self, members, restriction=...) -> MObject: ...
    def getIntersection(self, otherSet) -> MSelectionList: ...
    def getMemberPaths(self, shading) -> MDagPathArray: ...
    def getMembers(self, flatten) -> MSelectionList: ...
    def getUnion(self, otherSet) -> MSelectionList: ...
    def hasRestrictions(self) -> bool: ...
    def intersectsWith(self, otherSet) -> self: ...  # type: ignore
    def isMember(self, object) -> bool: ...
    def removeMember(self, object) -> self: ...  # type: ignore
    def removeMembers(self, MSelectionList) -> self: ...  # type: ignore
    def restriction(self) -> MFnSet.Restriction: ...
    def setAnnotation(self, annotation) -> self: ...  # type: ignore

class MFnSingleIndexedComponent(MFnComponent):
    elementMax: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def addElement(self, intelement) -> self: ...  # type: ignore
    def addElements(self, MIntArray) -> self: ...  # type: ignore
    def create(self, MFnTypeconstant) -> MObject: ...
    def element(self, index) -> int: ...
    def getCompleteData(self) -> int: ...
    def getElements(self) -> MIntArray: ...
    def setCompleteData(self, numElements) -> self: ...  # type: ignore

class MFnStringArrayData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def array(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...
    def __setitem__(self, index, object) -> None: ...

class MFnStringData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def string(self, *args, **kwargs): ...

class MFnTransform(MFnDagNode):
    kRotateMaxX: ClassVar[int] = ...
    kRotateMaxY: ClassVar[int] = ...
    kRotateMaxZ: ClassVar[int] = ...
    kRotateMinX: ClassVar[int] = ...
    kRotateMinY: ClassVar[int] = ...
    kRotateMinZ: ClassVar[int] = ...
    kScaleMaxX: ClassVar[int] = ...
    kScaleMaxY: ClassVar[int] = ...
    kScaleMaxZ: ClassVar[int] = ...
    kScaleMinX: ClassVar[int] = ...
    kScaleMinY: ClassVar[int] = ...
    kScaleMinZ: ClassVar[int] = ...
    kShearMaxXY: ClassVar[int] = ...
    kShearMaxXZ: ClassVar[int] = ...
    kShearMaxYZ: ClassVar[int] = ...
    kShearMinXY: ClassVar[int] = ...
    kShearMinXZ: ClassVar[int] = ...
    kShearMinYZ: ClassVar[int] = ...
    kTranslateMaxX: ClassVar[int] = ...
    kTranslateMaxY: ClassVar[int] = ...
    kTranslateMaxZ: ClassVar[int] = ...
    kTranslateMinX: ClassVar[int] = ...
    kTranslateMinY: ClassVar[int] = ...
    kTranslateMinZ: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    @staticmethod
    def balanceTransformation(*args, **kwargs): ...
    def clearRestPosition(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def enableLimit(self, *args, **kwargs): ...
    def isLimited(self, *args, **kwargs): ...
    def limitValue(self, *args, **kwargs): ...
    def resetFromRestPosition(self, *args, **kwargs): ...
    def resetTransformation(self, *args, **kwargs): ...
    def restPosition(self, *args, **kwargs): ...
    def rotateBy(self, *args, **kwargs): ...
    def rotateByComponents(self, *args, **kwargs): ...
    def rotateOrientation(self, *args, **kwargs): ...
    def rotatePivot(self, *args, **kwargs): ...
    def rotatePivotTranslation(self, *args, **kwargs): ...
    def rotation(self, *args, **kwargs): ...
    def rotationComponents(self, *args, **kwargs): ...
    def rotationOrder(self, *args, **kwargs): ...
    def scale(self, *args, **kwargs): ...
    def scaleBy(self, *args, **kwargs): ...
    def scalePivot(self, *args, **kwargs): ...
    def scalePivotTranslation(self, *args, **kwargs): ...
    def setLimit(self, *args, **kwargs): ...
    def setRestPosition(self, *args, **kwargs): ...
    def setRotateOrientation(self, *args, **kwargs): ...
    def setRotatePivot(self, *args, **kwargs): ...
    def setRotatePivotTranslation(self, *args, **kwargs): ...
    def setRotation(self, *args, **kwargs): ...
    def setRotationComponents(self, *args, **kwargs): ...
    def setRotationOrder(self, *args, **kwargs): ...
    def setScale(self, *args, **kwargs): ...
    def setScalePivot(self, *args, **kwargs): ...
    def setScalePivotTranslation(self, *args, **kwargs): ...
    def setShear(self, *args, **kwargs): ...
    def setTransformation(self, *args, **kwargs): ...
    def setTranslation(self, *args, **kwargs): ...
    def shear(self, *args, **kwargs): ...
    def shearBy(self, *args, **kwargs): ...
    def transformation(self, *args, **kwargs): ...
    def translateBy(self, *args, **kwargs): ...
    def translation(self, *args, **kwargs): ...

class MFnTripleIndexedComponent(MFnComponent):
    def __init__(self, *args, **kwargs) -> None: ...
    def addElement(self, sIndex, tIndex, uIndex) -> self: ...  # type: ignore
    def addElements(self, *args, **kwargs): ...
    def create(self, MFnTypeconstant) -> MObject: ...
    def getCompleteData(self, *args, **kwargs): ...
    def getElement(self, *args, **kwargs): ...
    def getElements(self, *args, **kwargs): ...
    def setCompleteData(self, numS, numT, numU) -> self: ...  # type: ignore

class MFnTypedAttribute(MFnAttribute):
    default: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def attrType(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...

class MFnUInt64ArrayData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def array(self, *args, **kwargs): ...
    def copyTo(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...
    def __setitem__(self, index, object) -> None: ...

class MFnUnitAttribute(MFnAttribute):
    kAngle: ClassVar[int] = ...
    kDistance: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kTime: ClassVar[int] = ...
    default: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, *args, **kwargs): ...
    def getMax(self, *args, **kwargs): ...
    def getMin(self, *args, **kwargs): ...
    def getSoftMax(self, *args, **kwargs): ...
    def getSoftMin(self, *args, **kwargs): ...
    def hasMax(self, *args, **kwargs): ...
    def hasMin(self, *args, **kwargs): ...
    def hasSoftMax(self, *args, **kwargs): ...
    def hasSoftMin(self, *args, **kwargs): ...
    def setMax(self, *args, **kwargs): ...
    def setMin(self, *args, **kwargs): ...
    def setSoftMax(self, *args, **kwargs): ...
    def setSoftMin(self, *args, **kwargs): ...
    def unitType(self, *args, **kwargs): ...

class MFnVectorArrayData(MFnData):
    def __init__(self, *args, **kwargs) -> None: ...
    def array(self, *args, **kwargs): ...
    def copyTo(self, *args, **kwargs): ...
    def create(self, *args, **kwargs): ...
    def set(self, *args, **kwargs): ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...
    def __setitem__(self, index, object) -> None: ...

class MGlobal:
    kAddToHeadOfList: ClassVar[int] = ...
    kAddToList: ClassVar[int] = ...
    kBaseUIMode: ClassVar[int] = ...
    kBatch: ClassVar[int] = ...
    kInteractive: ClassVar[int] = ...
    kLibraryApp: ClassVar[int] = ...
    kRemoveFromList: ClassVar[int] = ...
    kReplaceList: ClassVar[int] = ...
    kSelectComponentMode: ClassVar[int] = ...
    kSelectLeafMode: ClassVar[int] = ...
    kSelectObjectMode: ClassVar[int] = ...
    kSelectRootMode: ClassVar[int] = ...
    kSelectTemplateMode: ClassVar[int] = ...
    kSurfaceSelectMethod: ClassVar[int] = ...
    kWireframeSelectMethod: ClassVar[int] = ...
    kXORWithList: ClassVar[int] = ...
    @staticmethod
    def addToModel(*args, **kwargs): ...
    @staticmethod
    def addToModelAt(*args, **kwargs): ...
    @staticmethod
    def animSelectionMask() -> MSelectionMask: ...
    @staticmethod
    def apiVersion() -> int: ...
    @staticmethod
    def className() -> string: ...  # type: ignore
    @staticmethod
    def clearSelectionList() -> None: ...
    @staticmethod
    def closeErrorLog() -> None: ...
    @staticmethod
    def componentSelectionMask() -> MSelectionMask: ...
    @staticmethod
    def currentToolContext() -> MObject: ...
    @staticmethod
    def defaultErrorLogPathName() -> string: ...  # type: ignore
    @staticmethod
    def deleteNode(MObject) -> None: ...
    @staticmethod
    def disableStow() -> bool: ...
    @staticmethod
    def displayError(msg) -> None: ...
    @staticmethod
    def displayInfo(msg) -> None: ...
    @staticmethod
    def displayWarning(msg) -> None: ...
    @staticmethod
    def doErrorLogEntry(string) -> bool: ...
    @staticmethod
    def errorLogPathName() -> string: ...  # type: ignore
    @staticmethod
    def errorLoggingIsOn() -> bool: ...
    @staticmethod
    def executeCommandOnIdle(string, booldisplayEnabled=...) -> None: ...
    @staticmethod
    def executeCommandStringResult(string, booldisplayEnabled=..., boolundoEnabled=...) -> stringor[string, string, ...]: ...  # type: ignore
    @staticmethod
    def getAbsolutePathToResources() -> string: ...  # type: ignore
    @staticmethod
    def getActiveSelectionList(orderedSelectionIfAvailable=...) -> MSelectionList: ...
    @staticmethod
    def getAssociatedSets(MSelectionList) -> list: ...
    @staticmethod
    def getFunctionSetList(*args, **kwargs): ...
    @staticmethod
    def getHiliteList() -> MSelectionList: ...
    @staticmethod
    def getLiveList() -> MSelectionList: ...
    @staticmethod
    def getPreselectionHiliteList() -> MSelectionList: ...
    @staticmethod
    def getRichSelection(defaultToActiveSelection=...) -> MRichSelection: ...
    @staticmethod
    def getSelectionListByName(name) -> MSelectionList: ...
    @overload
    @staticmethod
    def initOptionVar(stringname, int, stringcategory) -> bool: ...
    @overload
    @staticmethod
    def initOptionVar(stringname, double, stringcategory) -> bool: ...
    @overload
    @staticmethod
    def initOptionVar(stringname, string, stringcategory) -> bool: ...
    @staticmethod
    def isRedoing() -> bool: ...
    @staticmethod
    def isSelected(MObject) -> bool: ...
    @staticmethod
    def isUndoing() -> bool: ...
    @staticmethod
    def isYAxisUp() -> bool: ...
    @staticmethod
    def isZAxisUp() -> bool: ...
    @staticmethod
    def mayaFeatureSet() -> int: ...
    @staticmethod
    def mayaName() -> string: ...  # type: ignore
    @staticmethod
    def mayaState() -> int: ...
    @staticmethod
    def mayaVersion() -> string: ...  # type: ignore
    @staticmethod
    def miscSelectionMask() -> MSelectionMask: ...
    @staticmethod
    def objectSelectionMask() -> MSelectionMask: ...
    @staticmethod
    def optionVarDoubleValue(string) -> double: ...  # type: ignore
    @staticmethod
    def optionVarExists(string) -> bool: ...
    @staticmethod
    def optionVarIntValue(string) -> int: ...
    @staticmethod
    def optionVarStringValue(string) -> MString: ...  # type: ignore
    @staticmethod
    def removeFromModel(MObject) -> None: ...
    @staticmethod
    def removeOptionVar(string) -> None: ...
    @staticmethod
    def resetToDefaultErrorLogPathName() -> None: ...
    @staticmethod
    def selectByName(string, listAdjustment=...) -> None: ...
    @staticmethod
    def selectCommand(MSelectionList, listAdjustment=...) -> None: ...
    @staticmethod
    def selectFromScreen(*args, **kwargs): ...
    @staticmethod
    def selectionMethod() -> int: ...
    @staticmethod
    def selectionMode() -> int: ...
    @staticmethod
    def setActiveSelectionList(MSelectionList, listAdjustment=...) -> None: ...
    @staticmethod
    def setAnimSelectionMask(*args, **kwargs): ...
    @staticmethod
    def setComponentSelectionMask(*args, **kwargs): ...
    @staticmethod
    def setDisableStow(bool) -> None: ...
    @staticmethod
    def setDisplayCVs(MSelectionList, bool) -> None: ...
    @staticmethod
    def setErrorLogPathName(string) -> None: ...
    @staticmethod
    def setHiliteList(MSelectionList) -> None: ...
    @staticmethod
    def setMiscSelectionMask(*args, **kwargs): ...
    @staticmethod
    def setObjectSelectionMask(*args, **kwargs): ...
    @overload
    @staticmethod
    def setOptionVarValue(string, int) -> bool: ...
    @overload
    @staticmethod
    def setOptionVarValue(stringname, double) -> bool: ...
    @overload
    @staticmethod
    def setOptionVarValue(stringname, string) -> bool: ...
    @staticmethod
    def setPreselectionHiliteList(MSelectionList) -> None: ...
    @staticmethod
    def setRichSelection(MRichSelection) -> None: ...
    @staticmethod
    def setSelectionMode(int) -> None: ...
    @staticmethod
    def setTrackSelectionOrderEnabled() -> None: ...
    @staticmethod
    def setYAxisUp() -> None: ...
    @staticmethod
    def setZAxisUp() -> None: ...
    @staticmethod
    def sourceFile(string) -> None: ...
    @overload
    @staticmethod
    def startErrorLogging() -> None: ...
    @overload
    @staticmethod
    def startErrorLogging(string) -> Any: ...
    @staticmethod
    def stopErrorLogging() -> None: ...
    @staticmethod
    def trackSelectionOrderEnabled() -> bool: ...
    @overload
    @staticmethod
    def unselect(MObject) -> None: ...
    @overload
    @staticmethod
    def unselect(MDagPath, MObject) -> None: ...
    @staticmethod
    def unselectByName(string) -> None: ...
    @staticmethod
    def upAxis() -> MVector: ...
    @overload
    @staticmethod
    def viewFrame(double) -> None: ...
    @overload
    @staticmethod
    def viewFrame(MTime) -> None: ...

class MImage:
    kByte: ClassVar[int] = ...
    kFloat: ClassVar[int] = ...
    kHeightFieldBumpFormat: ClassVar[int] = ...
    kNoFormat: ClassVar[int] = ...
    kNormalMapBumpFormat: ClassVar[int] = ...
    kUnknown: ClassVar[int] = ...
    kUnknownFormat: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, width, height, channels=..., type=...) -> self: ...  # type: ignore
    @overload
    def depth(self) -> int: ...
    @overload
    def depth(self, inbytes) -> Any: ...
    def depthMap(self) -> long: ...  # type: ignore
    def filter(self, sourceFormat, targetFormat, scale=..., offset=...) -> self: ...  # type: ignore
    @staticmethod
    def filterExists(sourceFormat, targetFormat) -> bool: ...
    def floatPixels(self) -> long: ...  # type: ignore
    def getDepthMapRange(self, *args, **kwargs): ...
    def getDepthMapSize(self, *args, **kwargs): ...
    def getSize(self, *args, **kwargs): ...
    def haveDepth(self) -> bool: ...
    def isRGBA(self) -> bool: ...
    def pixelType(self) -> int: ...
    def pixels(self) -> long: ...  # type: ignore
    def readDepthMap(self, pathname) -> self: ...  # type: ignore
    def readFromFile(self, pathname, type=...) -> self: ...  # type: ignore
    def readFromTextureNode(self, fileTextureObject, type=...) -> self: ...  # type: ignore
    def release(self) -> self: ...  # type: ignore
    def resize(self, width, height, preserveAspectRatio=...) -> self: ...  # type: ignore
    def setDepthMap(self, depth, width, heigth) -> self: ...  # type: ignore
    def setFloatPixels(self, pixels, width, height, channels=...) -> self: ...  # type: ignore
    def setPixels(self, pixels, width, height) -> self: ...  # type: ignore
    def setRGBA(self, bool) -> self: ...  # type: ignore
    def verticalFlip(self) -> bool: ...
    def writeToFile(self, pathname, outputFormat=...) -> self: ...  # type: ignore
    def writeToFileWithDepth(self, pathname, outputFormat=..., writeDepth=...) -> self: ...  # type: ignore

class MInt64Array:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MIntArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MItCurveCV:
    def __init__(self, *args, **kwargs) -> None: ...
    def currentItem(self) -> MObject: ...
    def hasHistoryOnCreate(self) -> bool: ...
    def index(self) -> int: ...
    def isDone(self) -> bool: ...
    def next(self) -> self: ...  # type: ignore
    def position(self) -> MPoint: ...
    @overload
    def reset(self) -> self: ...  # type: ignore
    @overload
    def reset(self, curve) -> self: ...  # type: ignore
    @overload
    def reset(self, curve, component=...) -> self: ...  # type: ignore
    def setPosition(self, point, space=...) -> self: ...  # type: ignore
    def translateBy(self, vector, space=...) -> self: ...  # type: ignore
    def updateCurve(self) -> self: ...  # type: ignore
    def __iter__(self): ...
    def __next__(self): ...

class MItDag:  # type: ignore
    kBreadthFirst: ClassVar[int] = ...
    kDepthFirst: ClassVar[int] = ...
    kInvalidType: ClassVar[int] = ...
    traverseUnderWorld: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def currentItem(self) -> MObject: ...
    def depth(self) -> integer: ...  # type: ignore
    def fullPathName(self) -> MString: ...  # type: ignore
    def getAllPaths(self) -> MDagPathArray: ...
    def getPath(self) -> MDagPath: ...
    def instanceCount(self, total) -> Integer: ...  # type: ignore
    def isDone(self) -> Bool: ...  # type: ignore
    def isInstanced(self, indirect=...) -> Bool: ...  # type: ignore
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    def partialPathName(self) -> MString: ...  # type: ignore
    def prune(self) -> self: ...  # type: ignore
    @overload
    def reset(self) -> self: ...  # type: ignore
    @overload
    def reset(self, rootObject, traversalType=..., filterType=...) -> self: ...  # type: ignore
    @overload
    def reset(self, rootPath, traversalType=..., filterType=...) -> self: ...  # type: ignore
    @overload
    def reset(self, dagInfoObject, rootObjectORrootPath, traversalType=...) -> self: ...  # type: ignore
    @overload
    def root(self) -> MObject: ...
    @overload
    def root(self, startnode) -> Any: ...
    def traversalType(self) -> MItDag.TraversalType: ...
    def __iter__(self): ...
    def __next__(self): ...

class MItDependencyGraph:
    kBreadthFirst: ClassVar[int] = ...
    kConnectedTo: ClassVar[int] = ...
    kDependsOn: ClassVar[int] = ...
    kDepthFirst: ClassVar[int] = ...
    kDownstream: ClassVar[int] = ...
    kEvaluationGraph: ClassVar[int] = ...
    kNodeLevel: ClassVar[int] = ...
    kPlugLevel: ClassVar[int] = ...
    kUpstream: ClassVar[int] = ...
    currentDirection: Incomplete
    currentFilter: Incomplete
    currentLevel: Incomplete
    currentRelationship: Incomplete
    currentTraversal: Incomplete
    nodeDepth: Incomplete
    pruningOnFilter: Incomplete
    traversingOverWorldSpaceDependents: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def currentNode(self) -> MObject: ...
    def currentNodeHasUnknownType(self) -> Bool: ...  # type: ignore
    def currentPlug(self) -> MPlug: ...
    def getNodePath(self) -> MObjectArray: ...
    def getNodesVisited(self) -> MObjectArray: ...
    def getPlugPath(self) -> MPlugArray: ...
    def getPlugsVisited(self) -> MPlugArray: ...
    def isDone(self) -> Bool: ...  # type: ignore
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    def previousPlug(self) -> MPlug: ...
    def prune(self) -> self: ...  # type: ignore
    def reset(self) -> self: ...  # type: ignore
    def resetFilter(self) -> self: ...  # type: ignore
    @overload
    def resetTo(self, rootObject, filter=..., direction=..., traversal=..., level=..., relationship=...) -> self: ...  # type: ignore
    @overload
    def resetTo(self, rootPlug, filter=..., direction=..., traversal=..., level=..., relationship=...) -> self: ...  # type: ignore
    @overload
    def resetTo(self, infoObject, rootObjectORrootPlug, direction=..., traversal=..., level=..., relationship=...) -> self: ...  # type: ignore
    def rootNode(self) -> MObject: ...
    def rootPlug(self) -> MPlug: ...
    def __iter__(self): ...
    def __next__(self): ...

class MItDependencyNodes:
    def __init__(self, *args, **kwargs) -> None: ...
    def isDone(self) -> Bool: ...  # type: ignore
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    @overload
    def reset(self) -> self: ...  # type: ignore
    @overload
    def reset(self, filterType=...) -> self: ...  # type: ignore
    @overload
    def reset(self, dagInfoObject) -> self: ...  # type: ignore
    def thisNode(self) -> MObject: ...
    def __iter__(self): ...
    def __next__(self): ...

class MItGeometry:
    def __init__(self, *args, **kwargs) -> None: ...
    def allPositions(self) -> MStatus: ...  # type: ignore
    def component(self) -> MObject: ...
    def count(self) -> int: ...
    def currentItem(self) -> MObject: ...
    def exactCount(self) -> int: ...
    def index(self) -> int: ...
    def isDone(self) -> Bool: ...  # type: ignore
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    def normal(self) -> MVector: ...
    def position(self) -> MPoint: ...
    def reset(self) -> self: ...  # type: ignore
    def setAllPositions(self) -> MStatus: ...  # type: ignore
    def setPosition(self) -> MStatus: ...  # type: ignore
    def weight(self) -> MWeight: ...
    def __iter__(self): ...
    def __next__(self): ...

class MItMeshEdge:
    isSmooth: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def center(self, space=...) -> MPoint: ...
    def connectedToEdge(self, index) -> bool: ...
    def connectedToFace(self, index) -> bool: ...
    def count(self) -> int: ...
    def currentItem(self) -> MObject: ...
    def geomChanged(self) -> self: ...  # type: ignore
    def getConnectedEdges(self) -> MIntArray: ...
    def getConnectedFaces(self) -> MIntArray: ...
    def index(self) -> int: ...
    def isDone(self) -> bool: ...
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def length(self, space=...) -> float: ...
    def next(self) -> self: ...  # type: ignore
    def numConnectedEdges(self) -> int: ...
    def numConnectedFaces(self) -> int: ...
    def onBoundary(self) -> bool: ...
    def point(self, whichVertex, space=...) -> MPoint: ...
    @overload
    def reset(self) -> self: ...  # type: ignore
    @overload
    def reset(self, mesh) -> self: ...  # type: ignore
    @overload
    def reset(self, mesh, component=...) -> self: ...  # type: ignore
    def setIndex(self, index) -> int: ...
    def setPoint(self, point, whichVertex, space=...) -> self: ...  # type: ignore
    def updateSurface(self) -> self: ...  # type: ignore
    def vertexId(self, whichVertex) -> int: ...
    def __iter__(self): ...
    def __next__(self): ...

class MItMeshFaceVertex:
    def __init__(self, *args, **kwargs) -> None: ...
    def currentItem(self) -> MObject: ...
    def faceId(self) -> int: ...
    def faceVertexId(self) -> int: ...
    def geomChanged(self) -> self: ...  # type: ignore
    def getBinormal(self, space=..., uvSet=...) -> MVector: ...
    def getColor(self, colorSetName=...) -> MColor: ...
    def getColorIndex(self, colorSetName=...) -> int: ...
    def getNormal(self, space=...) -> MVector: ...
    def getTangent(self, space=..., uvSet=...) -> MVector: ...
    def getUV(self, *args, **kwargs): ...
    def getUVIndex(self, uvSet=...) -> int: ...
    def hasColor(self) -> bool: ...
    def hasUVs(self, uvSet=...) -> bool: ...
    def isDone(self) -> bool: ...
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    def normalId(self) -> int: ...
    def position(self, space=...) -> MPoint: ...
    @overload
    def reset(self) -> self: ...  # type: ignore
    @overload
    def reset(self, mesh) -> self: ...  # type: ignore
    @overload
    def reset(self, mesh, component=...) -> self: ...  # type: ignore
    def setIndex(self, *args, **kwargs): ...
    def tangentId(self) -> int: ...
    def updateSurface(self) -> self: ...  # type: ignore
    def vertexId(self) -> int: ...
    def __iter__(self): ...
    def __next__(self): ...

class MItMeshPolygon:
    def __init__(self, *args, **kwargs) -> None: ...
    def center(self, space=...) -> MPoint: ...
    def count(self) -> int: ...
    def currentItem(self) -> MObject: ...
    def geomChanged(self) -> self: ...  # type: ignore
    def getArea(self, space=...) -> float: ...
    @overload
    def getColor(self, colorSetName=...) -> MColor: ...
    @overload
    def getColor(self, vertexIndex) -> MColor: ...
    def getColorIndex(self, vertexIndex, colorSetName=...) -> int: ...
    def getColorIndices(self, colorSetName=...) -> MIntArray: ...
    def getColors(self, colorSetName=...) -> MColorArray: ...
    def getConnectedEdges(self) -> MIntArray: ...
    def getConnectedFaces(self) -> MIntArray: ...
    def getConnectedVertices(self) -> MIntArray: ...
    def getEdges(self) -> MIntArray: ...
    def getNormal(self, space=...) -> MVector: ...
    def getNormals(self, space=...) -> MVectorArray: ...
    def getPointAtUV(self, uvPoint, space=..., uvSet=..., tolerance=...) -> MPoint: ...
    def getPoints(self, space=...) -> MPointArray: ...
    def getTriangle(self, *args, **kwargs): ...
    def getTriangles(self, *args, **kwargs): ...
    def getUV(self, *args, **kwargs): ...
    def getUVArea(self, uvSet=...) -> float: ...
    def getUVAtPoint(self, *args, **kwargs): ...
    def getUVIndex(self, vertex, uvSet=...) -> int: ...
    def getUVIndexAndValue(self, *args, **kwargs): ...
    def getUVSetNames(self) -> listofstrings: ...  # type: ignore
    def getUVs(self, *args, **kwargs): ...
    def getVertices(self) -> MIntArray: ...
    @overload
    def hasColor(self) -> bool: ...
    @overload
    def hasColor(self, localVertexIndex) -> bool: ...
    def hasUVs(self, uvSet=...) -> bool: ...
    def hasValidTriangulation(self) -> bool: ...
    def index(self) -> int: ...
    def isConnectedToEdge(self, index) -> bool: ...
    def isConnectedToFace(self, index) -> bool: ...
    def isConnectedToVertex(self, index) -> bool: ...
    def isConvex(self) -> bool: ...
    def isDone(self) -> bool: ...
    def isHoled(self) -> bool: ...
    def isLamina(self) -> bool: ...
    def isPlanar(self) -> bool: ...
    def isStarlike(self) -> bool: ...
    def isUVReversed(self, faceId) -> bool: ...
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    def normalIndex(self, vertex) -> int: ...
    def numColors(self, colorSetName=...) -> int: ...
    def numConnectedEdges(self) -> int: ...
    def numConnectedFaces(self) -> int: ...
    def numTriangles(self) -> int: ...
    def onBoundary(self) -> bool: ...
    def point(self, index, space=...) -> MPoint: ...
    def polygonVertexCount(self) -> int: ...
    @overload
    def reset(self) -> self: ...  # type: ignore
    @overload
    def reset(self, polyObject) -> self: ...  # type: ignore
    @overload
    def reset(self, polyObject, component=...) -> self: ...  # type: ignore
    def setIndex(self, index) -> int: ...
    def setPoint(self, point, index, space=...) -> self: ...  # type: ignore
    def setPoints(self, pointArray, space=...) -> self: ...  # type: ignore
    def setUV(self, vertexId, uvPoint, uvSet=...) -> self: ...  # type: ignore
    def setUVs(self, uArray, vArray, uvSet=...) -> self: ...  # type: ignore
    def tangentIndex(self, localVertexIndex) -> int: ...
    def updateSurface(self) -> self: ...  # type: ignore
    def vertexIndex(self, index) -> int: ...
    def zeroArea(self) -> bool: ...
    def zeroUVArea(self, uvSet=...) -> bool: ...
    def __iter__(self): ...
    def __next__(self): ...

class MItMeshVertex:
    def __init__(self, *args, **kwargs) -> None: ...
    def connectedToEdge(self, index) -> bool: ...
    def connectedToFace(self, index) -> bool: ...
    def count(self) -> int: ...
    def currentItem(self) -> MObject: ...
    def geomChanged(self) -> self: ...  # type: ignore
    @overload
    def getColor(self, colorSetName=...) -> MColor: ...
    @overload
    def getColor(self, faceIndex, colorSetName=...) -> MColor: ...
    def getColorIndices(self, colorSetName=...) -> MIntArray: ...
    def getColors(self, colorSetName=...) -> MColorArray: ...
    def getConnectedEdges(self) -> MIntArray: ...
    def getConnectedFaces(self) -> MIntArray: ...
    def getConnectedVertices(self) -> MIntArray: ...
    @overload
    def getNormal(self, space=...) -> MVector: ...
    @overload
    def getNormal(self, faceIndex, space=...) -> MVector: ...
    def getNormalIndices(self) -> MIntArray: ...
    def getNormals(self, space=...) -> MVectorArray: ...
    def getOppositeVertex(self, edgeId) -> int: ...
    def getUV(self, *args, **kwargs): ...
    def getUVIndices(self, uvSet=...) -> MIntArray: ...
    def getUVs(self, *args, **kwargs): ...
    @overload
    def hasColor(self) -> bool: ...
    @overload
    def hasColor(self, index) -> bool: ...
    def index(self) -> int: ...
    def isDone(self) -> bool: ...
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    def numConnectedEdges(self) -> int: ...
    def numConnectedFaces(self) -> int: ...
    def numUVs(self, uvSet=...) -> int: ...
    def onBoundary(self) -> bool: ...
    def position(self, space=...) -> MPoint: ...
    @overload
    def reset(self) -> self: ...  # type: ignore
    @overload
    def reset(self, polyObject) -> self: ...  # type: ignore
    @overload
    def reset(self, polyObject, component=...) -> self: ...  # type: ignore
    def setIndex(self, index) -> int: ...
    def setPosition(self, point, space=...) -> self: ...  # type: ignore
    def setUV(self, *args, **kwargs): ...
    def setUVs(self, uArray, vArray, faceIds, uvSet=...) -> self: ...  # type: ignore
    def translateBy(self, vector, space=...) -> self: ...  # type: ignore
    def updateSurface(self) -> self: ...  # type: ignore
    def __iter__(self): ...
    def __next__(self): ...

class MItSelectionList:
    kAnimSelectionItem: ClassVar[int] = ...
    kDNselectionItem: ClassVar[int] = ...
    kDagSelectionItem: ClassVar[int] = ...
    kPlugSelectionItem: ClassVar[int] = ...
    kUnknownItem: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getComponent(self, *args, **kwargs): ...
    def getDagPath(self) -> MDagPath: ...
    def getDependNode(self) -> MObject: ...
    def getPlug(self) -> MPlug: ...
    def getStrings(self) -> listofstrings: ...  # type: ignore
    def hasComponents(self) -> bool: ...
    def isDone(self) -> bool: ...
    def itemType(self) -> int: ...
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    def reset(self) -> self: ...  # type: ignore
    def setFilter(self, filter) -> self: ...  # type: ignore
    def __iter__(self): ...
    def __next__(self): ...

class MItSurfaceCV:
    def __init__(self, *args, **kwargs) -> None: ...
    def currentItem(self) -> MObject: ...
    def hasHistoryOnCreate(self) -> bool: ...
    def index(self) -> int: ...
    def isDone(self) -> bool: ...
    def isRowDone(self) -> bool: ...
    def iter(self) -> self: ...  # type: ignore
    def iternext(self) -> self: ...  # type: ignore
    def next(self) -> self: ...  # type: ignore
    def nextRow(self) -> self: ...  # type: ignore
    def position(self, space=...) -> MPoint: ...
    @overload
    def reset(self) -> self: ...  # type: ignore
    @overload
    def reset(self, surface, useURows=...) -> self: ...  # type: ignore
    @overload
    def reset(self, surface, component, useURows=...) -> self: ...  # type: ignore
    def setPosition(self, point, space=...) -> self: ...  # type: ignore
    def translateBy(self, vector, space=...) -> self: ...  # type: ignore
    def updateSurface(self) -> self: ...  # type: ignore
    def uvIndices(self, *args, **kwargs): ...
    def __iter__(self): ...
    def __next__(self): ...

class MIteratorType:
    kMDagPathObject: ClassVar[int] = ...
    kMObject: ClassVar[int] = ...
    kMPlugObject: ClassVar[int] = ...
    filterList: Incomplete
    filterListEnabled: Incomplete
    filterType: Incomplete
    objectType: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...

class MLockMessage(MMessage):
    kAddAttr: ClassVar[int] = ...
    kChildReorder: ClassVar[int] = ...
    kCreateChildInstance: ClassVar[int] = ...
    kCreateNodeInstance: ClassVar[int] = ...
    kCreateParentInstance: ClassVar[int] = ...
    kDelete: ClassVar[int] = ...
    kGroup: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kInvalidDAG: ClassVar[int] = ...
    kInvalidPlug: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kLastDAG: ClassVar[int] = ...
    kLastPlug: ClassVar[int] = ...
    kLockAttr: ClassVar[int] = ...
    kLockNode: ClassVar[int] = ...
    kPlugAttrValChange: ClassVar[int] = ...
    kPlugConnect: ClassVar[int] = ...
    kPlugDisconnect: ClassVar[int] = ...
    kPlugLockAttr: ClassVar[int] = ...
    kPlugRemoveAttr: ClassVar[int] = ...
    kPlugRenameAttr: ClassVar[int] = ...
    kPlugUnlockAttr: ClassVar[int] = ...
    kRemoveAttr: ClassVar[int] = ...
    kRename: ClassVar[int] = ...
    kRenameAttr: ClassVar[int] = ...
    kReparent: ClassVar[int] = ...
    kUnGroup: ClassVar[int] = ...
    kUnlockAttr: ClassVar[int] = ...
    kUnlockNode: ClassVar[int] = ...
    @staticmethod
    def setNodeLockDAGQueryCallback(dagPath, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def setNodeLockQueryCallback(*args, **kwargs): ...
    @staticmethod
    def setPlugLockQueryCallback(*args, **kwargs): ...

class MMatrix:
    kIdentity: ClassVar[MMatrix] = ...
    kTolerance: ClassVar[float] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def adjoint(self, *args, **kwargs): ...
    def det3x3(self, *args, **kwargs): ...
    def det4x4(self, *args, **kwargs): ...
    def getElement(self, *args, **kwargs): ...
    def homogenize(self, *args, **kwargs): ...
    def inverse(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def isSingular(self, *args, **kwargs): ...
    def setElement(self, *args, **kwargs): ...
    def setToIdentity(self, *args, **kwargs): ...
    def setToProduct(self, *args, **kwargs): ...
    def transpose(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __isub__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __sub__(self, other): ...

class MMatrixArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MMeshIntersector:
    isCreated: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def create(self, mesh, matrix) -> self: ...  # type: ignore
    def getClosestPoint(self, referencePoint, maxDistance=...) -> MPointOnMesh: ...

class MMeshIsectAccelParams:
    def __init__(self, *args, **kwargs) -> None: ...

class MMeshSmoothOptions:
    kCatmullClark: ClassVar[int] = ...
    kCreaseAll: ClassVar[int] = ...
    kCreaseEdge: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kInvalidSubdivision: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kLastSubdivision: ClassVar[int] = ...
    kLegacy: ClassVar[int] = ...
    kOpenSubdivCatmullClarkAdaptive: ClassVar[int] = ...
    kOpenSubdivCatmullClarkUniform: ClassVar[int] = ...
    boundaryRule: Incomplete
    divisions: Incomplete
    keepBorderEdge: Incomplete
    keepHardEdge: Incomplete
    propEdgeHardness: Incomplete
    smoothUVs: Incomplete
    smoothness: Incomplete
    subdivisionType: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...

class MMessage:
    kDefaultAction: ClassVar[int] = ...
    kDoAction: ClassVar[int] = ...
    kDoNotDoAction: ClassVar[int] = ...
    @staticmethod
    def currentCallbackId() -> id: ...  # type: ignore
    @staticmethod
    def nodeCallbacks(node) -> ids: ...  # type: ignore
    @staticmethod
    def removeCallback(id) -> None: ...
    @staticmethod
    def removeCallbacks(ids) -> None: ...

class MModelMessage(MMessage):
    kActiveListModified: ClassVar[int] = ...
    @staticmethod
    def addAfterDuplicateCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addBeforeDuplicateCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addCallback(message, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeAddedToModelCallback(dagNode, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeRemovedFromModelCallback(dagNode, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addPostDuplicateNodeListCallback(function, clientData=...) -> id: ...  # type: ignore

class MNamespace:
    @staticmethod
    def addNamespace(MStringname, MStringparent=...) -> Any: ...
    @staticmethod
    def currentNamespace() -> MString: ...  # type: ignore
    @staticmethod
    def getNamespaceFromName(MStringfullName) -> MString: ...  # type: ignore
    @staticmethod
    def getNamespaceObjects(MStringparentNamespace, boolrecurse=...) -> MObjectArray: ...
    @staticmethod
    def getNamespaces(*args, **kwargs): ...
    @staticmethod
    def makeNamepathAbsolute(MStringfullName) -> MString: ...  # type: ignore
    @staticmethod
    def moveNamespace(MStringsrc, MStringdst, boolforce=...) -> Any: ...
    @staticmethod
    def namespaceExists(MStringname) -> bool: ...
    @staticmethod
    def parentNamespace() -> MString: ...  # type: ignore
    @staticmethod
    def relativeNames() -> bool: ...
    @staticmethod
    def removeNamespace(MStringname, boolremoveContents=...) -> Any: ...
    @staticmethod
    def renameNamespace(MStringoldName, MStringnewName, MStringparent=...) -> Any: ...
    @staticmethod
    def rootNamespace() -> MString: ...  # type: ignore
    @staticmethod
    def setCurrentNamespace(MStringname) -> MString: ...  # type: ignore
    @staticmethod
    def setRelativeNames(boolnewState) -> Any: ...
    @staticmethod
    def stripNamespaceFromName(MStringfullName) -> MString: ...  # type: ignore
    @staticmethod
    def validateName(MStringname) -> MString: ...  # type: ignore

class MNodeCacheDisablingInfo:
    def __init__(self, *args, **kwargs) -> None: ...
    def getCacheDisabled(self) -> bool: ...
    def reset(self) -> Any: ...
    def setCacheDisabled(self, bool) -> Any: ...
    def setMitigation(self, mitigation) -> Any: ...
    def setReason(self, reason) -> Any: ...

class MNodeCacheSetupInfo:
    kLastPreference: ClassVar[int] = ...
    kLastRequirement: ClassVar[int] = ...
    kSimulationSupport: ClassVar[int] = ...
    kWantToCacheByDefault: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getPreference(self, PreferenceFlag) -> bool: ...
    def getRequirement(self, RequirementFlag) -> bool: ...
    def setPreference(self, PreferenceFlag, bool) -> Any: ...
    def setRequirement(self, RequirementFlag, bool) -> Any: ...

class MNodeClass:
    attributeCount: Incomplete
    classification: Incomplete
    pluginName: Incomplete
    typeId: Incomplete
    typeName: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def addExtensionAttribute(self, *args, **kwargs): ...
    def attribute(self, *args, **kwargs): ...
    def getAttributes(self, *args, **kwargs): ...
    def hasAttribute(self, *args, **kwargs): ...
    def removeExtensionAttribute(self, *args, **kwargs): ...
    def removeExtensionAttributeIfUnset(self, *args, **kwargs): ...

class MNodeMessage(MMessage):
    kAttributeAdded: ClassVar[int] = ...
    kAttributeArrayAdded: ClassVar[int] = ...
    kAttributeArrayRemoved: ClassVar[int] = ...
    kAttributeEval: ClassVar[int] = ...
    kAttributeKeyable: ClassVar[int] = ...
    kAttributeLocked: ClassVar[int] = ...
    kAttributeRemoved: ClassVar[int] = ...
    kAttributeRenamed: ClassVar[int] = ...
    kAttributeSet: ClassVar[int] = ...
    kAttributeUnkeyable: ClassVar[int] = ...
    kAttributeUnlocked: ClassVar[int] = ...
    kConnectionBroken: ClassVar[int] = ...
    kConnectionMade: ClassVar[int] = ...
    kIncomingDirection: ClassVar[int] = ...
    kKeyChangeInvalid: ClassVar[int] = ...
    kKeyChangeLast: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kMakeKeyable: ClassVar[int] = ...
    kMakeUnkeyable: ClassVar[int] = ...
    kOtherPlugSet: ClassVar[int] = ...
    @staticmethod
    def addAttributeAddedOrRemovedCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addAttributeChangedCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addKeyableChangeOverride(plug, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNameChangedCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeAboutToDeleteCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeDestroyedCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeDirtyCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodeDirtyPlugCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNodePreRemovalCallback(node, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addUuidChangedCallback(node, function, clientData=...) -> id: ...  # type: ignore

class MObject:
    kNullObj: ClassVar[MObject] = ...
    apiTypeStr: Any
    def __init__(self, *args, **kwargs) -> None: ...
    def apiType(self, *args, **kwargs): ...
    def hasFn(self, *args, **kwargs): ...
    def isNull(self, *args, **kwargs): ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MObjectArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MObjectHandle:
    def __init__(self, *args, **kwargs) -> None: ...
    def assign(self, source) -> self: ...  # type: ignore
    def hashCode(self) -> int: ...
    def isAlive(self) -> bool: ...
    def isValid(self) -> bool: ...
    def object(self) -> MObject: ...
    def __eq__(self, other: object) -> bool: ...  # type: ignore
    def __ge__(self, other: object) -> bool: ...  # type: ignore
    def __gt__(self, other: object) -> bool: ...  # type: ignore
    def __hash__(self) -> int: ...
    def __le__(self, other: object) -> bool: ...  # type: ignore
    def __lt__(self, other: object) -> bool: ...  # type: ignore
    def __ne__(self, other: object) -> bool: ...  # type: ignore

class MObjectSetMessage(MMessage):
    @staticmethod
    def addSetMembersModifiedCallback(node, function, clientData=...) -> id: ...  # type: ignore

class MPlane:
    def __init__(self, *args, **kwargs) -> None: ...
    def distance(self) -> float: ...
    def distanceToPoint(self, point, signed=...) -> float: ...
    def normal(self) -> MVector: ...
    @overload
    def setPlane(self, a, b, c, d) -> self: ...  # type: ignore
    @overload
    def setPlane(self, n, d) -> self: ...  # type: ignore

class MPlug:
    kAll: ClassVar[int] = ...
    kChanged: ClassVar[int] = ...
    kChildrenNotFreeToChange: ClassVar[int] = ...
    kFreeToChange: ClassVar[int] = ...
    kLastAttrSelector: ClassVar[int] = ...
    kNonDefault: ClassVar[int] = ...
    kNotFreeToChange: ClassVar[int] = ...
    info: Incomplete
    isArray: Incomplete
    isCaching: Incomplete
    isChannelBox: Incomplete
    isChild: Incomplete
    isCompound: Incomplete
    isConnected: Incomplete
    isDestination: Incomplete
    isDynamic: Incomplete
    isElement: Incomplete
    isFromReferencedFile: Incomplete
    isIgnoredWhenRendering: Incomplete
    isKeyable: Incomplete
    isLocked: Incomplete
    isNetworked: Incomplete
    isNull: Incomplete
    isProcedural: Incomplete
    isProxy: Incomplete
    isSource: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def array(self, *args, **kwargs): ...
    def asBool(self, *args, **kwargs): ...
    def asChar(self, *args, **kwargs): ...
    def asDouble(self, *args, **kwargs): ...
    def asFloat(self, *args, **kwargs): ...
    def asInt(self, *args, **kwargs): ...
    def asMAngle(self, *args, **kwargs): ...
    def asMDataHandle(self, *args, **kwargs): ...
    def asMDistance(self, *args, **kwargs): ...
    def asMObject(self, *args, **kwargs): ...
    def asMTime(self, *args, **kwargs): ...
    def asShort(self, *args, **kwargs): ...
    def asString(self, *args, **kwargs): ...
    def attribute(self, *args, **kwargs): ...
    def child(self, *args, **kwargs): ...
    def connectedTo(self, *args, **kwargs): ...
    def connectionByPhysicalIndex(self, *args, **kwargs): ...
    def constructHandle(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def destinations(self, *args, **kwargs): ...
    def destinationsWithConversions(self) -> Any: ...
    def destructHandle(self, *args, **kwargs): ...
    def elementByLogicalIndex(self, *args, **kwargs): ...
    def elementByPhysicalIndex(self, *args, **kwargs): ...
    def evaluateNumElements(self, *args, **kwargs): ...
    def getExistingArrayAttributeIndices(self, *args, **kwargs): ...
    def getSetAttrCmds(self, *args, **kwargs): ...
    def isDefaultValue(self, *args, **kwargs): ...
    def isExactlyEqual(self, *args, **kwargs): ...
    def isFreeToChange(self, *args, **kwargs): ...
    def logicalIndex(self, *args, **kwargs): ...
    def name(self, *args, **kwargs): ...
    def node(self, *args, **kwargs): ...
    def numChildren(self, *args, **kwargs): ...
    def numConnectedChildren(self, *args, **kwargs): ...
    def numConnectedElements(self, *args, **kwargs): ...
    def numElements(self, *args, **kwargs): ...
    def parent(self, *args, **kwargs): ...
    def partialName(self, *args, **kwargs): ...
    def proxied(self, *args, **kwargs): ...
    def selectAncestorLogicalIndex(self, *args, **kwargs): ...
    def setAttribute(self, *args, **kwargs): ...
    def setBool(self, *args, **kwargs): ...
    def setChar(self, *args, **kwargs): ...
    def setDouble(self, *args, **kwargs): ...
    def setFloat(self, *args, **kwargs): ...
    def setInt(self, *args, **kwargs): ...
    def setMAngle(self, *args, **kwargs): ...
    def setMDataHandle(self, *args, **kwargs): ...
    def setMDistance(self, *args, **kwargs): ...
    def setMObject(self, *args, **kwargs): ...
    def setMPxData(self, *args, **kwargs): ...
    def setMTime(self, *args, **kwargs): ...
    def setNumElements(self, *args, **kwargs): ...
    def setShort(self, *args, **kwargs): ...
    def setString(self, *args, **kwargs): ...
    def source(self, *args, **kwargs): ...
    @overload
    def sourceWithConversion(self) -> Any: ...
    @overload
    def sourceWithConversion(self) -> Any: ...  # type: ignore
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MPlugArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MPoint:
    kOrigin: ClassVar[MPoint] = ...
    kTolerance: ClassVar[float] = ...
    w: Incomplete
    x: Incomplete
    y: Incomplete
    z: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def cartesianize(self, *args, **kwargs): ...
    def distanceTo(self, *args, **kwargs): ...
    def homogenize(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def rationalize(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __isub__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __rtruediv__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __sub__(self, other): ...
    def __truediv__(self, other): ...

class MPointArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MPointOnMesh:
    barycentricCoords: Incomplete
    face: Any
    normal: Any
    point: Any
    triangle: Any
    def __init__(self, *args, **kwargs) -> None: ...

class MPolyMessage(MMessage):
    @staticmethod
    def addPolyComponentIdChangedCallback(*args, **kwargs): ...
    @staticmethod
    def addPolyTopologyChangedCallback(node, function, clientData=...) -> id: ...  # type: ignore

class MPxAttributePatternFactory:
    def __init__(self, *args, **kwargs) -> None: ...

class MPxCommand:
    kDouble: ClassVar[int] = ...
    kLong: ClassVar[int] = ...
    kNoArg: ClassVar[int] = ...
    kString: ClassVar[int] = ...
    commandString: Incomplete
    historyOn: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    @staticmethod
    def appendToResult(*args, **kwargs): ...
    @staticmethod
    def clearResult(*args, **kwargs): ...
    @staticmethod
    def currentResult(*args, **kwargs): ...
    @staticmethod
    def currentResultType(*args, **kwargs): ...
    @staticmethod
    def displayError(*args, **kwargs): ...
    @staticmethod
    def displayInfo(*args, **kwargs): ...
    @staticmethod
    def displayWarning(*args, **kwargs): ...
    def doIt(self, *args, **kwargs): ...
    def hasSyntax(self, *args, **kwargs): ...
    @staticmethod
    def isCurrentResultArray(*args, **kwargs): ...
    def isUndoable(self, *args, **kwargs): ...
    def redoIt(self, *args, **kwargs): ...
    @staticmethod
    def setResult(*args, **kwargs): ...
    def syntax(self, *args, **kwargs): ...
    def undoIt(self, *args, **kwargs): ...

class MPxData:
    kData: ClassVar[int] = ...
    kGeometryData: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def copy(self, src) -> self: ...  # type: ignore
    def name(self) -> string: ...  # type: ignore
    def readASCII(self, argList, endOfTheLastParsedElement) -> int: ...
    def readBinary(self, _in, length) -> int: ...
    def typeId(self) -> MTypeId: ...
    def writeASCII(self) -> string: ...  # type: ignore
    def writeBinary(self) -> bytearray: ...

class MPxGeometryData(MPxData):
    matrix: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def deleteComponent(self, compList) -> bool: ...
    def deleteComponentsFromGroups(self, compList, groupIdArray, groupComponentArray) -> bool: ...
    def getMatrix(self, matrix) -> bool: ...
    def iterator(self, componentList, component, useComponents, world=...) -> MPxGeometryIterator: ...
    def smartCopy(self, srcGeom) -> self: ...  # type: ignore
    def updateCompleteVertexGroup(self, component) -> bool: ...

class MPxGeometryIterator:
    currentPoint: Incomplete
    maxPoints: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def component(self) -> MObject: ...
    def geometry(self, *args, **kwargs): ...
    def hasNormals(self) -> bool: ...
    def hasPoints(self) -> bool: ...
    def index(self) -> int: ...
    def indexUnsimplified(self) -> int: ...
    def isDone(self) -> bool: ...
    def iteratorCount(self) -> int: ...
    def next(self) -> self: ...  # type: ignore
    def point(self) -> MPoint: ...
    def reset(self) -> self: ...  # type: ignore
    def setObject(self, shape) -> self: ...  # type: ignore
    def setPoint(self, point) -> self: ...  # type: ignore
    def setPointGetNext(self, point) -> int: ...
    def __iter__(self): ...
    def __next__(self): ...

class MPxNode:
    kAssembly: ClassVar[int] = ...
    kBlendShape: ClassVar[int] = ...
    kCameraSetNode: ClassVar[int] = ...
    kClientDeviceNode: ClassVar[int] = ...
    kConstraintNode: ClassVar[int] = ...
    kDeformerNode: ClassVar[int] = ...
    kDependNode: ClassVar[int] = ...
    kEmitterNode: ClassVar[int] = ...
    kEvaluatedDirectly: ClassVar[int] = ...
    kEvaluatedIndirectly: ClassVar[int] = ...
    kFieldNode: ClassVar[int] = ...
    kFluidEmitterNode: ClassVar[int] = ...
    kGeometryFilter: ClassVar[int] = ...
    kHardwareShader: ClassVar[int] = ...
    kHwShaderNode: ClassVar[int] = ...
    kIkSolverNode: ClassVar[int] = ...
    kImagePlaneNode: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kLeaveDirty: ClassVar[int] = ...
    kLocatorNode: ClassVar[int] = ...
    kManipContainer: ClassVar[int] = ...
    kManipulatorNode: ClassVar[int] = ...
    kMotionPathNode: ClassVar[int] = ...
    kObjectSet: ClassVar[int] = ...
    kParticleAttributeMapperNode: ClassVar[int] = ...
    kPostEvaluationTypeLast: ClassVar[int] = ...
    kSkinCluster: ClassVar[int] = ...
    kSpringNode: ClassVar[int] = ...
    kSurfaceShape: ClassVar[int] = ...
    kThreadedDeviceNode: ClassVar[int] = ...
    kTransformNode: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    @staticmethod
    def addAttribute(attr) -> None: ...
    @overload
    @staticmethod
    def addAttribute() -> Any: ...
    def addExternalContentForFileAttr(self, table, attr) -> bool: ...
    @staticmethod
    def attributeAffects(whenChanges, isAffected) -> None: ...
    def compute(self, plug, dataBlock) -> self: ...  # type: ignore
    def configCache(self, evalNode, schema) -> None: ...
    def connectionBroken(self, plug, otherPlug, asSrc) -> self: ...  # type: ignore
    def connectionMade(self, plug, otherPlug, asSrc) -> self: ...  # type: ignore
    def copyInternalData(self, node) -> self: ...  # type: ignore
    def dependsOn(self, *args, **kwargs): ...
    def doNotWrite(self) -> bool: ...
    def existWithoutInConnections(self) -> bool: ...
    def existWithoutOutConnections(self) -> bool: ...
    def forceCache(self, ctx=...) -> MDataBlock: ...
    def getCacheSetup(self, evalNode, disablingInfo, setupInfo, objectArray) -> None: ...
    def getExternalContent(self, table) -> self: ...  # type: ignore
    def getFilesToArchive(self, shortName=..., unresolvedName=..., markCouldBeImageSequence=...) -> listofstrings: ...  # type: ignore
    def getInternalValue(self, plug, dataHandle) -> bool: ...
    def getInternalValueInContext(self, plug, dataHandle, ctx) -> bool[OBSOLETE]: ...  # type: ignore
    def hasInvalidationRangeTransformation(self) -> bool: ...
    @staticmethod
    def inheritAttributesFrom(parentClassName) -> None: ...
    @overload
    def internalArrayCount(self, plug) -> int: ...
    @overload
    def internalArrayCount(self, plug, ctx) -> int[OBSOLETE]: ...  # type: ignore
    def isAbstractClass(self) -> bool: ...
    def isPassiveOutput(self, plug) -> bool: ...
    def legalConnection(self, *args, **kwargs): ...
    def legalDisconnection(self, *args, **kwargs): ...
    def name(self) -> string: ...  # type: ignore
    def passThroughToMany(self, plug, plugArray) -> bool: ...
    def passThroughToOne(self, plug) -> plug: ...  # type: ignore
    def postConstructor(self) -> self: ...  # type: ignore
    def postEvaluation(self, context, evalNode, evalType) -> None: ...
    def preEvaluation(self, context, evalNode) -> None: ...
    @overload
    def setDependentsDirty(self, plug, plugArray) -> self: ...  # type: ignore
    @overload
    def setDependentsDirty(self) -> Any: ...
    @overload
    def setDependentsDirty(self) -> Any: ...  # type: ignore
    def setDoNotWrite(self, bool) -> self: ...  # type: ignore
    def setExistWithoutInConnections(self, bool) -> bool: ...
    def setExistWithoutOutConnections(self, bool) -> bool: ...
    def setExternalContent(self, table) -> self: ...  # type: ignore
    def setExternalContentForFileAttr(self, attr, table) -> bool: ...
    def setInternalValue(self, plug, dataHandle) -> bool: ...
    def setInternalValueInContext(self, plug, dataHandle, ctx) -> bool[OBSOLETE]: ...  # type: ignore
    def setMPSafe(self, bool) -> self: ...  # type: ignore
    def shouldSave(self, *args, **kwargs): ...
    def thisMObject(self) -> MObject: ...
    def transformInvalidationRange(self, plug, timeRange) -> timeRange: ...  # type: ignore
    def type(self) -> int: ...
    def typeId(self) -> MTypeId: ...
    def typeName(self) -> string: ...  # type: ignore

class MPxSurfaceShape(MPxNode):
    boundingBoxCenterX: ClassVar[MObject] = ...
    boundingBoxCenterY: ClassVar[MObject] = ...
    boundingBoxCenterZ: ClassVar[MObject] = ...
    center: ClassVar[MObject] = ...
    instObjGroups: ClassVar[MObject] = ...
    intermediateObject: ClassVar[MObject] = ...
    inverseMatrix: ClassVar[MObject] = ...
    isTemplated: ClassVar[MObject] = ...
    kBoundingBoxChanged: ClassVar[int] = ...
    kMatchInvalidAttribute: ClassVar[int] = ...
    kMatchInvalidAttributeDim: ClassVar[int] = ...
    kMatchInvalidAttributeIndex: ClassVar[int] = ...
    kMatchInvalidAttributeRange: ClassVar[int] = ...
    kMatchInvalidName: ClassVar[int] = ...
    kMatchNone: ClassVar[int] = ...
    kMatchOk: ClassVar[int] = ...
    kMatchTooMany: ClassVar[int] = ...
    kNoPointCaching: ClassVar[int] = ...
    kNormal: ClassVar[int] = ...
    kObjectChanged: ClassVar[int] = ...
    kRestorePoints: ClassVar[int] = ...
    kSavePoints: ClassVar[int] = ...
    kTransformOriginalPoints: ClassVar[int] = ...
    kUTangent: ClassVar[int] = ...
    kUVNTriad: ClassVar[int] = ...
    kUpdatePoints: ClassVar[int] = ...
    kVTangent: ClassVar[int] = ...
    mControlPoints: ClassVar[MObject] = ...
    mControlValueX: ClassVar[MObject] = ...
    mControlValueY: ClassVar[MObject] = ...
    mControlValueZ: ClassVar[MObject] = ...
    mHasHistoryOnCreate: ClassVar[MObject] = ...
    matrix: ClassVar[MObject] = ...
    nodeBoundingBox: ClassVar[MObject] = ...
    nodeBoundingBoxMax: ClassVar[MObject] = ...
    nodeBoundingBoxMaxX: ClassVar[MObject] = ...
    nodeBoundingBoxMaxZ: ClassVar[MObject] = ...
    nodeBoundingBoxMin: ClassVar[MObject] = ...
    nodeBoundingBoxMinX: ClassVar[MObject] = ...
    nodeBoundingBoxMinY: ClassVar[MObject] = ...
    nodeBoundingBoxMinZ: ClassVar[MObject] = ...
    nodeBoundingBoxSize: ClassVar[MObject] = ...
    nodeBoundingBoxSizeX: ClassVar[MObject] = ...
    nodeBoundingBoxSizeY: ClassVar[MObject] = ...
    nodeBoundingBoxSizeZ: ClassVar[MObject] = ...
    objectColor: ClassVar[MObject] = ...
    objectGroupColor: ClassVar[MObject] = ...
    objectGroupId: ClassVar[MObject] = ...
    objectGroups: ClassVar[MObject] = ...
    objectGrpCompList: ClassVar[MObject] = ...
    parentInverseMatrix: ClassVar[MObject] = ...
    parentMatrix: ClassVar[MObject] = ...
    useObjectColor: ClassVar[MObject] = ...
    visibility: ClassVar[MObject] = ...
    worldInverseMatrix: ClassVar[MObject] = ...
    worldMatrix: ClassVar[MObject] = ...
    isRenderable: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def acceptsGeometryIterator(self, component, writeable=..., forReadOnly=...) -> bool: ...
    def activeComponents(self) -> MObjectArray: ...
    def boundingBox(self) -> MBoundingBox: ...
    def cachedShapeAttr(self) -> MObject: ...
    def canMakeLive(self) -> bool: ...
    def childChanged(self, state=...) -> self: ...  # type: ignore
    @overload
    def closestPoint(self, toThisPoint, theClosestPoint, tolerance=...) -> self: ...  # type: ignore
    @overload
    def closestPoint(self, raySource, rayDirection, theClosestPoint, theClosestNormal, findClosestOnMiss, tolerance=...) -> bool: ...
    def componentToPlugs(self, component, selectionList) -> self: ...  # type: ignore
    def convertToTweakNodePlug(self, plug) -> bool: ...
    def createFullRenderGroup(self) -> MObject: ...
    def createFullVertexGroup(self) -> MObject: ...
    def deleteComponents(self, componentList, undoInfo) -> bool: ...
    @overload
    def excludeAsPluginShape(self) -> bool: ...
    @overload
    def excludeAsPluginShape(self) -> Any: ...  # type: ignore
    def geometryData(self) -> MObject: ...
    def geometryIteratorSetup(self, componentList, components, forReadOnly=...) -> MPxGeometryIterator: ...
    def getComponentSelectionMask(self) -> MSelectionMask: ...
    def getShapeSelectionMask(self) -> MSelectionMask: ...
    def getWorldMatrix(self, block, instanceGeom) -> MMatrix: ...
    def hasActiveComponents(self) -> bool: ...
    def isBounded(self) -> bool: ...
    def localShapeInAttr(self) -> MObject: ...
    def localShapeOutAttr(self) -> MObject: ...
    def match(self, mask, componentList) -> bool: ...
    def matchComponent(self, item, spec, list) -> int: ...
    def newControlPointComponent(self) -> MObject: ...
    def pointAtParm(self, atThisParm, evaluatedPoint) -> bool: ...
    def renderGroupComponentType(self) -> int: ...
    def transformUsing(self, matrix, componentList, cachingMode=..., pointCache=...) -> self: ...  # type: ignore
    def tweakUsing(self, matrix, componentList, cachingMode, pointCache, handle) -> self: ...  # type: ignore
    def undeleteComponents(self, componentList, undoInfo) -> bool: ...
    def vertexOffsetDirection(self, component, direction, mode, normalize) -> bool: ...
    def weightedTransformUsing(self, xform, space, componentList, cachingMode, pointCache, freezePlane) -> self: ...  # type: ignore
    def weightedTweakUsing(self, xform, space, componentList, cachingMode, pointCache, freezePlane, handle) -> self: ...  # type: ignore
    def worldShapeOutAttr(self) -> MObject: ...

class MQuaternion:
    kIdentity: ClassVar[MQuaternion] = ...
    kTolerance: ClassVar[float] = ...
    w: Incomplete
    x: Incomplete
    y: Incomplete
    z: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def asAxisAngle(self, *args, **kwargs): ...
    def asEulerRotation(self, *args, **kwargs): ...
    def asMatrix(self, *args, **kwargs): ...
    def conjugate(self, *args, **kwargs): ...
    def conjugateIt(self, *args, **kwargs): ...
    def exp(self, *args, **kwargs): ...
    def inverse(self, *args, **kwargs): ...
    def invertIt(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def log(self, *args, **kwargs): ...
    def negateIt(self, *args, **kwargs): ...
    def normal(self, *args, **kwargs): ...
    def normalizeIt(self, *args, **kwargs): ...
    def setToXAxis(self, *args, **kwargs): ...
    def setToYAxis(self, *args, **kwargs): ...
    def setToZAxis(self, *args, **kwargs): ...
    def setValue(self, *args, **kwargs): ...
    @staticmethod
    def slerp(*args, **kwargs): ...
    @staticmethod
    def squad(*args, **kwargs): ...
    @staticmethod
    def squadPt(*args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __imul__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __neg__(self): ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __sub__(self, other): ...

class MRampAttribute:
    kLinear: ClassVar[int] = ...
    kNone: ClassVar[int] = ...
    kSmooth: ClassVar[int] = ...
    kSpline: ClassVar[int] = ...
    isColorRamp: Incomplete
    isCurveRamp: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def addEntries(self, *args, **kwargs): ...
    @staticmethod
    def createColorRamp(*args, **kwargs): ...
    @staticmethod
    def createCurveRamp(*args, **kwargs): ...
    @staticmethod
    def createRamp(*args, **kwargs): ...
    def deleteEntries(self, *args, **kwargs): ...
    def getEntries(self, *args, **kwargs): ...
    def getValueAtPosition(self, *args, **kwargs): ...
    def hasIndex(self, *args, **kwargs): ...
    def numEntries(self, *args, **kwargs): ...
    def pack(self, *args, **kwargs): ...
    def setInterpolationAtIndex(self, *args, **kwargs): ...
    def setPositionAtIndex(self, *args, **kwargs): ...
    def setRamp(self, *args, **kwargs): ...
    def setValueAtIndex(self, *args, **kwargs): ...
    def sort(self, *args, **kwargs): ...

class MRichSelection:
    def __init__(self, *args, **kwargs) -> None: ...
    def clear(self) -> self: ...  # type: ignore
    def getRawSymmetryMatrix(self, *args, **kwargs): ...
    def getSelection(self) -> MSelectionList: ...
    def getSymmetry(self) -> MSelectionList: ...
    def getSymmetryMatrix(self, MDagPath, space) -> MMatrix: ...
    def getSymmetryPlane(self, MDagPath, space) -> MPlane: ...
    def setSelection(self, MSelectionList) -> self: ...  # type: ignore

class MSceneMessage(MMessage):
    kAfterCreateReference: ClassVar[int] = ...
    kAfterCreateReferenceAndRecordEdits: ClassVar[int] = ...
    kAfterExport: ClassVar[int] = ...
    kAfterExportReference: ClassVar[int] = ...
    kAfterFileRead: ClassVar[int] = ...
    kAfterImport: ClassVar[int] = ...
    kAfterImportReference: ClassVar[int] = ...
    kAfterLoadReference: ClassVar[int] = ...
    kAfterLoadReferenceAndRecordEdits: ClassVar[int] = ...
    kAfterNew: ClassVar[int] = ...
    kAfterOpen: ClassVar[int] = ...
    kAfterPluginLoad: ClassVar[int] = ...
    kAfterPluginUnload: ClassVar[int] = ...
    kAfterReference: ClassVar[int] = ...
    kAfterRemoveReference: ClassVar[int] = ...
    kAfterSave: ClassVar[int] = ...
    kAfterSceneReadAndRecordEdits: ClassVar[int] = ...
    kAfterSoftwareFrameRender: ClassVar[int] = ...
    kAfterSoftwareRender: ClassVar[int] = ...
    kAfterUnloadReference: ClassVar[int] = ...
    kBeforeCreateReference: ClassVar[int] = ...
    kBeforeCreateReferenceAndRecordEdits: ClassVar[int] = ...
    kBeforeCreateReferenceCheck: ClassVar[int] = ...
    kBeforeExport: ClassVar[int] = ...
    kBeforeExportCheck: ClassVar[int] = ...
    kBeforeExportReference: ClassVar[int] = ...
    kBeforeFileRead: ClassVar[int] = ...
    kBeforeImport: ClassVar[int] = ...
    kBeforeImportCheck: ClassVar[int] = ...
    kBeforeImportReference: ClassVar[int] = ...
    kBeforeLoadReference: ClassVar[int] = ...
    kBeforeLoadReferenceAndRecordEdits: ClassVar[int] = ...
    kBeforeLoadReferenceCheck: ClassVar[int] = ...
    kBeforeNew: ClassVar[int] = ...
    kBeforeNewCheck: ClassVar[int] = ...
    kBeforeOpen: ClassVar[int] = ...
    kBeforeOpenCheck: ClassVar[int] = ...
    kBeforePluginLoad: ClassVar[int] = ...
    kBeforePluginUnload: ClassVar[int] = ...
    kBeforeReference: ClassVar[int] = ...
    kBeforeReferenceCheck: ClassVar[int] = ...
    kBeforeRemoveReference: ClassVar[int] = ...
    kBeforeSave: ClassVar[int] = ...
    kBeforeSaveCheck: ClassVar[int] = ...
    kBeforeSoftwareFrameRender: ClassVar[int] = ...
    kBeforeSoftwareRender: ClassVar[int] = ...
    kBeforeUnloadReference: ClassVar[int] = ...
    kExportStarted: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kMayaExiting: ClassVar[int] = ...
    kMayaInitialized: ClassVar[int] = ...
    kSceneUpdate: ClassVar[int] = ...
    kSoftwareRenderInterrupted: ClassVar[int] = ...
    @staticmethod
    def addCallback(message, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addCheckCallback(message, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addCheckFileCallback(message, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addCheckReferenceCallback(message, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addConnectionFailedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addNamespaceRenamedCallback(function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addReferenceCallback(message, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def addStringArrayCallback(message, function, clientData=...) -> id: ...  # type: ignore

class MSelectionList:
    kMergeNormal: ClassVar[int] = ...
    kRemoveFromList: ClassVar[int] = ...
    kXORWithList: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def add(self, pattern, searchChildNamespaces=...) -> self: ...  # type: ignore
    @overload
    def add(self, item, mergeWithExisting=...) -> self: ...  # type: ignore
    def clear(self) -> self: ...  # type: ignore
    def copy(self, src) -> self: ...  # type: ignore
    def getComponent(self, *args, **kwargs): ...
    def getDagPath(self, index) -> MDagPath: ...
    def getDependNode(self, index) -> MObject: ...
    def getPlug(self, *args, **kwargs): ...
    def getSelectionStrings(self, *args, **kwargs): ...
    def hasItem(self, item) -> bool: ...
    def hasItemPartly(self, dagPath, component) -> bool: ...
    def intersect(self, other, expandToLeaves=...) -> self: ...  # type: ignore
    def isEmpty(self) -> bool: ...
    def length(self) -> int: ...
    @overload
    def merge(self, other, strategy=...) -> self: ...  # type: ignore
    @overload
    def merge(self, dagPath, component, strategy=...) -> self: ...  # type: ignore
    def remove(self, index) -> self: ...  # type: ignore
    def replace(self, index, newItem) -> self: ...  # type: ignore
    def toggle(self, dagPath, component) -> self: ...  # type: ignore

class MSelectionMask:
    kSelectAnimAny: ClassVar[int] = ...
    kSelectAnimCurves: ClassVar[int] = ...
    kSelectAnimInTangents: ClassVar[int] = ...
    kSelectAnimKeyframes: ClassVar[int] = ...
    kSelectAnimMask: ClassVar[int] = ...
    kSelectAnimOutTangents: ClassVar[int] = ...
    kSelectCVs: ClassVar[int] = ...
    kSelectCameras: ClassVar[int] = ...
    kSelectClusters: ClassVar[int] = ...
    kSelectCollisionModels: ClassVar[int] = ...
    kSelectComponentsMask: ClassVar[int] = ...
    kSelectCurveKnots: ClassVar[int] = ...
    kSelectCurveParmPoints: ClassVar[int] = ...
    kSelectCurves: ClassVar[int] = ...
    kSelectCurvesOnSurfaces: ClassVar[int] = ...
    kSelectDynamicConstraints: ClassVar[int] = ...
    kSelectEdges: ClassVar[int] = ...
    kSelectEditPoints: ClassVar[int] = ...
    kSelectEmitters: ClassVar[int] = ...
    kSelectFacets: ClassVar[int] = ...
    kSelectFields: ClassVar[int] = ...
    kSelectFluids: ClassVar[int] = ...
    kSelectFollicles: ClassVar[int] = ...
    kSelectGuideLines: ClassVar[int] = ...
    kSelectHairSystems: ClassVar[int] = ...
    kSelectHandles: ClassVar[int] = ...
    kSelectHulls: ClassVar[int] = ...
    kSelectIkEndEffectors: ClassVar[int] = ...
    kSelectIkHandles: ClassVar[int] = ...
    kSelectIsoparms: ClassVar[int] = ...
    kSelectJointPivots: ClassVar[int] = ...
    kSelectJoints: ClassVar[int] = ...
    kSelectLatticePoints: ClassVar[int] = ...
    kSelectLattices: ClassVar[int] = ...
    kSelectLights: ClassVar[int] = ...
    kSelectLocalAxis: ClassVar[int] = ...
    kSelectLocators: ClassVar[int] = ...
    kSelectManipulators: ClassVar[int] = ...
    kSelectMeshComponents: ClassVar[int] = ...
    kSelectMeshEdges: ClassVar[int] = ...
    kSelectMeshFaces: ClassVar[int] = ...
    kSelectMeshFreeEdges: ClassVar[int] = ...
    kSelectMeshLines: ClassVar[int] = ...
    kSelectMeshUVs: ClassVar[int] = ...
    kSelectMeshVerts: ClassVar[int] = ...
    kSelectMeshes: ClassVar[int] = ...
    kSelectNCloths: ClassVar[int] = ...
    kSelectNParticles: ClassVar[int] = ...
    kSelectNRigids: ClassVar[int] = ...
    kSelectNurbsCurves: ClassVar[int] = ...
    kSelectNurbsSurfaces: ClassVar[int] = ...
    kSelectObjectGroups: ClassVar[int] = ...
    kSelectObjectsMask: ClassVar[int] = ...
    kSelectOrientationLocators: ClassVar[int] = ...
    kSelectPPStrokes: ClassVar[int] = ...
    kSelectParticleShapes: ClassVar[int] = ...
    kSelectParticles: ClassVar[int] = ...
    kSelectPivots: ClassVar[int] = ...
    kSelectPointsForGravity: ClassVar[int] = ...
    kSelectPointsOnCurvesForGravity: ClassVar[int] = ...
    kSelectPointsOnSurfacesForGravity: ClassVar[int] = ...
    kSelectRigidBodies: ClassVar[int] = ...
    kSelectRigidConstraints: ClassVar[int] = ...
    kSelectRotatePivots: ClassVar[int] = ...
    kSelectScalePivots: ClassVar[int] = ...
    kSelectSculpts: ClassVar[int] = ...
    kSelectSelectHandles: ClassVar[int] = ...
    kSelectSketchPlanes: ClassVar[int] = ...
    kSelectSprings: ClassVar[int] = ...
    kSelectSubdiv: ClassVar[int] = ...
    kSelectSubdivMeshEdges: ClassVar[int] = ...
    kSelectSubdivMeshFaces: ClassVar[int] = ...
    kSelectSubdivMeshMaps: ClassVar[int] = ...
    kSelectSubdivMeshPoints: ClassVar[int] = ...
    kSelectSurfaceEdge: ClassVar[int] = ...
    kSelectSurfaceKnots: ClassVar[int] = ...
    kSelectSurfaceParmPoints: ClassVar[int] = ...
    kSelectSurfaceRange: ClassVar[int] = ...
    kSelectSurfaces: ClassVar[int] = ...
    kSelectTemplates: ClassVar[int] = ...
    kSelectTextures: ClassVar[int] = ...
    kSelectUVLocators: ClassVar[int] = ...
    kSelectVertices: ClassVar[int] = ...
    kSelectXYZLocators: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def addMask(self, selType) -> self: ...  # type: ignore
    def copy(self, source) -> self: ...  # type: ignore
    @staticmethod
    def deregisterSelectionType(selTypeName) -> bool: ...
    @staticmethod
    def getSelectionTypePriority(selTypeName) -> int: ...
    @overload
    def intersects(self, mask) -> bool: ...
    @overload
    def intersects(self, selType) -> bool: ...
    @overload
    @staticmethod
    def registerSelectionType(selTypeName, priority=...) -> bool: ...
    @overload
    @staticmethod
    def registerSelectionType() -> Any: ...
    @overload
    @staticmethod
    def registerSelectionType() -> Any: ...  # type: ignore
    @overload
    def setMask(self, mask) -> self: ...  # type: ignore
    @overload
    def setMask(self, selType) -> self: ...  # type: ignore

class MSpace:
    kInvalid: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kObject: ClassVar[int] = ...
    kPostTransform: ClassVar[int] = ...
    kPreTransform: ClassVar[int] = ...
    kTransform: ClassVar[int] = ...
    kWorld: ClassVar[int] = ...

class MSyntax:
    kAngle: ClassVar[int] = ...
    kBoolean: ClassVar[int] = ...
    kDistance: ClassVar[int] = ...
    kDouble: ClassVar[int] = ...
    kInvalidArgType: ClassVar[int] = ...
    kInvalidObjectFormat: ClassVar[int] = ...
    kLastArgType: ClassVar[int] = ...
    kLastObjectFormat: ClassVar[int] = ...
    kLong: ClassVar[int] = ...
    kNoArg: ClassVar[int] = ...
    kNone: ClassVar[int] = ...
    kSelectionItem: ClassVar[int] = ...
    kSelectionList: ClassVar[int] = ...
    kString: ClassVar[int] = ...
    kStringObjects: ClassVar[int] = ...
    kTime: ClassVar[int] = ...
    kUnsigned: ClassVar[int] = ...
    enableEdit: Incomplete
    enableQuery: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def addArg(self, *args, **kwargs): ...
    def addFlag(self, *args, **kwargs): ...
    def makeFlagMultiUse(self, *args, **kwargs): ...
    def makeFlagQueryWithFullArgs(self, *args, **kwargs): ...
    def maxObjects(self, *args, **kwargs): ...
    def minObjects(self, *args, **kwargs): ...
    def setMaxObjects(self, *args, **kwargs): ...
    def setMinObjects(self, *args, **kwargs): ...
    def setObjectType(self, *args, **kwargs): ...
    def useSelectionAsDefault(self, *args, **kwargs): ...

class MTime:
    k100FPS: ClassVar[int] = ...
    k10FPS: ClassVar[int] = ...
    k119_88FPS: ClassVar[int] = ...
    k1200FPS: ClassVar[int] = ...
    k120FPS: ClassVar[int] = ...
    k125FPS: ClassVar[int] = ...
    k12FPS: ClassVar[int] = ...
    k1500FPS: ClassVar[int] = ...
    k150FPS: ClassVar[int] = ...
    k15FPS: ClassVar[int] = ...
    k16FPS: ClassVar[int] = ...
    k2000FPS: ClassVar[int] = ...
    k200FPS: ClassVar[int] = ...
    k20FPS: ClassVar[int] = ...
    k23_976FPS: ClassVar[int] = ...
    k240FPS: ClassVar[int] = ...
    k24FPS: ClassVar[int] = ...
    k250FPS: ClassVar[int] = ...
    k25FPS: ClassVar[int] = ...
    k29_97DF: ClassVar[int] = ...
    k29_97FPS: ClassVar[int] = ...
    k2FPS: ClassVar[int] = ...
    k3000FPS: ClassVar[int] = ...
    k300FPS: ClassVar[int] = ...
    k30FPS: ClassVar[int] = ...
    k375FPS: ClassVar[int] = ...
    k3FPS: ClassVar[int] = ...
    k400FPS: ClassVar[int] = ...
    k40FPS: ClassVar[int] = ...
    k44100FPS: ClassVar[int] = ...
    k47_952FPS: ClassVar[int] = ...
    k48000FPS: ClassVar[int] = ...
    k48FPS: ClassVar[int] = ...
    k4FPS: ClassVar[int] = ...
    k500FPS: ClassVar[int] = ...
    k50FPS: ClassVar[int] = ...
    k59_94FPS: ClassVar[int] = ...
    k5FPS: ClassVar[int] = ...
    k6000FPS: ClassVar[int] = ...
    k600FPS: ClassVar[int] = ...
    k60FPS: ClassVar[int] = ...
    k6FPS: ClassVar[int] = ...
    k750FPS: ClassVar[int] = ...
    k75FPS: ClassVar[int] = ...
    k80FPS: ClassVar[int] = ...
    k8FPS: ClassVar[int] = ...
    k90FPS: ClassVar[int] = ...
    kFilm: ClassVar[int] = ...
    kGames: ClassVar[int] = ...
    kHours: ClassVar[int] = ...
    kInvalid: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kMilliseconds: ClassVar[int] = ...
    kMinutes: ClassVar[int] = ...
    kNTSCField: ClassVar[int] = ...
    kNTSCFrame: ClassVar[int] = ...
    kPALField: ClassVar[int] = ...
    kPALFrame: ClassVar[int] = ...
    kSeconds: ClassVar[int] = ...
    kShowScan: ClassVar[int] = ...
    kUserDef: ClassVar[int] = ...
    unit: Incomplete
    value: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def asUnits(self, *args, **kwargs): ...
    @staticmethod
    def setUIUnit(*args, **kwargs): ...
    @staticmethod
    def ticksPerSecond(*args, **kwargs): ...
    @staticmethod
    def uiUnit(*args, **kwargs): ...
    def __add__(self, other): ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __isub__(self, other): ...
    def __itruediv__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __rtruediv__(self, other): ...
    def __sub__(self, other): ...
    def __truediv__(self, other): ...

class MTimeArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MTimeRange:
    def __init__(self, *args, **kwargs) -> None: ...
    def contains(self, *args, **kwargs): ...
    def empty(self) -> bool: ...
    def intersects(self, *args, **kwargs): ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other): ...
    def __ror__(self, other): ...

class MTimerMessage(MMessage):
    @staticmethod
    def addTimerCallback(period, function, clientData=...) -> id: ...  # type: ignore

class MTransformationMatrix:
    kIdentity: ClassVar[MTransformationMatrix] = ...
    kInvalid: ClassVar[int] = ...
    kLast: ClassVar[int] = ...
    kTolerance: ClassVar[float] = ...
    kXYZ: ClassVar[int] = ...
    kXZY: ClassVar[int] = ...
    kYXZ: ClassVar[int] = ...
    kYZX: ClassVar[int] = ...
    kZXY: ClassVar[int] = ...
    kZYX: ClassVar[int] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def asMatrix(self, *args, **kwargs): ...
    def asMatrixInverse(self, *args, **kwargs): ...
    def asRotateMatrix(self, *args, **kwargs): ...
    def asScaleMatrix(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def reorderRotation(self, *args, **kwargs): ...
    def rotateBy(self, *args, **kwargs): ...
    def rotateByComponents(self, *args, **kwargs): ...
    def rotatePivot(self, *args, **kwargs): ...
    def rotatePivotTranslation(self, *args, **kwargs): ...
    def rotation(self, *args, **kwargs): ...
    def rotationComponents(self, *args, **kwargs): ...
    def rotationOrder(self, *args, **kwargs): ...
    def rotationOrientation(self, *args, **kwargs): ...
    def scale(self, *args, **kwargs): ...
    def scaleBy(self, *args, **kwargs): ...
    def scalePivot(self, *args, **kwargs): ...
    def scalePivotTranslation(self, *args, **kwargs): ...
    def setRotatePivot(self, *args, **kwargs): ...
    def setRotatePivotTranslation(self, *args, **kwargs): ...
    def setRotation(self, *args, **kwargs): ...
    def setRotationComponents(self, *args, **kwargs): ...
    def setRotationOrientation(self, *args, **kwargs): ...
    def setScale(self, *args, **kwargs): ...
    def setScalePivot(self, *args, **kwargs): ...
    def setScalePivotTranslation(self, *args, **kwargs): ...
    def setShear(self, *args, **kwargs): ...
    def setToRotationAxis(self, *args, **kwargs): ...
    def setTranslation(self, *args, **kwargs): ...
    def shear(self, *args, **kwargs): ...
    def shearBy(self, *args, **kwargs): ...
    def translateBy(self, *args, **kwargs): ...
    def translation(self, *args, **kwargs): ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MTypeId:
    def __init__(self, *args, **kwargs) -> None: ...
    def id(self, *args, **kwargs): ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MURI:
    def __init__(self, *args, **kwargs) -> None: ...
    def addQueryItem(self, key, value) -> self: ...  # type: ignore
    def asString(self) -> string: ...  # type: ignore
    def clear(self) -> self: ...  # type: ignore
    def copy(self, source) -> self: ...  # type: ignore
    def getAllQueryItemKeys(self) -> array: ...  # type: ignore
    def getAllQueryItemValues(self, key) -> array: ...  # type: ignore
    def getAuthority(self) -> string: ...  # type: ignore
    def getDirectory(self) -> string: ...  # type: ignore
    def getFileName(self, boolincludeExtension=...) -> string: ...  # type: ignore
    def getFragment(self) -> string: ...  # type: ignore
    def getHost(self) -> string: ...  # type: ignore
    def getPassword(self) -> string: ...  # type: ignore
    def getPath(self) -> string: ...  # type: ignore
    def getPort(self) -> int: ...
    def getQueryItemValue(self, key) -> string: ...  # type: ignore
    def getQueryPairDelimiter(self) -> string: ...  # type: ignore
    def getQueryValueDelimiter(self) -> string: ...  # type: ignore
    def getScheme(self) -> string: ...  # type: ignore
    def getUserInfo(self) -> string: ...  # type: ignore
    def getUserName(self) -> string: ...  # type: ignore
    def isEmpty(self) -> bool: ...
    def isValid(self) -> bool: ...
    @staticmethod
    def isValidURI(uri) -> bool: ...
    def removeAllQueryItems(self, int) -> self: ...  # type: ignore
    def removeQueryItem(self, int) -> self: ...  # type: ignore
    def setAuthority(self, string) -> self: ...  # type: ignore
    def setDirectory(self, string) -> self: ...  # type: ignore
    def setFileName(self, string) -> self: ...  # type: ignore
    def setFragment(self, string) -> self: ...  # type: ignore
    def setHost(self, string) -> self: ...  # type: ignore
    def setPassword(self, string) -> self: ...  # type: ignore
    def setPath(self, string) -> self: ...  # type: ignore
    def setPort(self, int) -> self: ...  # type: ignore
    def setQueryDelimiters(self, valueDelimiter, pairDelimiter) -> self: ...  # type: ignore
    def setScheme(self, string) -> self: ...  # type: ignore
    def setURI(self, uri) -> self: ...  # type: ignore
    def setUserInfo(self, string) -> self: ...  # type: ignore
    def setUserName(self, string) -> self: ...  # type: ignore
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MUint64Array:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MUintArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MUserData:
    def __init__(self, deleteAfterUse=..., legacy=...) -> Any: ...  # type: ignore
    def deleteAfterUse(self) -> bool: ...
    def setDeleteAfterUse(self, bool) -> self: ...  # type: ignore

class MUserEventMessage(MMessage):
    @staticmethod
    def addUserEventCallback(eventName, function, clientData=...) -> id: ...  # type: ignore
    @staticmethod
    def deregisterUserEvent(eventName) -> Any: ...
    @staticmethod
    def isUserEvent(eventName) -> bool: ...
    @staticmethod
    def postUserEvent(eventName, clientData=...) -> Any: ...
    @staticmethod
    def registerUserEvent(eventName) -> Any: ...

class MUuid:
    def __init__(self, *args, **kwargs) -> None: ...
    def asString(self) -> string: ...  # type: ignore
    def copy(self, source) -> self: ...  # type: ignore
    def generate(self) -> self: ...  # type: ignore
    def valid(self) -> bool: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class MVector:
    kOneVector: ClassVar[MVector] = ...
    kTolerance: ClassVar[float] = ...
    kWaxis: ClassVar[int] = ...
    kXaxis: ClassVar[int] = ...
    kXaxisVector: ClassVar[MVector] = ...
    kXnegAxisVector: ClassVar[MVector] = ...
    kYaxis: ClassVar[int] = ...
    kYaxisVector: ClassVar[MVector] = ...
    kYnegAxisVector: ClassVar[MVector] = ...
    kZaxis: ClassVar[int] = ...
    kZaxisVector: ClassVar[MVector] = ...
    kZeroVector: ClassVar[MVector] = ...
    kZnegAxisVector: ClassVar[MVector] = ...
    x: Incomplete
    y: Incomplete
    z: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def angle(self, *args, **kwargs): ...
    def isEquivalent(self, *args, **kwargs): ...
    def isParallel(self, *args, **kwargs): ...
    def length(self, *args, **kwargs): ...
    def normal(self, *args, **kwargs): ...
    def normalize(self, *args, **kwargs): ...
    def rotateBy(self, *args, **kwargs): ...
    def rotateTo(self, *args, **kwargs): ...
    def transformAsNormal(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getitem__(self, index): ...
    def __gt__(self, other: object) -> bool: ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __isub__(self, other): ...
    def __itruediv__(self, other): ...
    def __le__(self, other: object) -> bool: ...
    def __len__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...
    def __mul__(self, other): ...
    def __ne__(self, other: object) -> bool: ...
    def __neg__(self): ...
    def __radd__(self, other): ...
    def __rmul__(self, other): ...
    def __rsub__(self, other): ...
    def __rtruediv__(self, other): ...
    def __rxor__(self, other): ...
    def __setitem__(self, index, object) -> None: ...
    def __sub__(self, other): ...
    def __truediv__(self, other): ...
    def __xor__(self, other): ...

class MVectorArray:
    sizeIncrement: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def append(self, *args, **kwargs): ...
    def clear(self, *args, **kwargs): ...
    def copy(self, *args, **kwargs): ...
    def insert(self, *args, **kwargs): ...
    def remove(self, *args, **kwargs): ...
    def setLength(self, *args, **kwargs): ...
    def __add__(self, other): ...
    def __contains__(self, other) -> bool: ...
    def __delitem__(self, other) -> None: ...
    def __getitem__(self, index): ...
    def __iadd__(self, other): ...
    def __imul__(self, other): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __rmul__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

class MWeight:
    influence: Incomplete
    seam: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...

def getStringResource(*args, **kwargs): ...
def registerStringResource(*args, **kwargs): ...
def registerStringResources(*args, **kwargs): ...
